@@ -1,22 +1,8 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2018 Dominik Haumann <dhaumann@kde.org>
 
-   Copyright (C) 2018 Dominik Haumann <dhaumann@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License as published by the Free Software Foundation; either
-   version 2.1 of the License, or (at your option) version 3, or any
-   later version accepted by the membership of KDE e.V. (or its
-   successor approved by the membership of KDE e.V.), which shall
-   act as a proxy defined in Section 6 of version 3 of the license.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "inlinenote_test.h"
@@ -81,37 +67,42 @@ public:
             painter.drawEllipse(1, 1, note.width() - 2, note.lineHeight() - 2);
         } else if (note.position().column() == 10) {
             painter.setPen(Qt::darkRed);
-            painter.setBrush(Qt::red);
+            if (note.underMouse()) {
+                painter.setBrush(Qt::red);
+            } else {
+                painter.setBrush(Qt::yellow);
+            }
             painter.drawRoundedRect(1, 1, note.width() - 2, note.lineHeight() - 2, 2, 2);
         }
     }
 
     void inlineNoteActivated(const InlineNote &note, Qt::MouseButtons buttons, const QPoint &globalPos) override
     {
-        Q_UNUSED(note)
         Q_UNUSED(buttons)
         Q_UNUSED(globalPos)
         ++noteActivatedCount;
+        lastUnderMouse = note.underMouse();
     }
 
     void inlineNoteFocusInEvent(const InlineNote &note, const QPoint &globalPos) override
     {
-        Q_UNUSED(note)
         Q_UNUSED(globalPos)
         ++focusInCount;
+        lastUnderMouse = note.underMouse();
     }
 
     void inlineNoteFocusOutEvent(const InlineNote &note) override
     {
-        Q_UNUSED(note)
         ++focusOutCount;
+        // Here it should not be under the mosu
+        lastUnderMouse = note.underMouse();
     }
 
     void inlineNoteMouseMoveEvent(const InlineNote &note, const QPoint &globalPos) override
     {
-        Q_UNUSED(note)
         Q_UNUSED(globalPos)
         ++mouseMoveCount;
+        lastUnderMouse = note.underMouse();
     }
 
 public:
@@ -119,6 +110,7 @@ public:
     int focusInCount = 0;
     int focusOutCount = 0;
     int mouseMoveCount = 0;
+    bool lastUnderMouse = false;
 };
 }
 
@@ -180,6 +172,7 @@ void InlineNoteTest::testInlineNote()
     QCOMPARE(noteProvider.focusInCount, 0);
     QCOMPARE(noteProvider.focusOutCount, 0);
     QCOMPARE(noteProvider.mouseMoveCount, 0);
+    QVERIFY(noteProvider.lastUnderMouse == false);
 
     // move mouse onto first note
     auto internalView = findViewInternal(&view);
@@ -192,6 +185,7 @@ void InlineNoteTest::testInlineNote()
     QCOMPARE(noteProvider.focusOutCount, 0);
     QCOMPARE(noteProvider.mouseMoveCount, 0);
     QCOMPARE(noteProvider.noteActivatedCount, 0);
+    QVERIFY(noteProvider.lastUnderMouse);
 
     // move one pixel
     QTest::mouseMove(&view, coordCol05 + QPoint(xWidth / 2 + 1, 1));
@@ -200,6 +194,7 @@ void InlineNoteTest::testInlineNote()
     QCOMPARE(noteProvider.focusOutCount, 0);
     QCOMPARE(noteProvider.mouseMoveCount, 1);
     QCOMPARE(noteProvider.noteActivatedCount, 0);
+    QVERIFY(noteProvider.lastUnderMouse);
 
     // activate
     QTest::mousePress(internalView, Qt::LeftButton, Qt::NoModifier, internalView->mapFromGlobal(view.mapToGlobal(coordCol05 + QPoint(xWidth / 2 + 1, 1))));
@@ -209,6 +204,7 @@ void InlineNoteTest::testInlineNote()
     QCOMPARE(noteProvider.focusOutCount, 0);
     QCOMPARE(noteProvider.mouseMoveCount, 1);
     QCOMPARE(noteProvider.noteActivatedCount, 1);
+    QVERIFY(noteProvider.lastUnderMouse);
 
     // focus out
     QTest::mouseMove(&view, coordCol04 + QPoint(0, 1));
@@ -218,6 +214,7 @@ void InlineNoteTest::testInlineNote()
     QCOMPARE(noteProvider.focusOutCount, 1);
     QCOMPARE(noteProvider.mouseMoveCount, 1);
     QCOMPARE(noteProvider.noteActivatedCount, 1);
+    QVERIFY(noteProvider.lastUnderMouse == false);
 
     iface->unregisterInlineNoteProvider(&noteProvider);
 }
