@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2010 Milian Wolff <mail@milianw.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2010 Milian Wolff <mail@milianw.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kateview_test.h"
@@ -508,4 +496,47 @@ void KateViewTest::testGotoMatchingBracket()
     QCOMPARE(view->cursorPosition(), cursor1);
 }
 
+void KateViewTest::testFindSelected()
+{
+    KTextEditor::DocumentPrivate doc(false, false);
+    doc.setText(
+        "foo\n"
+        "bar\n"
+        "foo\n"
+        "bar\n");
+    //           0123456789
+
+    KTextEditor::ViewPrivate *view = new KTextEditor::ViewPrivate(&doc, nullptr);
+    const KTextEditor::Cursor cursor1(0, 0); // before 1. foo
+    const KTextEditor::Cursor cursor2(0, 3); // after 1. foo
+    const KTextEditor::Range range1({0, 0}, {0, 3}); // 1. foo range
+    const KTextEditor::Cursor cursor3(2, 3); // after 2. foo
+    const KTextEditor::Range range2({2, 0}, {2, 3}); // 2. foo range
+
+    QVERIFY(!view->selection());
+    QCOMPARE(view->cursorPosition(), cursor1);
+
+    // first time we call this without a selection, just select the word under the cursor
+    view->findSelectedForwards();
+    QVERIFY(view->selection());
+    QCOMPARE(view->selectionRange(), range1);
+    // cursor jumps to the end of the word
+    QCOMPARE(view->cursorPosition(), cursor2);
+
+    // second time we call this it actually jumps to the next occurance
+    view->findSelectedForwards();
+    QCOMPARE(view->selectionRange(), range2);
+    QCOMPARE(view->cursorPosition(), cursor3);
+
+    // wrap around
+    view->findSelectedForwards();
+    QCOMPARE(view->selectionRange(), range1);
+    QCOMPARE(view->cursorPosition(), cursor2);
+
+    // search backwards, wrap again
+    view->findSelectedBackwards();
+    QCOMPARE(view->selectionRange(), range2);
+    QCOMPARE(view->cursorPosition(), cursor3);
+}
+
 // kate: indent-mode cstyle; indent-width 4; replace-tabs on;
