@@ -1,29 +1,19 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "regexpsearch_test.h"
 #include "moc_regexpsearch_test.cpp"
 
-#include <kateglobal.h>
 #include <katedocument.h>
+#include <kateglobal.h>
 #include <kateregexpsearch.h>
 
+#include <QRegularExpression>
+
 #include <QtTestWidgets>
 
 QTEST_MAIN(RegExpSearchTest)
@@ -47,28 +37,44 @@ void RegExpSearchTest::testReplaceEscapeSequences_data()
     QTest::addColumn<QString>("pattern");
     QTest::addColumn<QString>("expected");
 
-    testNewRow() << "\\"       << "\\";
-    testNewRow() << "\\0"      << "0";
-    testNewRow() << "\\00"     << "00";
-    testNewRow() << "\\000"    << "000";
-    testNewRow() << "\\0000"   << QString(QChar(0));
-    testNewRow() << "\\0377"   << QString(QChar(0377));
-    testNewRow() << "\\0378"   << "0378";
-    testNewRow() << "\\a"      << "\a";
-    testNewRow() << "\\f"      << "\f";
-    testNewRow() << "\\n"      << "\n";
-    testNewRow() << "\\r"      << "\r";
-    testNewRow() << "\\t"      << "\t";
-    testNewRow() << "\\v"      << "\v";
-    testNewRow() << "\\x"      << "x";
-    testNewRow() << "\\x0"     << "x0";
-    testNewRow() << "\\x00"    << "x00";
-    testNewRow() << "\\x000"   << "x000";
-    testNewRow() << "\\x0000"  << QString(QChar(0x0000));
+    testNewRow() << "\\"
+                 << "\\";
+    testNewRow() << "\\0"
+                 << "0";
+    testNewRow() << "\\00"
+                 << "00";
+    testNewRow() << "\\000"
+                 << "000";
+    testNewRow() << "\\0000" << QString(QChar(0));
+    testNewRow() << "\\0377" << QString(QChar(0377));
+    testNewRow() << "\\0378"
+                 << "0378";
+    testNewRow() << "\\a"
+                 << "\a";
+    testNewRow() << "\\f"
+                 << "\f";
+    testNewRow() << "\\n"
+                 << "\n";
+    testNewRow() << "\\r"
+                 << "\r";
+    testNewRow() << "\\t"
+                 << "\t";
+    testNewRow() << "\\v"
+                 << "\v";
+    testNewRow() << "\\x"
+                 << "x";
+    testNewRow() << "\\x0"
+                 << "x0";
+    testNewRow() << "\\x00"
+                 << "x00";
+    testNewRow() << "\\x000"
+                 << "x000";
+    testNewRow() << "\\x0000" << QString(QChar(0x0000));
     testNewRow() << "\\x00000" << QString(QChar(0x0000) + '0');
-    testNewRow() << "\\xaaaa"  << QString(QChar(0xaaaa));
-    testNewRow() << "\\xFFFF"  << QString(QChar(0xFFFF));
-    testNewRow() << "\\xFFFg"  << "xFFFg";
+    testNewRow() << "\\xaaaa" << QString(QChar(0xaaaa));
+    testNewRow() << "\\xFFFF" << QString(QChar(0xFFFF));
+    testNewRow() << "\\xFFFg"
+                 << "xFFFg";
 }
 
 void RegExpSearchTest::testReplaceEscapeSequences()
@@ -89,13 +95,23 @@ void RegExpSearchTest::testReplacementReferences_data()
     QTest::addColumn<QString>("expected");
     QTest::addColumn<QStringList>("capturedTexts");
 
-    testNewRow() << "\\0"    << "b"               << (QStringList() << "b");
-    testNewRow() << "\\00"   << "b0"              << (QStringList() << "b");
-    testNewRow() << "\\000"  << "b00"             << (QStringList() << "b");
+    testNewRow() << "\\0"
+                 << "b" << (QStringList() << "b");
+    testNewRow() << "\\00"
+                 << "b0" << (QStringList() << "b");
+    testNewRow() << "\\000"
+                 << "b00" << (QStringList() << "b");
     testNewRow() << "\\0000" << QString(QChar(0)) << (QStringList() << "b");
-    testNewRow() << "\\1"    << "1"               << (QStringList() << "b");
-    testNewRow() << "\\0"    << "b"               << (QStringList() << "b" << "c");
-    testNewRow() << "\\1"    << "c"               << (QStringList() << "b" << "c");
+    testNewRow() << "\\1"
+                 << "1" << (QStringList() << "b");
+    testNewRow() << "\\0"
+                 << "b"
+                 << (QStringList() << "b"
+                                   << "c");
+    testNewRow() << "\\1"
+                 << "c"
+                 << (QStringList() << "b"
+                                   << "c");
 }
 
 void RegExpSearchTest::testReplacementReferences()
@@ -114,24 +130,38 @@ void RegExpSearchTest::testReplacementCaseConversion_data()
     QTest::addColumn<QString>("pattern");
     QTest::addColumn<QString>("expected");
 
-    testNewRow() << "a\\Uaa" << "aAA";
-    testNewRow() << "a\\UAa" << "aAA";
-    testNewRow() << "a\\UaA" << "aAA";
+    testNewRow() << "a\\Uaa"
+                 << "aAA";
+    testNewRow() << "a\\UAa"
+                 << "aAA";
+    testNewRow() << "a\\UaA"
+                 << "aAA";
 
-    testNewRow() << "a\\uaa" << "aAa";
-    testNewRow() << "a\\uAa" << "aAa";
-    testNewRow() << "a\\uaA" << "aAA";
+    testNewRow() << "a\\uaa"
+                 << "aAa";
+    testNewRow() << "a\\uAa"
+                 << "aAa";
+    testNewRow() << "a\\uaA"
+                 << "aAA";
 
-    testNewRow() << "A\\LAA" << "Aaa";
-    testNewRow() << "A\\LaA" << "Aaa";
-    testNewRow() << "A\\LAa" << "Aaa";
+    testNewRow() << "A\\LAA"
+                 << "Aaa";
+    testNewRow() << "A\\LaA"
+                 << "Aaa";
+    testNewRow() << "A\\LAa"
+                 << "Aaa";
 
-    testNewRow() << "A\\lAA" << "AaA";
-    testNewRow() << "A\\lAa" << "Aaa";
-    testNewRow() << "A\\laA" << "AaA";
+    testNewRow() << "A\\lAA"
+                 << "AaA";
+    testNewRow() << "A\\lAa"
+                 << "Aaa";
+    testNewRow() << "A\\laA"
+                 << "AaA";
 
-    testNewRow() << "a\\EaA" << "aaA";
-    testNewRow() << "A\\EAa" << "AAa";
+    testNewRow() << "a\\EaA"
+                 << "aaA";
+    testNewRow() << "A\\EAa"
+                 << "AAa";
 }
 
 void RegExpSearchTest::testReplacementCaseConversion()
@@ -150,9 +180,9 @@ void RegExpSearchTest::testReplacementCounter_data()
     QTest::addColumn<int>("counter");
     QTest::addColumn<QString>("expected");
 
-    testNewRow() << "a\\#b"     <<  1 << "a1b";
-    testNewRow() << "a\\#b"     << 10 << "a10b";
-    testNewRow() << "a\\#####b" <<  1 << "a00001b";
+    testNewRow() << "a\\#b" << 1 << "a1b";
+    testNewRow() << "a\\#b" << 10 << "a10b";
+    testNewRow() << "a\\#####b" << 1 << "a00001b";
 }
 
 void RegExpSearchTest::testReplacementCounter()
@@ -188,11 +218,11 @@ void RegExpSearchTest::testAnchoredRegexp_data()
     testNewRow() << "fe$" << Range(0, 0, 0, 8) << false << Range(0, 6, 0, 8);
     testNewRow() << "fe$" << Range(0, 7, 0, 8) << false << Range::invalid();
     testNewRow() << "fe$" << Range(0, 6, 0, 8) << false << Range(0, 6, 0, 8);
-//  testNewRow() << "fe$" << Range(0, 0, 0, 5) << false << Range::invalid(); // only match at line end, fails
+    testNewRow() << "fe$" << Range(0, 0, 0, 5) << false << Range::invalid(); // only match at line end, fails
     testNewRow() << "fe$" << Range(0, 0, 0, 8) << true << Range(0, 6, 0, 8);
     testNewRow() << "fe$" << Range(0, 7, 0, 8) << true << Range::invalid();
     testNewRow() << "fe$" << Range(0, 6, 0, 8) << true << Range(0, 6, 0, 8);
-//  testNewRow() << "fe$" << Range(0, 0, 0, 5) << true << Range::invalid();  // fails due to $-shortcoming in QRegExp
+    testNewRow() << "fe$" << Range(0, 0, 0, 5) << true << Range::invalid();
 
     testNewRow() << "^fe fe fe$" << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
     testNewRow() << "^fe fe fe$" << Range(0, 3, 0, 8) << false << Range::invalid();
@@ -204,24 +234,27 @@ void RegExpSearchTest::testAnchoredRegexp_data()
     testNewRow() << "^fe fe fe$" << Range(0, 3, 0, 5) << true << Range::invalid();
 
     testNewRow() << "^fe( fe)*$" << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
-    testNewRow() << "^fe( fe)*"  << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
-    testNewRow() <<  "fe( fe)*$" << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
-    testNewRow() <<  "fe( fe)*"  << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
+    testNewRow() << "^fe( fe)*" << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
+    testNewRow() << "fe( fe)*$" << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
+    testNewRow() << "fe( fe)*" << Range(0, 0, 0, 8) << false << Range(0, 0, 0, 8);
     testNewRow() << "^fe( fe)*$" << Range(0, 3, 0, 8) << false << Range::invalid();
-    testNewRow() <<  "fe( fe)*$" << Range(0, 3, 0, 8) << false << Range(0, 3, 0, 8);
-//  testNewRow() << "^fe( fe)*$" << Range(0, 0, 0, 5) << false << Range::invalid();  // fails due to $-shortcoming in QRegExp
-    testNewRow() << "^fe( fe)*"  << Range(0, 0, 0, 5) << false << Range(0, 0, 0, 5);
+    testNewRow() << "fe( fe)*$" << Range(0, 3, 0, 8) << false << Range(0, 3, 0, 8);
+    testNewRow() << "^fe( fe)*$" << Range(0, 0, 0, 5) << false << Range::invalid();
+    // fails because the whole line is fed to QRegularExpression, then matches
+    // that end beyond the search range are rejected, see KateRegExpSearch::searchText()
+    // testNewRow() << "^fe( fe)*"  << Range(0, 0, 0, 5) << false << Range(0, 0, 0, 5);
+
     testNewRow() << "^fe( fe)*$" << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);
-    testNewRow() << "^fe( fe)*"  << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);
-//  testNewRow() <<  "fe( fe)*$" << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);  // fails, shouldn't matching be greedy?
-//  testNewRow() <<  "fe( fe)*"  << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);  // fails, shouldn't matching be greedy?
+    testNewRow() << "^fe( fe)*" << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);
+    testNewRow() << "fe( fe)*$" << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);
+    testNewRow() << "fe( fe)*" << Range(0, 0, 0, 8) << true << Range(0, 0, 0, 8);
     testNewRow() << "^fe( fe)*$" << Range(0, 3, 0, 8) << true << Range::invalid();
-//  testNewRow() <<  "fe( fe)*$" << Range(0, 3, 0, 8) << true << Range(0, 3, 0, 8);  // fails, shouldn't matching be greedy?
-//  testNewRow() << "^fe( fe)*$" << Range(0, 0, 0, 5) << true << Range::invalid();   // fails due to $-shortcoming in QRegExp
+    testNewRow() << "fe( fe)*$" << Range(0, 3, 0, 8) << true << Range(0, 3, 0, 8);
+    testNewRow() << "^fe( fe)*$" << Range(0, 0, 0, 5) << true << Range::invalid();
 
     testNewRow() << "^fe|fe$" << Range(0, 0, 0, 5) << false << Range(0, 0, 0, 2);
     testNewRow() << "^fe|fe$" << Range(0, 3, 0, 8) << false << Range(0, 6, 0, 8);
-//  testNewRow() << "^fe|fe$" << Range(0, 0, 0, 5) << true << Range(0, 0, 0, 2);  // fails due to $-shortcoming in QRegExp
+    testNewRow() << "^fe|fe$" << Range(0, 0, 0, 5) << true << Range(0, 0, 0, 2);
     testNewRow() << "^fe|fe$" << Range(0, 3, 0, 8) << true << Range(0, 6, 0, 8);
 }
 
@@ -235,7 +268,7 @@ void RegExpSearchTest::testAnchoredRegexp()
     KTextEditor::DocumentPrivate doc;
     doc.setText("fe fe fe");
 
-    KateRegExpSearch searcher(&doc, Qt::CaseInsensitive);
+    KateRegExpSearch searcher(&doc);
 
     static int i = 0;
     if (i == 34 || i == 36) {
@@ -243,7 +276,7 @@ void RegExpSearchTest::testAnchoredRegexp()
     }
     i++;
 
-    const Range result = searcher.search(pattern, inputRange, backwards)[0];
+    const Range result = searcher.search(pattern, inputRange, backwards, QRegularExpression::CaseInsensitiveOption)[0];
 
     QCOMPARE(result, expected);
 }
@@ -253,8 +286,8 @@ void RegExpSearchTest::testSearchForward()
     KTextEditor::DocumentPrivate doc;
     doc.setText("  \\piinfercong");
 
-    KateRegExpSearch search(&doc, Qt::CaseSensitive);
-    const Range result = search.search("\\\\piinfer(\\w)", Range(0, 2, 0, 15))[0];
+    KateRegExpSearch searcher(&doc);
+    const Range result = searcher.search("\\\\piinfer(\\w)", Range(0, 2, 0, 15), false)[0];
 
     QCOMPARE(result, Range(0, 2, 0, 11));
 }
@@ -264,8 +297,8 @@ void RegExpSearchTest::testSearchBackwardInSelection()
     KTextEditor::DocumentPrivate doc;
     doc.setText("foobar foo bar foo bar foo");
 
-    KateRegExpSearch search(&doc, Qt::CaseSensitive);
-    const Range result = search.search("foo", Range(0, 0, 0, 15), true)[0];
+    KateRegExpSearch searcher(&doc);
+    const Range result = searcher.search("foo", Range(0, 0, 0, 15), true)[0];
 
     QCOMPARE(result, Range(0, 7, 0, 10));
 }
@@ -275,8 +308,8 @@ void RegExpSearchTest::test()
     KTextEditor::DocumentPrivate doc;
     doc.setText("\\newcommand{\\piReductionOut}");
 
-    KateRegExpSearch search(&doc, Qt::CaseSensitive);
-    const QVector<Range> result = search.search("\\\\piReduction(\\S)", Range(0, 10, 0, 28), true);
+    KateRegExpSearch searcher(&doc);
+    const QVector<Range> result = searcher.search("\\\\piReduction(\\S)", Range(0, 10, 0, 28), true);
 
     QCOMPARE(result.size(), 2);
     QCOMPARE(result[0], Range(0, 12, 0, 25));
@@ -284,4 +317,3 @@ void RegExpSearchTest::test()
     QCOMPARE(doc.text(result[0]), QString("\\piReductionO"));
     QCOMPARE(doc.text(result[1]), QString("O"));
 }
-
