@@ -1,36 +1,20 @@
 /*
- * This file is part of the KDE libraries
- *
- * Copyright (C) 2014 Miquel Sabaté Solà <mikisabate@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2014 Miquel Sabaté Solà <mikisabate@gmail.com>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
+#include "view.h"
 #include <QClipboard>
+#include <inputmode/kateviinputmode.h>
 #include <katebuffer.h>
 #include <kateconfig.h>
-#include <inputmode/kateviinputmode.h>
-#include "view.h"
 
 using namespace KTextEditor;
 
-
 QTEST_MAIN(ViewTest)
 
-
 void ViewTest::yankHighlightingTests()
 {
     const QColor yankHighlightColour = kate_view->renderer()->config()->savedLineColor();
@@ -99,7 +83,7 @@ void ViewTest::visualLineUpDownTests()
 {
     // Need to ensure we have dynamic wrap, a fixed width font, and a decent size kate_view.
     ensureKateViewVisible();
-    const QFont oldFont = kate_view->renderer()->config()->font();
+    const QFont oldFont = kate_view->renderer()->config()->baseFont();
     QFont fixedWidthFont("Courier");
     fixedWidthFont.setStyleHint(QFont::TypeWriter);
     Q_ASSERT_X(QFontInfo(fixedWidthFont).fixedPitch(), "setting up visual line up down tests", "Need a fixed pitch font!");
@@ -168,7 +152,7 @@ void ViewTest::visualLineUpDownTests()
 
     {
         // Jump down a few lines all in one go, where we have some variable length lines to navigate.
-        const int numVisualLinesOnLine[] = { 3, 5, 2, 3 };
+        const int numVisualLinesOnLine[] = {3, 5, 2, 3};
         const int numLines = sizeof(numVisualLinesOnLine) / sizeof(int);
         const int startVisualLine = 2;
         const int numberLinesToGoDownInOneGo = 10;
@@ -216,8 +200,8 @@ void ViewTest::visualLineUpDownTests()
         // Deal with dynamic wrapping and indented blocks - continuations of a line are "invisibly" idented by
         // the same amount as the beginning of the line, and we have to subtract this indentation.
         const QString unindentedFirstLine = "stickyhelper\n";
-        const int  numIndentationSpaces = 5;
-        Q_ASSERT(textWrappingLength >  numIndentationSpaces * 2 /* keep some wriggle room */);
+        const int numIndentationSpaces = 5;
+        Q_ASSERT(textWrappingLength > numIndentationSpaces * 2 /* keep some wriggle room */);
         const QString indentedFillsLineEndsOnSpace = QString(" ").repeated(numIndentationSpaces) + QString("X").repeated(textWrappingLength - 1 - numIndentationSpaces) + ' ';
         DoTest(unindentedFirstLine + indentedFillsLineEndsOnSpace + "LINE3", QString("l").repeated(numIndentationSpaces) + "jgjr.", unindentedFirstLine + indentedFillsLineEndsOnSpace + ".INE3");
 
@@ -229,8 +213,8 @@ void ViewTest::visualLineUpDownTests()
 
     {
         // Take into account any invisible indentation when setting the sticky column.
-        const int  numIndentationSpaces = 5;
-        Q_ASSERT(textWrappingLength >  numIndentationSpaces * 2 /* keep some wriggle room */);
+        const int numIndentationSpaces = 5;
+        Q_ASSERT(textWrappingLength > numIndentationSpaces * 2 /* keep some wriggle room */);
         const QString indentedFillsLineEndsOnSpace = QString(" ").repeated(numIndentationSpaces) + QString("X").repeated(textWrappingLength - 1 - numIndentationSpaces) + ' ';
         const int posInSecondWrappedLineToChange = 3;
         QString expectedText = indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace;
@@ -297,9 +281,7 @@ void ViewTest::visualLineUpDownTests()
         const int posOnSecondLineToChange = 2;
         QString expectedSecondLine = beginsWithTabFillsLineEndsOnSpace;
         expectedSecondLine[posOnSecondLineToChange + 1 /* "+1" as we're not counting the leading tab as a pos */] = '.';
-        DoTest(unindentedFirstLine + beginsWithTabFillsLineEndsOnSpace + fillsLineAndEndsOnSpace,
-               QString("l").repeated(tabWidth + posOnSecondLineToChange) + "gjgjgkr.",
-               unindentedFirstLine + expectedSecondLine + fillsLineAndEndsOnSpace);
+        DoTest(unindentedFirstLine + beginsWithTabFillsLineEndsOnSpace + fillsLineAndEndsOnSpace, QString("l").repeated(tabWidth + posOnSecondLineToChange) + "gjgjgkr.", unindentedFirstLine + expectedSecondLine + fillsLineAndEndsOnSpace);
     }
 
     // Restore back to how we were before.
@@ -315,12 +297,11 @@ void ViewTest::ScrollViewTests()
 
     // First of all, we have to initialize some sizes and fonts.
     ensureKateViewVisible();
-    const QFont oldFont = kate_view->renderer()->config()->font();
+    const QFont oldFont = kate_view->renderer()->config()->baseFont();
     QFont fixedWidthFont("Monospace");
     fixedWidthFont.setStyleHint(QFont::TypeWriter);
     fixedWidthFont.setPixelSize(14);
-    Q_ASSERT_X(QFontInfo(fixedWidthFont).fixedPitch(),
-               "setting up ScrollViewTests", "Need a fixed pitch font!");
+    Q_ASSERT_X(QFontInfo(fixedWidthFont).fixedPitch(), "setting up ScrollViewTests", "Need a fixed pitch font!");
     kate_view->renderer()->config()->setFont(fixedWidthFont);
 
     // Generating our text here.
@@ -389,13 +370,24 @@ void ViewTest::clipboardTests_data()
     QTest::addColumn<QString>("commands");
     QTest::addColumn<QString>("clipboard");
 
-    QTest::newRow("yank") << "yyfoo\nbar" << "yy" << "yyfoo\n";
-    QTest::newRow("delete") << "ddfoo\nbar" << "dd" << "ddfoo\n";
-    QTest::newRow("yank empty line") << "\nbar" << "yy" << QString();
-    QTest::newRow("delete word") << "word foo" << "dw" << "word ";
-    QTest::newRow("delete onechar word") << "w foo" << "dw" << "w ";
-    QTest::newRow("delete onechar") << "word foo" << "dc" << QString();
-    QTest::newRow("delete empty lines") << " \t\n\n  \nfoo" << "d3d" << QString();
+    QTest::newRow("yank") << "yyfoo\nbar"
+                          << "yy"
+                          << "yyfoo\n";
+    QTest::newRow("delete") << "ddfoo\nbar"
+                            << "dd"
+                            << "ddfoo\n";
+    QTest::newRow("yank empty line") << "\nbar"
+                                     << "yy" << QString();
+    QTest::newRow("delete word") << "word foo"
+                                 << "dw"
+                                 << "word ";
+    QTest::newRow("delete onechar word") << "w foo"
+                                         << "dw"
+                                         << "w ";
+    QTest::newRow("delete onechar") << "word foo"
+                                    << "dc" << QString();
+    QTest::newRow("delete empty lines") << " \t\n\n  \nfoo"
+                                        << "d3d" << QString();
 }
 
 void ViewTest::clipboardTests()
