@@ -1,31 +1,17 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "expandingdelegate.h"
 
-#include <QTextLine>
-#include <QPainter>
+#include <QApplication>
 #include <QBrush>
 #include <QKeyEvent>
+#include <QPainter>
+#include <QTextLine>
 #include <QTreeView>
-#include <QApplication>
 
 #include "katepartdebug.h"
 
@@ -33,16 +19,16 @@
 
 ExpandingDelegate::ExpandingDelegate(ExpandingWidgetModel *model, QObject *parent)
     : QItemDelegate(parent)
+    , m_currentColumnStart(0)
     , m_model(model)
 {
 }
 
-//Gets the background-color in the way QItemDelegate does it
+// Gets the background-color in the way QItemDelegate does it
 static QColor getUsedBackgroundColor(const QStyleOptionViewItem &option, const QModelIndex &index)
 {
     if (option.showDecorationSelected && (option.state & QStyle::State_Selected)) {
-        QPalette::ColorGroup cg = option.state & QStyle::State_Enabled
-                                  ? QPalette::Normal : QPalette::Disabled;
+        QPalette::ColorGroup cg = (option.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
         if (cg == QPalette::Normal && !(option.state & QStyle::State_Active)) {
             cg = QPalette::Inactive;
         }
@@ -60,14 +46,14 @@ static QColor getUsedBackgroundColor(const QStyleOptionViewItem &option, const Q
 
 static void dampColors(QColor &col)
 {
-    //Reduce the colors that are less visible to the eye, because they are closer to black when it comes to contrast
-    //The most significant color to the eye is green. Then comes red, and then blue, with blue _much_ less significant.
+    // Reduce the colors that are less visible to the eye, because they are closer to black when it comes to contrast
+    // The most significant color to the eye is green. Then comes red, and then blue, with blue _much_ less significant.
 
     col.setBlue(0);
     col.setRed(col.red() / 2);
 }
 
-//A hack to compute more eye-focused contrast values
+// A hack to compute more eye-focused contrast values
 static double readabilityContrast(QColor foreground, QColor background)
 {
     dampColors(foreground);
@@ -87,7 +73,7 @@ void ExpandingDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
         model()->placeExpandingWidget(index);
     }
 
-    //Make sure the decorations are painted at the top, because the center of expanded items will be filled with the embedded widget.
+    // Make sure the decorations are painted at the top, because the center of expanded items will be filled with the embedded widget.
     if (model()->isPartiallyExpanded(index) == ExpandingWidgetModel::ExpandUpwards) {
         m_cachedAlignment = Qt::AlignBottom;
     } else {
@@ -97,7 +83,8 @@ void ExpandingDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     option.decorationAlignment = m_cachedAlignment;
     option.displayAlignment = m_cachedAlignment;
 
-    //qCDebug(LOG_KTE) << "Painting row " << index.row() << ", column " << index.column() << ", internal " << index.internalPointer() << ", drawselected " << option.showDecorationSelected << ", selected " << (option.state & QStyle::State_Selected);
+    // qCDebug(LOG_KTE) << "Painting row " << index.row() << ", column " << index.column() << ", internal " << index.internalPointer() << ", drawselected " << option.showDecorationSelected << ", selected " << (option.state &
+    // QStyle::State_Selected);
 
     m_cachedHighlights.clear();
     m_backgroundColor = getUsedBackgroundColor(option, index);
@@ -108,23 +95,23 @@ void ExpandingDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     }
 
     /*qCDebug(LOG_KTE) << "Highlights for line:";
-    foreach (const QTextLayout::FormatRange& fr, m_cachedHighlights)
+    for (const QTextLayout::FormatRange& fr : m_cachedHighlights)
       qCDebug(LOG_KTE) << fr.start << " len " << fr.length << " format ";*/
 
     QItemDelegate::paint(painter, option, index);
 
-    ///This is a bug workaround for the Qt raster paint engine: It paints over widgets embedded into the viewport when updating due to mouse events
+    /// This is a bug workaround for the Qt raster paint engine: It paints over widgets embedded into the viewport when updating due to mouse events
     ///@todo report to Qt Software
     if (model()->isExpanded(index) && model()->expandingWidget(index)) {
         model()->expandingWidget(index)->update();
     }
 }
 
-QList<QTextLayout::FormatRange> ExpandingDelegate::createHighlighting(const QModelIndex &index, QStyleOptionViewItem &option) const
+QVector<QTextLayout::FormatRange> ExpandingDelegate::createHighlighting(const QModelIndex &index, QStyleOptionViewItem &option) const
 {
     Q_UNUSED(index);
     Q_UNUSED(option);
-    return QList<QTextLayout::FormatRange>();
+    return QVector<QTextLayout::FormatRange>();
 }
 
 QSize ExpandingDelegate::basicSizeHint(const QModelIndex &index) const
@@ -139,7 +126,7 @@ QSize ExpandingDelegate::sizeHint(const QStyleOptionViewItem &option, const QMod
         QWidget *widget = model()->expandingWidget(index);
         QSize widgetSize = widget->size();
 
-        s.setHeight(widgetSize.height() + s.height() + 10);   //10 is the sum that must match exactly the offsets used in ExpandingWidgetModel::placeExpandingWidgets
+        s.setHeight(widgetSize.height() + s.height() + 10); // 10 is the sum that must match exactly the offsets used in ExpandingWidgetModel::placeExpandingWidgets
     } else if (model()->isPartiallyExpanded(index)) {
         s.setHeight(s.height() + 30 + 10);
     }
@@ -155,7 +142,6 @@ void ExpandingDelegate::adjustStyle(const QModelIndex &index, QStyleOptionViewIt
 void ExpandingDelegate::adjustRect(QRect &rect) const
 {
     if (!model()->indexIsItem(m_currentIndex) /*&& m_currentIndex.column() == 0*/) {
-
         rect.setLeft(model()->treeView()->columnViewportPosition(0));
         int columnCount = model()->columnCount(m_currentIndex.parent());
 
@@ -174,7 +160,7 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
 
     QTextLayout layout(text, option.font, painter->device());
 
-    QList<QTextLayout::FormatRange> additionalFormats;
+    QVector<QTextLayout::FormatRange> additionalFormats;
 
     int missingFormats = text.length();
 
@@ -183,7 +169,7 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
             continue;
         }
 
-        if (!additionalFormats.count())
+        if (additionalFormats.isEmpty())
             if (i != 0 && m_cachedHighlights[i - 1].start + m_cachedHighlights[i - 1].length > m_currentColumnStart) {
                 QTextLayout::FormatRange before;
                 before.start = 0;
@@ -215,8 +201,8 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
 
     if (m_backgroundColor.isValid()) {
         QColor background = m_backgroundColor;
-//     qCDebug(LOG_KTE) << text << "background:" << background.name();
-        //Now go through the formats, and make sure the contrast background/foreground is readable
+        //     qCDebug(LOG_KTE) << text << "background:" << background.name();
+        // Now go through the formats, and make sure the contrast background/foreground is readable
         for (int a = 0; a < additionalFormats.size(); ++a) {
             QColor currentBackground = background;
             if (additionalFormats[a].format.hasProperty(QTextFormat::BackgroundBrush)) {
@@ -229,10 +215,10 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
             QColor invertedColor(0xffffffff - additionalFormats[a].format.foreground().color().rgb());
             double invertedContrast = readabilityContrast(invertedColor, currentBackground);
 
-//       qCDebug(LOG_KTE) << "values:" << invertedContrast << currentContrast << invertedColor.name() << currentColor.name();
+            //       qCDebug(LOG_KTE) << "values:" << invertedContrast << currentContrast << invertedColor.name() << currentColor.name();
 
             if (invertedContrast > currentContrast) {
-//         qCDebug(LOG_KTE) << text << additionalFormats[a].length << "switching from" << currentColor.name() << "to" << invertedColor.name();
+                //         qCDebug(LOG_KTE) << text << additionalFormats[a].length << "switching from" << currentColor.name() << "to" << invertedColor.name();
                 QBrush b(additionalFormats[a].format.foreground());
                 b.setColor(invertedColor);
                 additionalFormats[a].format.setForeground(b);
@@ -244,7 +230,7 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
         if (additionalFormats[a].length == 0) {
             additionalFormats.removeAt(a);
         } else {
-            ///For some reason the text-formats seem to be invalid in some way, sometimes
+            /// For some reason the text-formats seem to be invalid in some way, sometimes
             ///@todo Fix this properly, it sucks not copying everything over
             QTextCharFormat fm;
             fm.setForeground(QBrush(additionalFormats[a].format.foreground().color()));
@@ -256,15 +242,11 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
         }
     }
 
-//   qCDebug(LOG_KTE) << "Highlights for text [" << text << "] col start " << m_currentColumnStart << ":";
-//   foreach (const QTextLayout::FormatRange& fr, additionalFormats)
-//     qCDebug(LOG_KTE) << fr.start << " len " << fr.length << "foreground" << fr.format.foreground() << "background" << fr.format.background();
-
-    layout.setAdditionalFormats(additionalFormats);
+    layout.setFormats(additionalFormats);
 
     QTextOption to;
 
-    to.setAlignment( static_cast<Qt::Alignment>(m_cachedAlignment | option.displayAlignment) );
+    to.setAlignment(static_cast<Qt::Alignment>(m_cachedAlignment | option.displayAlignment));
 
     to.setWrapMode(QTextOption::WrapAnywhere);
     layout.setTextOption(to);
@@ -275,7 +257,7 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
     line.setLineWidth(rect.width() - (option.displayAlignment == Qt::AlignRight ? 8 : 0));
     layout.endLayout();
 
-    //We need to do some hand layouting here
+    // We need to do some hand layouting here
     if (to.alignment() & Qt::AlignBottom) {
         layout.draw(painter, QPoint(rect.left(), rect.bottom() - (int)line.height()));
     } else {
@@ -284,9 +266,9 @@ void ExpandingDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewIte
 
     return;
 
-    //if (painter->fontMetrics().width(text) > textRect.width() && !text.contains(QLatin1Char('\n')))
-    //str = elidedText(option.fontMetrics, textRect.width(), option.textElideMode, text);
-    //qt_format_text(option.font, textRect, option.displayAlignment, str, 0, 0, 0, 0, painter);
+    // if (painter->fontMetrics().width(text) > textRect.width() && !text.contains(QLatin1Char('\n')))
+    // str = elidedText(option.fontMetrics, textRect.width(), option.textElideMode, text);
+    // qt_format_text(option.font, textRect, option.displayAlignment, str, 0, 0, 0, 0, painter);
 }
 
 void ExpandingDelegate::drawDecoration(QPainter *painter, const QStyleOptionViewItem &option, const QRect &rect, const QPixmap &pixmap) const
@@ -299,11 +281,9 @@ void ExpandingDelegate::drawDecoration(QPainter *painter, const QStyleOptionView
 void ExpandingDelegate::drawBackground(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index)
-    QStyleOptionViewItemV4 opt = option;
-    //initStyleOption(&opt, index);
-    //Problem: This isn't called at all, because drawBrackground is not virtual :-/
+    // Problem: This isn't called at all, because drawBrackground is not virtual :-/
     QStyle *style = model()->treeView()->style() ? model()->treeView()->style() : QApplication::style();
-    style->drawControl(QStyle::CE_ItemViewItem, &opt, painter);
+    style->drawControl(QStyle::CE_ItemViewItem, &option, painter);
 }
 
 ExpandingWidgetModel *ExpandingDelegate::model() const
@@ -330,9 +310,9 @@ bool ExpandingDelegate::editorEvent(QEvent *event, QAbstractItemModel * /*model*
     return false;
 }
 
-QList<QTextLayout::FormatRange> ExpandingDelegate::highlightingFromVariantList(const QList<QVariant> &customHighlights) const
+QVector<QTextLayout::FormatRange> ExpandingDelegate::highlightingFromVariantList(const QList<QVariant> &customHighlights) const
 {
-    QList<QTextLayout::FormatRange> ret;
+    QVector<QTextLayout::FormatRange> ret;
 
     for (int i = 0; i + 2 < customHighlights.count(); i += 3) {
         if (!customHighlights[i].canConvert(QVariant::Int) || !customHighlights[i + 1].canConvert(QVariant::Int) || !customHighlights[i + 2].canConvert<QTextFormat>()) {
