@@ -1,22 +1,8 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2007 David Nolden <david.nolden.kdevelop@art-master.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef EXPANDING_WIDGET_MODEL_H
 #define EXPANDING_WIDGET_MODEL_H
@@ -42,8 +28,6 @@ public:
     /// The following three are convenience-functions for the current item that could be replaced by the later ones
     ///@return whether the current item can be expanded
     bool canExpandCurrentItem() const;
-    ///@return whether the current item can be collapsed
-    bool canCollapseCurrentItem() const;
     /// Expand/collapse the current item
     void setCurrentItemExpanded(bool);
 
@@ -58,7 +42,7 @@ public:
     enum ExpansionType {
         NotExpanded = 0,
         ExpandDownwards, // The additional(expanded) information is shown UNDER the original information
-        ExpandUpwards    // The additional(expanded) information is shown ABOVE the original information
+        ExpandUpwards // The additional(expanded) information is shown ABOVE the original information
     };
 
     /// Returns whether the given index is currently partially expanded. Does not do any other checks like calling models for data.
@@ -138,7 +122,7 @@ private:
     // Store expanding-widgets and cache whether items can be expanded
     mutable QMap<QModelIndex, ExpandingType> m_expandState;
     QMap<QModelIndex, QPointer<QWidget>> m_expandingWidgets; // Map rows to their expanding-widgets
-    QMap<QModelIndex, int> m_contextMatchQualities;          // Map rows to their context-match qualities(undefined if unknown, else 0 to 10). Not used yet, eventually remove.
+    QMap<QModelIndex, int> m_contextMatchQualities; // Map rows to their context-match qualities(undefined if unknown, else 0 to 10). Not used yet, eventually remove.
 };
 
 /**
