@@ -1,32 +1,18 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "katecompletionconfig.h"
 #include "katecompletionmodel.h"
 #include "kateglobal.h"
 #include "ui_completionconfigwidget.h"
 
-#include <KSharedConfig>
 #include <KConfigGroup>
-#include <KStandardGuiItem>
 #include <KLocalizedString>
+#include <KSharedConfig>
+#include <KStandardGuiItem>
 
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -41,8 +27,7 @@ KateCompletionConfig::KateCompletionConfig(KateCompletionModel *model, QWidget *
 {
     setWindowTitle(i18n("Code Completion Configuration"));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QWidget *mw = new QWidget(this);
     mainLayout->addWidget(mw);
