@@ -1,22 +1,8 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATECOMPLETIONCONFIG_H
 #define KATECOMPLETIONCONFIG_H
@@ -42,7 +28,7 @@ class KateCompletionConfig : public QDialog, public KateConfig
 
 public:
     explicit KateCompletionConfig(KateCompletionModel *model, QWidget *parent = nullptr);
-    virtual ~KateCompletionConfig();
+    ~KateCompletionConfig() override;
 
     /**
      * Read config from object
@@ -58,7 +44,7 @@ public Q_SLOTS:
     void apply();
 
 protected:
-    void updateConfig() Q_DECL_OVERRIDE;
+    void updateConfig() override;
 
 private Q_SLOTS:
     void moveColumnUp();
