@@ -1,39 +1,28 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2005-2006 Hamish Rodda <rodda@kde.org>
- *  Copyright (C) 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATECOMPLETIONMODEL_H
 #define KATECOMPLETIONMODEL_H
 
 #include <QAbstractProxyModel>
-#include <QPair>
 #include <QList>
+#include <QPair>
 
 #include <ktexteditor/codecompletionmodel.h>
 
-#include <ktexteditor_export.h>
 #include "expandingtree/expandingwidgetmodel.h"
+#include <ktexteditor_export.h>
 
 class KateCompletionWidget;
 class KateArgumentHintModel;
-namespace KTextEditor { class ViewPrivate; }
+namespace KTextEditor
+{
+class ViewPrivate;
+}
 class QWidget;
 class QTextEdit;
 class QTimer;
@@ -67,15 +56,17 @@ public:
     void setCurrentCompletion(KTextEditor::CodeCompletionModel *model, const QString &completion);
 
     Qt::CaseSensitivity matchCaseSensitivity() const;
-    void setMatchCaseSensitivity(Qt::CaseSensitivity cs);
+    Qt::CaseSensitivity exactMatchCaseSensitivity() const;
+    void setMatchCaseSensitivity(Qt::CaseSensitivity match_cs);
+    void setMatchCaseSensitivity(Qt::CaseSensitivity match_cs, Qt::CaseSensitivity exact_match_cs);
 
     static QString columnName(int column);
     int translateColumn(int sourceColumn) const;
 
     static QString propertyName(KTextEditor::CodeCompletionModel::CompletionProperty property);
 
-    ///Returns a common prefix for all current visible completion entries
-    ///If there is no common prefix, extracts the next useful prefix for the selected index
+    /// Returns a common prefix for all current visible completion entries
+    /// If there is no common prefix, extracts the next useful prefix for the selected index
     QString commonPrefix(QModelIndex selectedIndex) const;
 
     void rowSelected(const QModelIndex &row) override;
@@ -90,18 +81,18 @@ public:
     QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
 
     // Disabled in case of bugs, reenable once fully debugged.
-    //virtual QMap<int, QVariant> itemData ( const QModelIndex & index ) const;
+    // virtual QMap<int, QVariant> itemData ( const QModelIndex & index ) const;
     QModelIndex parent(const QModelIndex &index) const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
     // Disabled in case of bugs, reenable once fully debugged.
-    //virtual QModelIndex sibling ( int row, int column, const QModelIndex & index ) const;
+    // virtual QModelIndex sibling ( int row, int column, const QModelIndex & index ) const;
     void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) override;
 
-    ///Maps from this display-model into the appropriate source code-completion model
+    /// Maps from this display-model into the appropriate source code-completion model
     virtual QModelIndex mapToSource(const QModelIndex &proxyIndex) const;
 
-    ///Maps from an index in a source-model to the index of the item in this display-model
+    /// Maps from an index in a source-model to the index of the item in this display-model
     virtual QModelIndex mapFromSource(const QModelIndex &sourceIndex) const;
 
     // Sorting
@@ -114,9 +105,6 @@ public:
     Qt::CaseSensitivity sortingCaseSensitivity() const;
     void setSortingCaseSensitivity(Qt::CaseSensitivity cs);
 
-    bool isSortingReverse() const;
-    void setSortingReverse(bool reverse);
-
     // Filtering
     bool isFilteringEnabled() const;
 
@@ -136,14 +124,9 @@ public:
     // Grouping
     bool isGroupingEnabled() const;
 
-    enum gm {
-        ScopeType     = 0x1,
-        Scope         = 0x2,
-        AccessType    = 0x4,
-        ItemType      = 0x8
-    };
+    enum gm { ScopeType = 0x1, Scope = 0x2, AccessType = 0x4, ItemType = 0x8 };
 
-    enum { //An own property that will be used to mark the best-matches group internally
+    enum { // An own property that will be used to mark the best-matches group internally
         BestMatchesProperty = 2 * KTextEditor::CodeCompletionModel::LastProperty
     };
 
@@ -166,12 +149,12 @@ public:
     // Column merging
     bool isColumnMergingEnabled() const;
 
-    const QList< QList<int> > &columnMerges() const;
-    void setColumnMerges(const QList< QList<int> > &columnMerges);
+    const QList<QList<int>> &columnMerges() const;
+    void setColumnMerges(const QList<QList<int>> &columnMerges);
 
     void debugStats();
 
-    ///Returns whether one of the filtered items exactly matches its completion string
+    /// Returns whether one of the filtered items exactly matches its completion string
     bool shouldMatchHideCompletionList() const;
 
     uint filteredItemCount() const;
@@ -181,7 +164,7 @@ protected:
 
 Q_SIGNALS:
     void expandIndex(const QModelIndex &index);
-    //Emitted whenever something has changed about the group of argument-hints
+    // Emitted whenever something has changed about the group of argument-hints
     void argumentHintsChanged();
 
 public Q_SLOTS:
@@ -195,14 +178,13 @@ private Q_SLOTS:
     void slotRowsRemoved(const QModelIndex &parent, int start, int end);
     void slotModelReset();
 
-    //Updates the best-matches group
+    // Updates the best-matches group
     void updateBestMatches();
-    //Makes sure that the ungrouped group contains each item only once
-    //Must only be called right after the group was created
+    // Makes sure that the ungrouped group contains each item only once
+    // Must only be called right after the group was created
     void makeGroupItemsUnique(bool onlyFiltered = false);
 
 private:
-
     typedef QPair<KTextEditor::CodeCompletionModel *, QModelIndex> ModelRow;
     virtual int contextMatchQuality(const ModelRow &sourceRow) const;
 
@@ -227,13 +209,7 @@ private:
 
         bool filter();
 
-        enum MatchType {
-            NoMatch = 0,
-            PerfectMatch,
-            StartsWithMatch,
-            AbbreviationMatch,
-            ContainsMatch
-        };
+        enum MatchType { NoMatch = 0, PerfectMatch, StartsWithMatch, AbbreviationMatch, ContainsMatch };
         MatchType match();
 
         const ModelRow &sourceRow() const;
@@ -270,8 +246,6 @@ private:
         bool matchFilters;
         bool m_haveExactMatch;
         bool m_unimportant;
-
-        QString completionSortingName() const;
     };
 
 public:
@@ -279,20 +253,20 @@ public:
     class Group
     {
     public:
-        explicit Group(const QString& title, int attribute, KateCompletionModel *model);
+        explicit Group(const QString &title, int attribute, KateCompletionModel *model);
 
-        void addItem(Item i, bool notifyModel = false);
+        void addItem(const Item &i, bool notifyModel = false);
         /// Removes the item specified by \a row.  Returns true if a change was made to rows.
         bool removeItem(const ModelRow &row);
         void resort();
         void refilter();
         void clear();
-        //Returns whether this group should be ordered before other
+        // Returns whether this group should be ordered before other
         bool orderBefore(Group *other) const;
-        //Returns a number that can be used for ordering
+        // Returns a number that can be used for ordering
         int orderNumber() const;
 
-        ///Returns the row in the this group's filtered list of the given model-row in a source-model
+        /// Returns the row in the this group's filtered list of the given model-row in a source-model
         ///-1 if the item is not in the filtered list
         ///@todo Implement an efficient way of doing this map, that does _not_ iterate over all items!
         int rowOf(ModelRow item)
@@ -320,11 +294,11 @@ private:
     QString commonPrefixInternal(const QString &forcePrefix) const;
     /// @note performs model reset
     void createGroups();
-    ///Creates all sub-items of index i, or the item corresponding to index i. Returns the affected groups.
-    ///i must be an index in the source model
+    /// Creates all sub-items of index i, or the item corresponding to index i. Returns the affected groups.
+    /// i must be an index in the source model
     QSet<Group *> createItems(const HierarchicalModelHandler &, const QModelIndex &i, bool notifyModel = false);
-    ///Deletes all sub-items of index i, or the item corresponding to index i. Returns the affected groups.
-    ///i must be an index in the source model
+    /// Deletes all sub-items of index i, or the item corresponding to index i. Returns the affected groups.
+    /// i must be an index in the source model
     QSet<Group *> deleteItems(const QModelIndex &i);
     Group *createItem(const HierarchicalModelHandler &, const QModelIndex &i, bool notifyModel = false);
     /// @note Make sure you're in a {begin,end}ResetModel block when calling this!
@@ -332,7 +306,7 @@ private:
     void hideOrShowGroup(Group *g, bool notifyModel = false);
     /// When forceGrouping is enabled, all given attributes will be used for grouping, regardless of the completion settings.
     Group *fetchGroup(int attribute, const QString &scope = QString(), bool forceGrouping = false);
-    //If this returns nonzero on an index, the index is the header of the returned group
+    // If this returns nonzero on an index, the index is the header of the returned group
     Group *groupForIndex(const QModelIndex &index) const;
     inline Group *groupOfParent(const QModelIndex &child) const
     {
@@ -341,13 +315,9 @@ private:
     QModelIndex indexForRow(Group *g, int row) const;
     QModelIndex indexForGroup(Group *g) const;
 
-    enum changeTypes {
-        Broaden,
-        Narrow,
-        Change
-    };
+    enum changeTypes { Broaden, Narrow, Change };
 
-    //Returns whether the model needs to be reset
+    // Returns whether the model needs to be reset
     void changeCompletions(Group *g, changeTypes changeType, bool notifyModel);
 
     bool hasCompletionModel() const;
@@ -359,7 +329,7 @@ private:
     void resort();
     void refilter();
 
-    static bool matchesAbbreviation(const QString &word, const QString &typed);
+    static bool matchesAbbreviation(const QString &word, const QString &typed, Qt::CaseSensitivity caseSensitive);
 
     bool m_hasGroups = false;
 
@@ -367,16 +337,15 @@ private:
     // General
     QList<KTextEditor::CodeCompletionModel *> m_completionModels;
     QMap<KTextEditor::CodeCompletionModel *, QString> m_currentMatch;
-    Qt::CaseSensitivity m_matchCaseSensitivity = Qt::CaseInsensitive;
 
     // Column merging
-    QList< QList<int> > m_columnMerges;
+    QList<QList<int>> m_columnMerges;
 
     QTimer *m_updateBestMatchesTimer;
 
     Group *m_ungrouped;
-    Group *m_argumentHints; //The argument-hints will be passed on to another model, to be shown in another widget
-    Group *m_bestMatches; //A temporary group used for holding the best matches of all visible items
+    Group *m_argumentHints; // The argument-hints will be passed on to another model, to be shown in another widget
+    Group *m_bestMatches; // A temporary group used for holding the best matches of all visible items
 
     // Storing the sorted order
     QList<Group *> m_rowTable;
@@ -387,12 +356,16 @@ private:
     QHash<QString, Group *> m_customGroupHash;
 
     // ### Configurable state
+    // Matching
+    Qt::CaseSensitivity m_matchCaseSensitivity = Qt::CaseInsensitive;
+    Qt::CaseSensitivity m_exactMatchCaseSensitivity = Qt::CaseInsensitive; // Must be equal to or stricter than m_matchCaseSensitivity.
+
     // Sorting
     bool m_sortingEnabled = false;
     bool m_sortingAlphabetical = false;
     bool m_isSortingByInheritance = false;
     Qt::CaseSensitivity m_sortingCaseSensitivity = Qt::CaseInsensitive;
-    QHash< int, QList<int> > m_sortingGroupingOrder;
+    QHash<int, QList<int>> m_sortingGroupingOrder;
 
     // Filtering
     bool m_filteringEnabled = false;
@@ -407,7 +380,7 @@ private:
     bool m_accessConst = false, m_accessStatic = false, m_accesSignalSlot = false;
 
     // Column merging
-    bool m_columnMergingEnabled = false/*, m_haveExactMatch*/;
+    bool m_columnMergingEnabled = false /*, m_haveExactMatch*/;
 
     friend class CompletionTest;
 };
