@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
 
-    Copyright (C) 2005-2006 Hamish Rodda <rodda@kde.org>
-    Copyright (C) 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katecompletionwidget.h"
@@ -155,9 +141,7 @@ KateCompletionWidget::KateCompletionWidget(KTextEditor::ViewPrivate *parent)
     connect(view(), SIGNAL(cursorPositionChanged(KTextEditor::View *, KTextEditor::Cursor)), this, SLOT(cursorPositionChanged()));
     connect(view(), SIGNAL(verticalScrollPositionChanged(KTextEditor::View *, KTextEditor::Cursor)), this, SLOT(updatePositionSlot()));
 
-    /**
-     * connect to all possible editing primitives
-     */
+    // connect to all possible editing primitives
     connect(&view()->doc()->buffer(), SIGNAL(lineWrapped(KTextEditor::Cursor)), this, SLOT(wrapLine(KTextEditor::Cursor)));
     connect(&view()->doc()->buffer(), SIGNAL(lineUnwrapped(int)), this, SLOT(unwrapLine(int)));
     connect(&view()->doc()->buffer(), SIGNAL(textInserted(KTextEditor::Cursor, QString)), this, SLOT(insertText(KTextEditor::Cursor, QString)));
@@ -396,7 +380,7 @@ void KateCompletionWidget::startCompletion(const KTextEditor::Range &word, const
         if (m_completionRanges.contains(model)) {
             if (*m_completionRanges[model].range == range) {
                 continue; // Leave it running as it is
-            } else {      // delete the range that was used previously
+            } else { // delete the range that was used previously
                 KTextEditor::MovingRange *oldRange = m_completionRanges[model].range;
                 // qCDebug(LOG_KTE)<<"removing completion range 2";
                 m_completionRanges.remove(model);
@@ -1345,6 +1329,11 @@ bool KateCompletionWidget::isCompletionModelRegistered(KTextEditor::CodeCompleti
     return m_sourceModels.contains(model);
 }
 
+QList<KTextEditor::CodeCompletionModel *> KateCompletionWidget::codeCompletionModels() const
+{
+    return m_sourceModels;
+}
+
 int KateCompletionWidget::automaticInvocationDelay() const
 {
     return m_automaticInvocationDelay;
