@@ -8,10 +8,8 @@
 // BEGIN includes
 #include "katewordcompletion.h"
 #include "kateconfig.h"
-#include "katedefaultcolors.h"
 #include "katedocument.h"
 #include "kateglobal.h"
-#include "katepartdebug.h"
 #include "kateview.h"
 
 #include <ktexteditor/movingrange.h>
@@ -24,7 +22,6 @@
 #include <KPageDialog>
 #include <KPageWidgetModel>
 #include <KParts/Part>
-#include <KPluginFactory>
 #include <KToggleAction>
 
 #include <QAction>
@@ -205,7 +202,7 @@ QStringList KateWordCompletionModel::allMatches(KTextEditor::View *view, const K
         while (offset < end) {
             const QChar c = text.at(offset);
             // increment offset when at line end, so we take the last character too
-            if ((! c.isLetterOrNumber() && c != QLatin1Char('_')) || (offset == end - 1 && offset++)) {
+            if ((!c.isLetterOrNumber() && c != QLatin1Char('_')) || (offset == end - 1 && offset++)) {
                 if (offset - wordBegin > minWordSize && (line != range.end().line() || offset != range.end().column())) {
                     // don't add the word we are inside with cursor!
                     if (!cursorLine || (view->cursorPosition().column() < wordBegin || view->cursorPosition().column() > offset)) {
@@ -290,11 +287,11 @@ KTextEditor::Range KateWordCompletionModel::completionRange(KTextEditor::View *v
 // BEGIN KateWordCompletionView
 struct KateWordCompletionViewPrivate {
     KTextEditor::MovingRange *liRange; // range containing last inserted text
-    KTextEditor::Range dcRange;        // current range to be completed by directional completion
-    KTextEditor::Cursor dcCursor;      // directional completion search cursor
+    KTextEditor::Range dcRange; // current range to be completed by directional completion
+    KTextEditor::Cursor dcCursor; // directional completion search cursor
     QRegularExpression wordRegEx;
     int directionalPos; // be able to insert "" at the correct time
-    bool isCompleting;  // true when the directional completion is doing a completion
+    bool isCompleting; // true when the directional completion is doing a completion
 };
 
 KateWordCompletionView::KateWordCompletionView(KTextEditor::View *view, KActionCollection *ac)
@@ -308,10 +305,8 @@ KateWordCompletionView::KateWordCompletionView(KTextEditor::View *view, KActionC
 
     d->liRange = static_cast<KTextEditor::DocumentPrivate *>(m_view->document())->newMovingRange(KTextEditor::Range::invalid(), KTextEditor::MovingRange::DoNotExpand);
 
-    const KColorScheme &colors(KTextEditor::EditorPrivate::self()->defaultColors().view());
     KTextEditor::Attribute::Ptr a = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
-    a->setBackground(colors.background(KColorScheme::ActiveBackground));
-    a->setForeground(colors.foreground(KColorScheme::ActiveText)); // ### this does 0
+    a->setBackground(static_cast<KTextEditor::ViewPrivate *>(view)->renderer()->config()->selectionColor());
     d->liRange->setAttribute(a);
 
     QAction *action;
