@@ -1,28 +1,17 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2003 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2006 Dominik Haumann <dhdev@gmx.de>
-   Copyright (C) 2007 Mirko Stocker <me@misto.ch>
-   Copyright (C) 2009 Michel Ludwig <michel.ludwig@kdemail.net>
-   Copyright (C) 2009 Erlend Hamberg <ehamberg@gmail.com>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002, 2003 Anders Lund <anders.lund@lund.tdcadsl.dk>
+    SPDX-FileCopyrightText: 2003 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2006 Dominik Haumann <dhdev@gmx.de>
+    SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
+    SPDX-FileCopyrightText: 2009 Michel Ludwig <michel.ludwig@kdemail.net>
+    SPDX-FileCopyrightText: 2009 Erlend Hamberg <ehamberg@gmail.com>
 
-   Based on work of:
-     Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+    Based on work of:
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 // BEGIN Includes
@@ -37,7 +26,6 @@
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "katemodeconfigpage.h"
-#include "kateschema.h"
 #include "kateview.h"
 #include "spellcheck/spellcheck.h"
 
@@ -53,15 +41,15 @@
 #include "ui_textareaappearanceconfigwidget.h"
 
 #include <KIO/Job>
-#include <KIO/OpenUrlJob>
 #include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 
 #include "kateabstractinputmodefactory.h"
 #include "katepartdebug.h"
 #include <KActionCollection>
 #include <KCharsets>
 #include <KColorCombo>
-#include <KComboBox>
+#include <KFontChooser>
 #include <KLineEdit>
 #include <KMessageBox>
 #include <KProcess>
@@ -71,7 +59,6 @@
 #include <QCheckBox>
 #include <QClipboard>
 #include <QComboBox>
-#include <QDialog>
 #include <QDomDocument>
 #include <QFile>
 #include <QFileDialog>
@@ -87,7 +74,6 @@
 #include <QSpinBox>
 #include <QStringList>
 #include <QTabBar>
-#include <QTabWidget>
 #include <QTemporaryFile>
 #include <QTextCodec>
 #include <QTextStream>
@@ -102,7 +88,7 @@ KateIndentConfigTab::KateIndentConfigTab(QWidget *parent)
 {
     // This will let us have more separation between this page and
     // the QTabWidget edge (ereslibre)
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     QWidget *newWidget = new QWidget(this);
 
     ui = new Ui::IndentationConfigWidget();
@@ -134,7 +120,6 @@ KateIndentConfigTab::KateIndentConfigTab(QWidget *parent)
     observeChanges(ui->sbTabWidth);
 
     layout->addWidget(newWidget);
-    setLayout(layout);
 }
 
 KateIndentConfigTab::~KateIndentConfigTab()
@@ -230,7 +215,7 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
 {
     // This will let us have more separation between this page and
     // the QTabWidget edge (ereslibre)
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     QWidget *newWidget = new QWidget(this);
 
     ui = new Ui::CompletionConfigTab();
@@ -247,7 +232,6 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
     observeChanges(ui->removeTail);
 
     layout->addWidget(newWidget);
-    setLayout(layout);
 }
 
 KateCompletionConfigTab::~KateCompletionConfigTab()
@@ -303,7 +287,7 @@ KateSpellCheckConfigTab::KateSpellCheckConfigTab(QWidget *parent)
 {
     // This will let us have more separation between this page and
     // the QTabWidget edge (ereslibre)
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     QWidget *newWidget = new QWidget(this);
 
     ui = new Ui::SpellCheckConfigWidget();
@@ -318,7 +302,6 @@ KateSpellCheckConfigTab::KateSpellCheckConfigTab(QWidget *parent)
     layout->addWidget(m_sonnetConfigWidget);
 
     layout->addWidget(newWidget);
-    setLayout(layout);
 }
 
 KateSpellCheckConfigTab::~KateSpellCheckConfigTab()
@@ -371,7 +354,7 @@ KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
 {
     // This will let us having more separation between this page and
     // the QTabWidget edge (ereslibre)
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     QWidget *newWidget = new QWidget(this);
 
     ui = new Ui::NavigationConfigWidget();
@@ -389,7 +372,6 @@ KateNavigationConfigTab::KateNavigationConfigTab(QWidget *parent)
     observeChanges(ui->sbAutoCenterCursor);
 
     layout->addWidget(newWidget);
-    setLayout(layout);
 }
 
 KateNavigationConfigTab::~KateNavigationConfigTab()
@@ -443,7 +425,7 @@ QString KateNavigationConfigTab::name() const
 KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     : KateConfigPage(parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     QWidget *newWidget = new QWidget(this);
     ui = new Ui::EditConfigWidget();
     ui->setupUi(newWidget);
@@ -483,7 +465,6 @@ KateEditGeneralConfigTab::KateEditGeneralConfigTab(QWidget *parent)
     observeChanges(ui->sbWordWrap);
 
     layout->addWidget(newWidget);
-    setLayout(layout);
 }
 
 KateEditGeneralConfigTab::~KateEditGeneralConfigTab()
@@ -572,7 +553,7 @@ KateEditConfigTab::KateEditConfigTab(QWidget *parent)
     , completionConfigTab(new KateCompletionConfigTab(this))
     , spellCheckConfigTab(new KateSpellCheckConfigTab(this))
 {
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     QTabWidget *tabWidget = new QTabWidget(this);
 
@@ -602,7 +583,6 @@ KateEditConfigTab::KateEditConfigTab(QWidget *parent)
     }
 
     layout->addWidget(tabWidget);
-    setLayout(layout);
 }
 
 KateEditConfigTab::~KateEditConfigTab()
@@ -687,6 +667,12 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
     layout->addWidget(tabWidget);
     layout->setContentsMargins(0, 0, 0, 0);
 
+    QWidget *fontTab = new QWidget(tabWidget);
+    QGridLayout *grid = new QGridLayout(fontTab);
+    m_fontchooser = new KFontChooser(fontTab, KFontChooser::NoDisplayFlags);
+    grid->addWidget(m_fontchooser, 0, 0);
+    tabWidget->addTab(fontTab, i18n("Font"));
+
     QWidget *textareaTab = new QWidget(tabWidget);
     textareaUi->setupUi(textareaTab);
     tabWidget->addTab(textareaTab, i18n("General"));
@@ -703,10 +689,13 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
 
     reload();
 
+    observeChanges(m_fontchooser);
+
     observeChanges(textareaUi->chkAnimateBracketMatching);
     observeChanges(textareaUi->chkDynWrapAnywhere);
     observeChanges(textareaUi->chkDynWrapAtStaticMarker);
     observeChanges(textareaUi->chkFoldFirstLine);
+    observeChanges(textareaUi->chkShowBracketMatchPreview);
     observeChanges(textareaUi->chkShowIndentationLines);
     observeChanges(textareaUi->chkShowLineCount);
     observeChanges(textareaUi->chkShowTabs);
@@ -755,6 +744,7 @@ void KateViewDefaultsConfig::apply()
     KateDocumentConfig::global()->setShowSpaces(KateDocumentConfig::WhitespaceRendering(textareaUi->spacesComboBox->currentIndex()));
     KateDocumentConfig::global()->setShowTabs(textareaUi->chkShowTabs->isChecked());
 
+    KateRendererConfig::global()->setFont(m_fontchooser->font());
     KateRendererConfig::global()->setAnimateBracketMatching(textareaUi->chkAnimateBracketMatching->isChecked());
     KateRendererConfig::global()->setShowIndentationLines(textareaUi->chkShowIndentationLines->isChecked());
     KateRendererConfig::global()->setShowWholeBracketExpression(textareaUi->chkShowWholeBracketExpression->isChecked());
@@ -768,6 +758,7 @@ void KateViewDefaultsConfig::apply()
     KateViewConfig::global()->setValue(KateViewConfig::DynWrapAtStaticMarker, textareaUi->chkDynWrapAtStaticMarker->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::FoldFirstLine, textareaUi->chkFoldFirstLine->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ScrollBarMiniMapWidth, bordersUi->spBoxMiniMapWidth->value());
+    KateViewConfig::global()->setValue(KateViewConfig::ShowBracketMatchPreview, textareaUi->chkShowBracketMatchPreview->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ShowFoldingBar, bordersUi->chkShowFoldingMarkers->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ShowFoldingPreview, bordersUi->chkShowFoldingPreview->isChecked());
     KateViewConfig::global()->setValue(KateViewConfig::ShowIconBar, bordersUi->chkIconBorder->isChecked());
@@ -800,10 +791,13 @@ void KateViewDefaultsConfig::reload()
     bordersUi->rbSortBookmarksByPosition->setChecked(KateViewConfig::global()->bookmarkSort() == 0);
     bordersUi->spBoxMiniMapWidth->setValue(KateViewConfig::global()->scrollBarMiniMapWidth());
 
+    m_fontchooser->setFont(KateRendererConfig::global()->baseFont());
+
     textareaUi->chkAnimateBracketMatching->setChecked(KateRendererConfig::global()->animateBracketMatching());
     textareaUi->chkDynWrapAnywhere->setChecked(KateViewConfig::global()->dynWrapAnywhere());
     textareaUi->chkDynWrapAtStaticMarker->setChecked(KateViewConfig::global()->dynWrapAtStaticMarker());
     textareaUi->chkFoldFirstLine->setChecked(KateViewConfig::global()->foldFirstLine());
+    textareaUi->chkShowBracketMatchPreview->setChecked(KateViewConfig::global()->value(KateViewConfig::ShowBracketMatchPreview).toBool());
     textareaUi->chkShowIndentationLines->setChecked(KateRendererConfig::global()->showIndentationLines());
     textareaUi->chkShowLineCount->setChecked(KateViewConfig::global()->showLineCount());
     textareaUi->chkShowTabs->setChecked(KateDocumentConfig::global()->showTabs());
@@ -818,12 +812,10 @@ void KateViewDefaultsConfig::reload()
 
 void KateViewDefaultsConfig::reset()
 {
-    ;
 }
 
 void KateViewDefaultsConfig::defaults()
 {
-    ;
 }
 
 QString KateViewDefaultsConfig::name() const
@@ -851,18 +843,18 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     // FIXME: Is really needed to move all this code below to another class,
     // since it is another tab itself on the config dialog. This means we should
     // initialize, add and work with as we do with modeConfigPage (ereslibre)
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     QTabWidget *tabWidget = new QTabWidget(this);
 
     QWidget *tmpWidget = new QWidget(tabWidget);
-    QVBoxLayout *internalLayout = new QVBoxLayout;
+    QVBoxLayout *internalLayout = new QVBoxLayout(tmpWidget);
     QWidget *newWidget = new QWidget(tabWidget);
     ui = new Ui::OpenSaveConfigWidget();
     ui->setupUi(newWidget);
 
     QWidget *tmpWidget2 = new QWidget(tabWidget);
-    QVBoxLayout *internalLayout2 = new QVBoxLayout;
+    QVBoxLayout *internalLayout2 = new QVBoxLayout(tmpWidget2);
     QWidget *newWidget2 = new QWidget(tabWidget);
     uiadv = new Ui::OpenSaveConfigAdvWidget();
     uiadv->setupUi(newWidget2);
@@ -886,16 +878,13 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(uiadv->cmbSwapFileMode);
     connect(uiadv->cmbSwapFileMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KateSaveConfigTab::swapFileModeChanged);
 
-
     observeChanges(uiadv->edtBackupPrefix);
     observeChanges(uiadv->edtBackupSuffix);
     observeChanges(uiadv->kurlSwapDirectory);
     observeChanges(uiadv->spbSwapFileSync);
 
     internalLayout->addWidget(newWidget);
-    tmpWidget->setLayout(internalLayout);
     internalLayout2->addWidget(newWidget2);
-    tmpWidget2->setLayout(internalLayout2);
 
     // add all tabs
     tabWidget->insertTab(0, tmpWidget, i18n("General"));
@@ -905,7 +894,6 @@ KateSaveConfigTab::KateSaveConfigTab(QWidget *parent)
     observeChanges(modeConfigPage);
 
     layout->addWidget(tabWidget);
-    setLayout(layout);
 
     // support variable expansion in backup prefix/suffix
     KTextEditor::Editor::instance()->addVariableExpansion({uiadv->edtBackupPrefix, uiadv->edtBackupSuffix},
