@@ -1,35 +1,22 @@
-/* This file is part of the KDE libraries
-   Copyright (c) 2000 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2002-2004 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2007 Mirko Stocker <me@misto.ch>
+/*
+    SPDX-FileCopyrightText: 2000 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2002-2004 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katebuffer.h"
-#include "katedocument.h"
-#include "katehighlight.h"
-#include "kateconfig.h"
-#include "kateglobal.h"
 #include "kateautoindent.h"
+#include "kateconfig.h"
+#include "katedocument.h"
+#include "kateglobal.h"
+#include "katehighlight.h"
 #include "katepartdebug.h"
 
-#include <KLocalizedString>
 #include <KCharsets>
 #include <KFilterDev>
+#include <KLocalizedString>
 
 #include <QDate>
 #include <QFile>
@@ -47,15 +34,15 @@ static const int KATE_MAX_DYNAMIC_CONTEXTS = 512;
  * Create an empty buffer. (with one block with one empty line)
  */
 KateBuffer::KateBuffer(KTextEditor::DocumentPrivate *doc)
-    : Kate::TextBuffer(doc),
-      m_doc(doc),
-      m_brokenEncoding(false),
-      m_tooLongLinesWrapped(false),
-      m_longestLineLoaded(0),
-      m_highlight(nullptr),
-      m_tabWidth(8),
-      m_lineHighlighted(0),
-      m_maxDynamicContexts(KATE_MAX_DYNAMIC_CONTEXTS)
+    : Kate::TextBuffer(doc)
+    , m_doc(doc)
+    , m_brokenEncoding(false)
+    , m_tooLongLinesWrapped(false)
+    , m_longestLineLoaded(0)
+    , m_highlight(nullptr)
+    , m_tabWidth(8)
+    , m_lineHighlighted(0)
+    , m_maxDynamicContexts(KATE_MAX_DYNAMIC_CONTEXTS)
 {
 }
 
@@ -75,62 +62,48 @@ void KateBuffer::editStart()
 
 void KateBuffer::editEnd()
 {
-    /**
-     * not finished, do nothing
-     */
+    // not finished, do nothing
     if (!finishEditing()) {
         return;
     }
 
-    /**
-     * nothing change, OK
-     */
+    // nothing change, OK
     if (!editingChangedBuffer()) {
         return;
     }
 
-    /**
-     * if we arrive here, line changed should be OK
-     */
+    // if we arrive here, line changed should be OK
     Q_ASSERT(editingMinimalLineChanged() != -1);
     Q_ASSERT(editingMaximalLineChanged() != -1);
     Q_ASSERT(editingMinimalLineChanged() <= editingMaximalLineChanged());
 
-    /**
-     * no highlighting, nothing to do
-     */
+    updateHighlighting();
+}
+
+void KateBuffer::updateHighlighting()
+{
+    // no highlighting, nothing to do
     if (!m_highlight) {
         return;
     }
 
-    /**
-     * if we don't touch the highlighted area => fine
-     */
+    // if we don't touch the highlighted area => fine
     if (editingMinimalLineChanged() > m_lineHighlighted) {
         return;
     }
 
-    /**
-     * look one line too far, needed for linecontinue stuff
-     */
+    // look one line too far, needed for linecontinue stuff
     const int editTagLineEnd = editingMaximalLineChanged() + 1;
 
-    /**
-     * for indentation sensitive folding, we need to redo things
-     * one line up, to e.g. get notified about new folding starts
-     * see bug 351496
-     */
+    // for indentation sensitive folding, we need to redo things
+    // one line up, to e.g. get notified about new folding starts
+    // see bug 351496
     int editTagLineStart = editingMinimalLineChanged();
     if ((editTagLineStart > 0) && m_highlight->foldingIndentationSensitive())
         --editTagLineStart;
 
-    /**
-     * really update highlighting
-     */
-    doHighlight(
-        editTagLineStart,
-        editTagLineEnd,
-        true);
+    // really update highlighting
+    doHighlight(editTagLineStart, editTagLineEnd, true);
 }
 
 void KateBuffer::clear()
@@ -155,7 +128,7 @@ bool KateBuffer::openFile(const QString &m_file, bool enforceTextCodec)
     setTextCodec(m_doc->config()->codec());
 
     // setup eol
-    setEndOfLineMode((EndOfLineMode) m_doc->config()->eol());
+    setEndOfLineMode((EndOfLineMode)m_doc->config()->eol());
 
     // NOTE: we do not remove trailing spaces on load. This was discussed
     //       over the years again and again. bugs: 306926, 239077, ...
@@ -168,16 +141,13 @@ bool KateBuffer::openFile(const QString &m_file, bool enforceTextCodec)
     m_tooLongLinesWrapped = false;
     m_longestLineLoaded = 0;
 
-    /**
-     * allow non-existent files without error, if local file!
-     * will allow to do "kate newfile.txt" without error messages but still fail if e.g. you mistype a url
-     * and it can't be fetched via fish:// or other strange things in kio happen...
-     * just clear() + exit with success!
-     */
+    // allow non-existent files without error, if local file!
+    // will allow to do "kate newfile.txt" without error messages but still fail if e.g. you mistype a url
+    // and it can't be fetched via fish:// or other strange things in kio happen...
+    // just clear() + exit with success!
     if (m_doc->url().isLocalFile() && !QFile::exists(m_file)) {
         clear();
-        KTextEditor::Message *message = new KTextEditor::Message(i18nc("short translation, user created new file", "New file"),
-                KTextEditor::Message::Warning);
+        KTextEditor::Message *message = new KTextEditor::Message(i18nc("short translation, user created new file", "New file"), KTextEditor::Message::Warning);
         message->setPosition(KTextEditor::Message::TopInView);
         message->setAutoHide(1000);
         m_doc->postMessage(message);
@@ -188,19 +158,15 @@ bool KateBuffer::openFile(const QString &m_file, bool enforceTextCodec)
         return true;
     }
 
-    /**
-     * check if this is a normal file or not, avoids to open char devices or directories!
-     * else clear buffer and break out with error
-     */
+    // check if this is a normal file or not, avoids to open char devices or directories!
+    // else clear buffer and break out with error
     if (!QFileInfo(m_file).isFile()) {
         clear();
         return false;
     }
 
-    /**
-     * try to load
-     */
-    if (!load(m_file, m_brokenEncoding, m_tooLongLinesWrapped, m_longestLineLoaded,  enforceTextCodec)) {
+    // try to load
+    if (!load(m_file, m_brokenEncoding, m_tooLongLinesWrapped, m_longestLineLoaded, enforceTextCodec)) {
         return false;
     }
 
@@ -251,7 +217,7 @@ bool KateBuffer::saveFile(const QString &m_file)
     setTextCodec(m_doc->config()->codec());
 
     // setup eol
-    setEndOfLineMode((EndOfLineMode) m_doc->config()->eol());
+    setEndOfLineMode((EndOfLineMode)m_doc->config()->eol());
 
     // generate bom?
     setGenerateByteOrderMark(m_doc->config()->bom());
@@ -335,8 +301,6 @@ void KateBuffer::setHighlight(int hlMode)
             invalidate = true;
         }
 
-        h->use();
-
         m_highlight = h;
 
         if (invalidate) {
@@ -371,41 +335,8 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
     t.start();
     qCDebug(LOG_KTE) << "HIGHLIGHTED START --- NEED HL, LINESTART: " << startLine << " LINEEND: " << endLine;
     qCDebug(LOG_KTE) << "HL UNTIL LINE: " << m_lineHighlighted;
-    qCDebug(LOG_KTE) << "HL DYN COUNT: " << KateHlManager::self()->countDynamicCtxs() << " MAX: " << m_maxDynamicContexts;
 #endif
 
-    // see if there are too many dynamic contexts; if yes, invalidate HL of all documents
-    if (KateHlManager::self()->countDynamicCtxs() >= m_maxDynamicContexts) {
-        {
-            if (KateHlManager::self()->resetDynamicCtxs()) {
-#ifdef BUFFER_DEBUGGING
-                qCDebug(LOG_KTE) << "HL invalidated - too many dynamic contexts ( >= " << m_maxDynamicContexts << ")";
-#endif
-
-                // avoid recursive invalidation
-                KateHlManager::self()->setForceNoDCReset(true);
-
-                foreach (KTextEditor::DocumentPrivate *doc, KTextEditor::EditorPrivate::self()->kateDocuments()) {
-                    doc->makeAttribs();
-                }
-
-                // doHighlight *shall* do his work. After invalidation, some highlight has
-                // been recalculated, but *maybe not* until endLine ! So we shall force it manually...
-                doHighlight(m_lineHighlighted, endLine, false);
-                m_lineHighlighted = endLine;
-
-                KateHlManager::self()->setForceNoDCReset(false);
-                return;
-            } else {
-                m_maxDynamicContexts *= 2;
-
-#ifdef BUFFER_DEBUGGING
-                qCDebug(LOG_KTE) << "New dynamic contexts limit: " << m_maxDynamicContexts;
-#endif
-            }
-        }
-    }
-
     // if possible get previous line, otherwise create 0 line.
     Kate::TextLine prevLine = (startLine >= 1) ? plainLine(startLine - 1) : Kate::TextLine();
 
@@ -442,7 +373,7 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
 #endif
 
         // need we to continue ?
-        bool stillcontinue =  ctxChanged;
+        bool stillcontinue = ctxChanged;
         if (stillcontinue && start_spellchecking < 0) {
             start_spellchecking = current_line;
         } else if (!stillcontinue && start_spellchecking >= 0) {
@@ -454,9 +385,7 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
         textLine = nextLine;
     }
 
-    /**
-     * perhaps we need to adjust the maximal highlighed line
-     */
+    // perhaps we need to adjust the maximal highlighted line
     int oldHighlighted = m_lineHighlighted;
     if (ctxChanged || current_line > m_lineHighlighted) {
         m_lineHighlighted = current_line;
@@ -465,14 +394,13 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
     // tag the changed lines !
     if (invalidate) {
 #ifdef BUFFER_DEBUGGING
-        qCDebug(LOG_KTE) << "HIGHLIGHTED TAG LINES: " << startLine <<  current_line;
+        qCDebug(LOG_KTE) << "HIGHLIGHTED TAG LINES: " << startLine << current_line;
 #endif
 
         emit tagLines(startLine, qMax(current_line, oldHighlighted));
 
         if (start_spellchecking >= 0 && lines() > 0) {
-            emit respellCheckBlock(start_spellchecking,
-                                   qMin(lines() - 1, (last_line_spellchecking == -1) ? qMax(current_line, oldHighlighted) : last_line_spellchecking));
+            emit respellCheckBlock(start_spellchecking, qMin(lines() - 1, (last_line_spellchecking == -1) ? qMax(current_line, oldHighlighted) : last_line_spellchecking));
         }
     }
 
@@ -486,79 +414,54 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
 
 KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
 {
-    /**
-     * ensure valid input
-     */
-    Q_ASSERT(startLine >= 0);
-    Q_ASSERT(startLine < lines());
+    // ensure valid input
+    if (startLine < 0 || startLine >= lines()) {
+        return KTextEditor::Range::invalid();
+    }
 
-    /**
-     * no highlighting, no folding, ATM
-     */
+    // no highlighting, no folding, ATM
     if (!m_highlight || m_highlight->noHighlighting()) {
         return KTextEditor::Range::invalid();
     }
 
-    /**
-     * first: get the wanted start line highlighted
-     */
+    // first: get the wanted start line highlighted
     ensureHighlighted(startLine);
     Kate::TextLine startTextLine = plainLine(startLine);
 
-    /**
-     * return if no folding start!
-     */
+    // return if no folding start!
     if (!startTextLine->markedAsFoldingStart()) {
         return KTextEditor::Range::invalid();
     }
 
-    /**
-     * now: decided if indentation based folding or not!
-     */
+    // now: decided if indentation based folding or not!
     if (startTextLine->markedAsFoldingStartIndentation()) {
-        /**
-         * get our start indentation level
-         */
+        // get our start indentation level
         const int startIndentation = startTextLine->indentDepth(tabWidth());
 
-        /**
-         * search next line with indentation level <= our one
-         */
+        // search next line with indentation level <= our one
         int lastLine = startLine + 1;
         for (; lastLine < lines(); ++lastLine) {
-            /**
-             * get line
-             */
+            // get line
             Kate::TextLine textLine = plainLine(lastLine);
 
-            /**
-             * indentation higher than our start line? continue
-             */
+            // indentation higher than our start line? continue
             if (startIndentation < textLine->indentDepth(tabWidth())) {
                 continue;
             }
 
-            /**
-             * empty line? continue
-             */
+            // empty line? continue
             if (m_highlight->isEmptyLine(textLine.data())) {
                 continue;
             }
 
-            /**
-             * else, break
-             */
+            // else, break
             break;
         }
 
-        /**
-         * lastLine is always one too much
-         */
+        // lastLine is always one too much
         --lastLine;
 
-        /**
-         * backtrack all empty lines, we don't want to add them to the fold!
-         */
+        // backtrack all empty lines, we don't want to add them to the fold!
         while (lastLine > startLine) {
             if (m_highlight->isEmptyLine(plainLine(lastLine).data())) {
                 --lastLine;
@@ -567,47 +470,31 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
             }
         }
 
-        /**
-         * we shall not fold one-liners
-         */
+        // we shall not fold one-liners
         if (lastLine == startLine) {
             return KTextEditor::Range::invalid();
         }
 
-        /**
-         * be done now
-         */
+        // be done now
         return KTextEditor::Range(KTextEditor::Cursor(startLine, 0), KTextEditor::Cursor(lastLine, plainLine(lastLine)->length()));
     }
 
-    /**
-     * 'normal' attribute based folding, aka token based like '{' BLUB '}'
-     */
+    // 'normal' attribute based folding, aka token based like '{' BLUB '}'
 
-    /**
-     * first step: search the first region type, that stays open for the start line
-     */
+    // first step: search the first region type, that stays open for the start line
     short openedRegionType = 0;
     int openedRegionOffset = -1;
     {
-        /**
-         * mapping of type to "first" offset of it and current number of not matched openings
-         */
-        QHash<short, QPair<int, int> > foldingStartToOffsetAndCount;
+        // mapping of type to "first" offset of it and current number of not matched openings
+        QHash<short, QPair<int, int>> foldingStartToOffsetAndCount;
 
-        /**
-         * walk over all attributes of the line and compute the matchings
-         */
-        const QVector<Kate::TextLineData::Attribute> &startLineAttributes = startTextLine->attributesList();
-        for (int i = 0; i < startLineAttributes.size(); ++i) {
-            /**
-             * folding close?
-             */
+        // walk over all attributes of the line and compute the matchings
+        const auto &startLineAttributes = startTextLine->foldings();
+        for (size_t i = 0; i < startLineAttributes.size(); ++i) {
+            // folding close?
             if (startLineAttributes[i].foldingValue < 0) {
-                /**
-                 * search for this type, try to decrement counter, perhaps erase element!
-                 */
-                QHash<short, QPair<int, int> >::iterator end = foldingStartToOffsetAndCount.find(-startLineAttributes[i].foldingValue);
+                // search for this type, try to decrement counter, perhaps erase element!
+                QHash<short, QPair<int, int>>::iterator end = foldingStartToOffsetAndCount.find(-startLineAttributes[i].foldingValue);
                 if (end != foldingStartToOffsetAndCount.end()) {
                     if (end.value().second > 1) {
                         --(end.value().second);
@@ -617,14 +504,10 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
                 }
             }
 
-            /**
-             * folding open?
-             */
+            // folding open?
             if (startLineAttributes[i].foldingValue > 0) {
-                /**
-                 * search for this type, either insert it, with current offset or increment counter!
-                 */
-                QHash<short, QPair<int, int> >::iterator start = foldingStartToOffsetAndCount.find(startLineAttributes[i].foldingValue);
+                // search for this type, either insert it, with current offset or increment counter!
+                QHash<short, QPair<int, int>>::iterator start = foldingStartToOffsetAndCount.find(startLineAttributes[i].foldingValue);
                 if (start != foldingStartToOffsetAndCount.end()) {
                     ++(start.value().second);
                 } else {
@@ -633,10 +516,8 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
             }
         }
 
-        /**
-         * compute first type with offset
-         */
-        QHashIterator<short, QPair<int, int> > hashIt(foldingStartToOffsetAndCount);
+        // compute first type with offset
+        QHashIterator<short, QPair<int, int>> hashIt(foldingStartToOffsetAndCount);
         while (hashIt.hasNext()) {
             hashIt.next();
             if (openedRegionOffset == -1 || hashIt.value().first < openedRegionOffset) {
@@ -646,69 +527,45 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
         }
     }
 
-    /**
-     * no opening region found, bad, nothing to do
-     */
+    // no opening region found, bad, nothing to do
     if (openedRegionType == 0) {
         return KTextEditor::Range::invalid();
     }
 
-    /**
-     * second step: search for matching end region marker!
-     */
+    // second step: search for matching end region marker!
     int countOfOpenRegions = 1;
     for (int line = startLine + 1; line < lines(); ++line) {
-        /**
-         * ensure line is highlighted
-         */
+        // ensure line is highlighted
         ensureHighlighted(line);
         Kate::TextLine textLine = plainLine(line);
 
-        /**
-         * search for matching end marker
-         */
-        const QVector<Kate::TextLineData::Attribute> &lineAttributes = textLine->attributesList();
-        for (int i = 0; i < lineAttributes.size(); ++i) {
-            /**
-             * matching folding close?
-             */
+        // search for matching end marker
+        const auto &lineAttributes = textLine->foldings();
+        for (size_t i = 0; i < lineAttributes.size(); ++i) {
+            // matching folding close?
             if (lineAttributes[i].foldingValue == -openedRegionType) {
                 --countOfOpenRegions;
 
-                /**
-                 * end reached?
-                 * compute resulting range!
-                 */
+                // end reached?
+                // compute resulting range!
                 if (countOfOpenRegions == 0) {
-                    /**
-                     * special handling of end: if end is at column 0 of a line, move it to end of previous line!
-                     * fixes folding for stuff like
-                     * #pragma mark END_OLD_AND_START_NEW_REGION
-                     */
-                    KTextEditor::Cursor endCursor(line, lineAttributes[i].offset);
-                    if (endCursor.column() == 0 && endCursor.line() > 0) {
-                        endCursor = KTextEditor::Cursor(endCursor.line() - 1, plainLine(lines() - 1)->length());
+                    // Don't return a valid range without content!
+                    if (line - startLine == 1) {
+                        return KTextEditor::Range::invalid();
                     }
 
-                    /**
-                     * return computed range
-                     */
-                    return KTextEditor::Range(KTextEditor::Cursor(startLine, openedRegionOffset), endCursor);
+                    // return computed range
+                    return KTextEditor::Range(KTextEditor::Cursor(startLine, openedRegionOffset), KTextEditor::Cursor(line, lineAttributes[i].offset));
                 }
             }
 
-            /**
-             * matching folding open?
-             */
+            // matching folding open?
             if (lineAttributes[i].foldingValue == openedRegionType) {
                 ++countOfOpenRegions;
             }
         }
     }
 
-    /**
-     * if we arrive here, the opened range spans to the end of the document!
-     */
+    // if we arrive here, the opened range spans to the end of the document!
     return KTextEditor::Range(KTextEditor::Cursor(startLine, openedRegionOffset), KTextEditor::Cursor(lines() - 1, plainLine(lines() - 1)->length()));
 }
-
