@@ -1,24 +1,10 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2001-2004 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
 
-    Copyright (C) 2001-2004 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-    Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
-    Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef _KATE_DOCUMENT_H_
@@ -622,6 +608,8 @@ public:
      * If the Document does not have a variable called @p name,
      * an empty QString() is returned.
      *
+     * // TODO KF6: expose in KTextEditor::Document?
+     *
      * @param name variable to query
      * @return value of the variable @p name
      * @see setVariable()
@@ -634,6 +622,8 @@ public:
      * @e indent-mode to @e cstyle will immediately cause the Document to load
      * the C Style indenter.
      *
+     * // TODO KF6: expose in KTextEditor::Document?
+     *
      * @param name the variable name
      * @param value the value to be set
      * @see variable()
@@ -1241,8 +1231,6 @@ public:
 public:
     QStringList embeddedHighlightingModes() const override;
     QString highlightingModeAt(const KTextEditor::Cursor &position) override;
-    // TODO KDE5: move to View
-    virtual KTextEditor::Attribute::Ptr attributeAt(const KTextEditor::Cursor &position);
 
     //
     // BEGIN: KTextEditor::MessageInterface
