@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2001-2014 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2005-2014 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2001-2014 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2005-2014 Dominik Haumann (dhaumann@kde.org)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTEXTEDITOR_DOCUMENT_H
@@ -64,11 +50,11 @@ enum SearchOption {
 
     // options for all modes
     CaseInsensitive = 1 << 4, ///< Ignores cases, e.g. "a" matches "A"
-    Backwards = 1 << 5,       ///< Searches in backward direction
+    Backwards = 1 << 5, ///< Searches in backward direction
 
     // options for plaintext
     EscapeSequences = 1 << 10, ///< Plaintext mode: Processes escape sequences
-    WholeWords = 1 << 11,      ///< Plaintext mode: Whole words only, e.g. @em not &quot;amp&quot; in &quot;example&quot;
+    WholeWords = 1 << 11, ///< Plaintext mode: Whole words only, e.g. @em not &quot;amp&quot; in &quot;example&quot;
 
     MaxSearchOption = 1 << 31 ///< Placeholder for binary compatibility
 };
@@ -78,6 +64,8 @@ Q_DECLARE_FLAGS(SearchOptions, SearchOption)
 Q_DECLARE_OPERATORS_FOR_FLAGS(SearchOptions)
 
 /**
+ * \class Document document.h <KTextEditor/Document>
+ *
  * \brief A KParts derived class representing a text document.
  *
  * Topics:
