@@ -1,21 +1,7 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2019-2020 Nibaldo González S. <nibgonz@gmail.com>
 
-    Copyright (C) 2019 Nibaldo González S. <nibgonz@gmail.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // BEGIN Includes
@@ -50,16 +36,14 @@ static bool isDelimiter(const ushort c)
 
 /**
  * Overlay scroll bar on the list according to the operating system
- * and/or the desktop environment. In old desktop themes the scroll bar
+ * and/or the desktop environment. In some desktop themes the scroll bar
  * isn't transparent, so it's better not to overlap it on the list.
+ * NOTE: Currently, in the Breeze theme, the scroll bar does not overlap
+ * the content. See: https://phabricator.kde.org/T9126
  */
-static bool overlapScrollBar()
+inline static bool overlapScrollBar()
 {
-#if defined(Q_OS_WIN64) || defined(Q_OS_WIN32)
     return false;
-#else
-    return true;
-#endif
 }
 }
 
@@ -87,7 +71,7 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
      * Calculate the size of the list and the checkbox icon (in pixels) according
      * to the font size. From font 12pt to 26pt increase the list size.
      */
-    int menuWidth = 260;
+    int menuWidth = 266;
     int menuHeight = 428;
     const int fontSize = font.pointSize();
     if (fontSize >= 12) {
@@ -139,6 +123,8 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
     setSizeList(menuHeight, menuWidth);
 
     // Data model (items).
+    // couple model to view to let it be deleted with the view
+    m_model = new QStandardItemModel(0, 0, m_list);
     loadHighlightingModel();
 
     /*
@@ -172,7 +158,7 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
     if (overlapScrollBar()) {
         QHBoxLayout *layoutScrollBar = new QHBoxLayout();
         layoutScrollBar->addWidget(m_scroll);
-        layoutScrollBar->setContentsMargins(1, m_scrollbarMargin, m_scrollbarMargin, m_scrollbarMargin);
+        layoutScrollBar->setContentsMargins(1, 2, 2, 2); // ScrollBar Margin = 2, Also see: KateModeMenuListData::ListView::getContentWidth()
         m_layoutList->addLayout(layoutScrollBar, 0, 0, Qt::AlignRight);
     }
 
@@ -185,22 +171,6 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
         layoutContainer->addLayout(layoutSearchBar);
     }
 
-    // In the Windows OS, decrease menu margins.
-#ifdef Q_OS_WIN
-    layoutContainer->setContentsMargins(3, 3, 2, 3);
-    layoutContainer->setSpacing(0);
-    if (searchBarPos == Bottom) {
-        layoutSearchBar->setContentsMargins(2, 5, 2, 2);
-    } else if (searchBarPos == Top) {
-        layoutSearchBar->setContentsMargins(2, 2, 2, 5);
-    }
-    layoutSearchBar->setSpacing(0);
-    m_layoutList->setContentsMargins(2, 2, 2, 2);
-    m_layoutList->setSpacing(0);
-#endif
-
-    container->setLayout(layoutContainer);
-
     QWidgetAction *widAct = new QWidgetAction(this);
     widAct->setDefaultWidget(container);
     addAction(widAct);
@@ -212,10 +182,36 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
     connect(m_list, &KateModeMenuListData::ListView::clicked, this, &KateModeMenuList::selectHighlighting);
 }
 
+void KateModeMenuList::reloadItems()
+{
+    const QString searchText = m_searchBar->text().trimmed();
+    m_searchBar->m_bestResults.clear();
+    if (!isHidden()) {
+        hide();
+    }
+    /*
+     * Clear model.
+     * NOTE: This deletes the item objects and widgets indexed to items.
+     * That is, the QLabel & QFrame objects of the section titles are also deleted.
+     * See: QAbstractItemView::setIndexWidget(), QObject::deleteLater()
+     */
+    m_model->clear();
+    m_list->selectionModel()->clear();
+    m_selectedItem = nullptr;
+
+    loadHighlightingModel();
+
+    // Restore search text, if there is.
+    m_searchBar->m_bSearchStateAutoScroll = false;
+    if (!searchText.isEmpty()) {
+        selectHighlightingFromExternal();
+        m_searchBar->updateSearch(searchText);
+        m_searchBar->setText(searchText);
+    }
+}
+
 void KateModeMenuList::loadHighlightingModel()
 {
-    // couple model to view to let it be deleted with the view
-    m_model = new QStandardItemModel(0, 0, m_list);
     m_list->setModel(m_model);
 
     QString *prevHlSection = nullptr;
@@ -224,7 +220,7 @@ void KateModeMenuList::loadHighlightingModel()
      * a custom word wrap and prevent the item's text from passing under the scroll bar.
      * NOTE: 8 = Icon margin
      */
-    const int maxWidthText = m_list->getContentWidth(1, 4) - m_iconSize - 8;
+    const int maxWidthText = m_list->getContentWidth(1, 8) - m_iconSize - 8;
 
     // Transparent color used as background in the sections.
     QPixmap transparentPixmap = QPixmap(m_iconSize / 2, m_iconSize / 2);
@@ -245,6 +241,10 @@ void KateModeMenuList::loadHighlightingModel()
      * and the attribute "translatedSection" isn't empty if "section" has a value.
      */
     for (auto *hl : KTextEditor::EditorPrivate::self()->modeManager()->list()) {
+        if (hl->name.isEmpty()) {
+            continue;
+        }
+
         // Detects a new section.
         if (!hl->translatedSection.isEmpty() && (prevHlSection == nullptr || hl->translatedSection != *prevHlSection)) {
             createSectionList(hl->sectionTranslated(), transparentBrush);
@@ -253,9 +253,16 @@ void KateModeMenuList::loadHighlightingModel()
 
         // Create item in the list with the language name.
         KateModeMenuListData::ListItem *item = KateModeMenuListData::Factory::createListItem();
+        /*
+         * NOTE:
+         *  - (If the scroll bar is not overlapped) In QListView::setWordWrap(),
+         *    when the scroll bar is hidden, the word wrap changes, but the size
+         *    of the items is keeped, causing display problems in some items.
+         *    KateModeMenuList::setWordWrap() applies a fixed word wrap.
+         *  - Search names generated in: KateModeMenuListData::SearchLine::updateSearch()
+         */
         item->setText(setWordWrap(hl->nameTranslated(), maxWidthText, m_list->fontMetrics()));
         item->setMode(hl);
-        // NOTE: Search names generated in: KateModeMenuListData::SearchLine::updateSearch()
 
         item->setIcon(m_emptyIcon);
         item->setEditable(false);
@@ -282,11 +289,6 @@ KateModeMenuListData::ListItem *KateModeMenuList::createSectionList(const QStrin
         QFrame *line = new QFrame(m_list);
         line->setFrameStyle(QFrame::HLine);
 
-        // In the Windows OS, decrease opacity of the section separator line.
-#ifdef Q_OS_WIN
-        line->setStyleSheet(QStringLiteral("color: rgb(188, 190, 191);"));
-#endif
-
         if (modelPosition < 0) {
             m_model->appendRow(separator);
         } else {
@@ -331,7 +333,7 @@ KateModeMenuListData::ListItem *KateModeMenuList::createSectionList(const QStrin
     m_list->selectionModel()->select(section->index(), QItemSelectionModel::Deselect);
 
     // Apply word wrap in sections, for long labels.
-    const int containerTextWidth = m_list->getContentWidth(1, 2);
+    const int containerTextWidth = m_list->getContentWidth(2, 4);
     int heightSectionMargin = m_list->visualRect(m_model->index(section->row(), 0)).height() - label->sizeHint().height();
 
     if (label->sizeHint().width() > containerTextWidth) {
@@ -374,12 +376,11 @@ void KateModeMenuList::setSizeList(const int height, const int width)
 
 void KateModeMenuList::autoScroll()
 {
-    if (m_autoScroll == ScrollToSelectedItem) {
+    if (m_selectedItem && m_autoScroll == ScrollToSelectedItem) {
         m_list->setCurrentItem(m_selectedItem->row());
         m_list->scrollToItem(m_selectedItem->row(), QAbstractItemView::PositionAtCenter);
     } else {
-        m_list->setCurrentItem(0);
-        m_list->scrollToTop();
+        m_list->scrollToFirstItem();
     }
 }
 
@@ -433,7 +434,7 @@ void KateModeMenuList::showEvent(QShowEvent *event)
 
     // Select text from the search bar
     if (!m_searchBar->text().isEmpty()) {
-        if (m_searchBar->text().simplified().isEmpty()) {
+        if (m_searchBar->text().trimmed().isEmpty()) {
             m_searchBar->clear();
         } else {
             m_searchBar->selectAll();
@@ -450,7 +451,16 @@ void KateModeMenuList::showEvent(QShowEvent *event)
 
     // First show or if an external changed the current syntax highlighting.
     if (!m_selectedItem || (m_selectedItem->hasMode() && m_selectedItem->getMode()->name != doc->fileType())) {
-        selectHighlightingFromExternal(doc->fileType());
+        if (!selectHighlightingFromExternal(doc->fileType())) {
+            // Strange case: if the current syntax highlighting does not exist in the list.
+            if (m_selectedItem) {
+                m_selectedItem->setIcon(m_emptyIcon);
+            }
+            if ((m_selectedItem || !m_list->currentItem()) && m_searchBar->text().isEmpty()) {
+                m_list->scrollToFirstItem();
+            }
+            m_selectedItem = nullptr;
+        }
     }
 }
 
@@ -474,7 +484,7 @@ void KateModeMenuList::updateSelectedItem(KateModeMenuListData::ListItem *item)
 
 void KateModeMenuList::selectHighlightingSetVisibility(QStandardItem *pItem, const bool bHideMenu)
 {
-    if (!pItem->isSelectable() || !pItem->isEnabled()) {
+    if (!pItem || !pItem->isSelectable() || !pItem->isEnabled()) {
         return;
     }
 
@@ -499,7 +509,7 @@ void KateModeMenuList::selectHighlighting(const QModelIndex &index)
     selectHighlightingSetVisibility(m_model->item(index.row(), 0), true);
 }
 
-void KateModeMenuList::selectHighlightingFromExternal(const QString &nameMode)
+bool KateModeMenuList::selectHighlightingFromExternal(const QString &nameMode)
 {
     for (int i = 0; i < m_model->rowCount(); ++i) {
         KateModeMenuListData::ListItem *item = static_cast<KateModeMenuListData::ListItem *>(m_model->item(i, 0));
@@ -523,20 +533,21 @@ void KateModeMenuList::selectHighlightingFromExternal(const QString &nameMode)
                 m_list->scrollToItem(i);
             } else {
                 // autoScroll()
-                m_list->setCurrentItem(0);
-                m_list->scrollToTop();
+                m_list->scrollToFirstItem();
             }
-            return;
+            return true;
         }
     }
+    return false;
 }
 
-void KateModeMenuList::selectHighlightingFromExternal()
+bool KateModeMenuList::selectHighlightingFromExternal()
 {
     KTextEditor::DocumentPrivate *doc = m_doc;
     if (doc) {
-        selectHighlightingFromExternal(doc->fileType());
+        return selectHighlightingFromExternal(doc->fileType());
     }
+    return false;
 }
 
 void KateModeMenuList::loadEmptyMsg()
@@ -548,7 +559,8 @@ void KateModeMenuList::loadEmptyMsg()
     const int fontSize = font().pointSize() > 10 ? font().pointSize() + 4 : 14;
 
     QColor color = m_emptyListMsg->palette().color(QPalette::Text);
-    m_emptyListMsg->setStyleSheet(QLatin1String("font-size: ") + QString::number(fontSize) + QLatin1String("pt; color: rgba(") + QString::number(color.red()) + QLatin1Char(',') + QString::number(color.green()) + QLatin1Char(',') + QString::number(color.blue()) + QLatin1String(", 0.3);"));
+    m_emptyListMsg->setStyleSheet(QLatin1String("font-size: ") + QString::number(fontSize) + QLatin1String("pt; color: rgba(") + QString::number(color.red()) + QLatin1Char(',') + QString::number(color.green()) + QLatin1Char(',') +
+                                  QString::number(color.blue()) + QLatin1String(", 0.3);"));
 
     m_emptyListMsg->setAlignment(Qt::AlignCenter);
     m_layoutList->addWidget(m_emptyListMsg, 0, 0, Qt::AlignCenter);
@@ -649,7 +661,7 @@ int KateModeMenuListData::ListView::getWidth() const
 int KateModeMenuListData::ListView::getContentWidth(const int overlayScrollbarMargin, const int classicScrollbarMargin) const
 {
     if (overlapScrollBar()) {
-        return getWidth() - m_parentMenu->m_scroll->sizeHint().width() - m_parentMenu->m_scrollbarMargin - overlayScrollbarMargin;
+        return getWidth() - m_parentMenu->m_scroll->sizeHint().width() - 2 - overlayScrollbarMargin; // ScrollBar Margin = 2
     }
     return getWidth() - verticalScrollBar()->sizeHint().width() - classicScrollbarMargin;
 }
@@ -1051,16 +1063,18 @@ void KateModeMenuListData::SearchLine::updateSearch(const QString &s)
         // Show title in singular or plural, depending on the number of items.
         QLabel *labelSection = static_cast<QLabel *>(listView->indexWidget(listModel->index(0, 0)));
         if (m_bestResults.size() == 1) {
-            labelSection->setText(i18nc("Title (in singular) of the best result in an item search. Please, that the translation doesn't have more than 34 characters, since the menu where it's displayed is small and fixed.", "Best Search Match"));
+            labelSection->setText(
+                i18nc("Title (in singular) of the best result in an item search. Please, that the translation doesn't have more than 34 characters, since the menu where it's displayed is small and fixed.", "Best Search Match"));
         } else {
-            labelSection->setText(i18nc("Title (in plural) of the best results in an item search. Please, that the translation doesn't have more than 34 characters, since the menu where it's displayed is small and fixed.", "Best Search Matches"));
+            labelSection->setText(
+                i18nc("Title (in plural) of the best results in an item search. Please, that the translation doesn't have more than 34 characters, since the menu where it's displayed is small and fixed.", "Best Search Matches"));
         }
 
         int heightSectionMargin = m_parentMenu->m_defaultHeightItemSection - labelSection->sizeHint().height();
         if (heightSectionMargin < 2) {
             heightSectionMargin = 2;
         }
-        int maxWidthText = listView->getContentWidth(0, 1);
+        int maxWidthText = listView->getContentWidth(1, 3);
         // NOTE: labelSection->sizeHint().width() == labelSection->indent() + labelSection->fontMetrics().horizontalAdvance(labelSection->text())
         const bool bSectionMultiline = labelSection->sizeHint().width() > maxWidthText;
         maxWidthText -= labelSection->indent();
@@ -1076,7 +1090,7 @@ void KateModeMenuListData::SearchLine::updateSearch(const QString &s)
 
         // Special Case: always show the "R Script" mode first by typing "r" in the search box
         if (searchText.length() == 1 && searchText.compare(QLatin1String("r"), m_caseSensitivity) == 0) {
-            for (QPair<ListItem *, int> itemBestResults : m_bestResults) {
+            for (const QPair<ListItem *, int> &itemBestResults : qAsConst(m_bestResults)) {
                 listModel->takeRow(itemBestResults.second);
                 ++rowModelBestResults;
                 if (itemBestResults.first->getMode()->name == QLatin1String("R Script")) {
@@ -1089,7 +1103,7 @@ void KateModeMenuListData::SearchLine::updateSearch(const QString &s)
             }
         } else {
             // Move items to the "Best Search Matches" section
-            for (QPair<ListItem *, int> itemBestResults : m_bestResults) {
+            for (const QPair<ListItem *, int> &itemBestResults : qAsConst(m_bestResults)) {
                 listModel->takeRow(itemBestResults.second);
                 listModel->insertRow(++rowModelBestResults, itemBestResults.first);
                 listView->setRowHidden(rowModelBestResults, false);
