@@ -1,45 +1,35 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2002-2010 Anders Lund <anders@alweb.dk>
- *
- *  Rewritten based on code of Copyright (c) 2002 Michael Goffioul <kdeprint@swing.be>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2002-2010 Anders Lund <anders@alweb.dk>
+
+    Rewritten based on code of:
+    SPDX-FileCopyrightText: 2002 Michael Goffioul <kdeprint@swing.be>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kateprinter.h"
 
 #include "kateconfig.h"
 #include "katedocument.h"
+#include "kateglobal.h"
 #include "kateview.h"
 
 #include <KConfigGroup>
 #include <KSharedConfig>
 
 #include <QApplication>
-#include <QPrinter>
+#include <QMarginsF>
+#include <QPageLayout>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
+#include <QPrinter>
 
 #include "printconfigwidgets.h"
 #include "printpainter.h"
 
 using namespace KatePrinter;
 
-//BEGIN KatePrinterPrivate
+// BEGIN KatePrinterPrivate
 class KatePrinterPrivate : public QObject
 {
     Q_OBJECT
@@ -48,14 +38,17 @@ public:
     ~KatePrinterPrivate();
 
     bool print(QPrinter *printer);
+    void setColorScheme(const QString &scheme);
 
 public Q_SLOTS:
     void paint(QPrinter *printer);
 
 private:
-    KTextEditor::ViewPrivate     *m_view;
+    KTextEditor::ViewPrivate *m_view;
     KTextEditor::DocumentPrivate *m_doc;
     PrintPainter *m_painter;
+    static void readSettings(QPrinter *printer);
+    static void writeSettings(QPrinter *printer);
 };
 
 KatePrinterPrivate::KatePrinterPrivate(KTextEditor::DocumentPrivate *doc, KTextEditor::ViewPrivate *view)
@@ -91,6 +84,8 @@ bool KatePrinterPrivate::print(QPrinter *printer)
         parentWidget = QApplication::activeWindow();
     }
 
+    readSettings(printer);
+
     QPointer<QPrintDialog> printDialog(new QPrintDialog(printer, parentWidget));
     printDialog->setOptionTabs(tabs);
 
@@ -107,6 +102,8 @@ bool KatePrinterPrivate::print(QPrinter *printer)
         return false;
     }
 
+    writeSettings(printer);
+
     // configure the painter
     m_painter->setPrintGuide(kpts->printGuide());
     m_painter->setPrintLineNumbers(kpts->printLineNumbers());
@@ -143,9 +140,43 @@ void KatePrinterPrivate::paint(QPrinter *printer)
 {
     m_painter->paint(printer);
 }
-//END KatePrinterPrivate
 
-//BEGIN KatePrinter
+void KatePrinterPrivate::setColorScheme(const QString &scheme)
+{
+    m_painter->setColorScheme(scheme);
+}
+
+void KatePrinterPrivate::writeSettings(QPrinter *printer)
+{
+    KSharedConfigPtr config = KTextEditor::EditorPrivate::config();
+    KConfigGroup group(config, QStringLiteral("Kate Print Settings"));
+    KConfigGroup margins(&group, QStringLiteral("Margins"));
+
+    QMarginsF m = printer->pageLayout().margins(QPageLayout::Millimeter);
+    margins.writeEntry("left", m.left());
+    margins.writeEntry("top", m.top());
+    margins.writeEntry("right", m.right());
+    margins.writeEntry("bottom", m.bottom());
+}
+
+void KatePrinterPrivate::readSettings(QPrinter *printer)
+{
+    KSharedConfigPtr config = KTextEditor::EditorPrivate::config();
+    KConfigGroup group(config, QStringLiteral("Kate Print Settings"));
+    KConfigGroup margins(&group, QStringLiteral("Margins"));
+
+    qreal left, right, top, bottom;
+    left = margins.readEntry("left", left);
+    top = margins.readEntry("top", top);
+    right = margins.readEntry("right", right);
+    bottom = margins.readEntry("bottom", bottom);
+    QMarginsF m = QMarginsF(left, top, right, bottom);
+    printer->setPageMargins(m, QPageLayout::Millimeter);
+}
+
+// END KatePrinterPrivate
+
+// BEGIN KatePrinter
 
 bool KatePrinter::print(KTextEditor::ViewPrivate *view)
 {
@@ -158,8 +189,9 @@ bool KatePrinter::printPreview(KTextEditor::ViewPrivate *view)
 {
     QPrinter printer;
     KatePrinterPrivate p(view->doc(), view);
+    p.setColorScheme(QStringLiteral("Printing"));
     QPrintPreviewDialog preview(&printer);
-    QObject::connect(&preview, SIGNAL(paintRequested(QPrinter*)), &p, SLOT(paint(QPrinter*)));
+    QObject::connect(&preview, SIGNAL(paintRequested(QPrinter *)), &p, SLOT(paint(QPrinter *)));
     return preview.exec();
 }
 
@@ -174,11 +206,12 @@ bool KatePrinter::printPreview(KTextEditor::DocumentPrivate *doc)
 {
     QPrinter printer;
     KatePrinterPrivate p(doc);
+    p.setColorScheme(QStringLiteral("Printing"));
     QPrintPreviewDialog preview(&printer);
-    QObject::connect(&preview, SIGNAL(paintRequested(QPrinter*)), &p, SLOT(paint(QPrinter*)));
+    QObject::connect(&preview, SIGNAL(paintRequested(QPrinter *)), &p, SLOT(paint(QPrinter *)));
     return preview.exec();
 }
 
-//END KatePrinter
+// END KatePrinter
 
 #include "kateprinter.moc"
