@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2005 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2008-2018 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2005 Hamish Rodda <rodda@kde.org>
-    Copyright (C) 2008-2018 Dominik Haumann <dhaumann@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katelayoutcache.h"
@@ -143,9 +129,7 @@ KateLayoutCache::KateLayoutCache(KateRenderer *renderer, QObject *parent)
 {
     Q_ASSERT(m_renderer);
 
-    /**
-     * connect to all possible editing primitives
-     */
+    // connect to all possible editing primitives
     connect(&m_renderer->doc()->buffer(), SIGNAL(lineWrapped(KTextEditor::Cursor)), this, SLOT(wrapLine(KTextEditor::Cursor)));
     connect(&m_renderer->doc()->buffer(), SIGNAL(lineUnwrapped(int)), this, SLOT(unwrapLine(int)));
     connect(&m_renderer->doc()->buffer(), SIGNAL(textInserted(KTextEditor::Cursor, QString)), this, SLOT(insertText(KTextEditor::Cursor, QString)));
@@ -488,7 +472,7 @@ int KateLayoutCache::viewLineCount(int realLine)
 void KateLayoutCache::viewCacheDebugOutput() const
 {
     qCDebug(LOG_KTE) << "Printing values for " << m_textLayouts.count() << " lines:";
-    for (const KateTextLayout &t : m_textLayouts) {
+    for (const KateTextLayout &t : qAsConst(m_textLayouts)) {
         if (t.isValid()) {
             t.debugOutput();
         } else {
