@@ -14,7 +14,6 @@
 
 #include "inlinenotedata.h"
 #include "katebuffer.h"
-#include "kateconfig.h"
 #include "katedocument.h"
 #include "katehighlight.h"
 #include "katerenderrange.h"
@@ -27,11 +26,9 @@
 #include "katepartdebug.h"
 
 #include <QBrush>
-#include <QFont>
 #include <QPainter>
 #include <QRegularExpression>
 #include <QStack>
-#include <QTextLine>
 #include <QtMath> // qCeil
 
 static const QChar tabChar(QLatin1Char('\t'));
@@ -209,7 +206,7 @@ void KateRenderer::paintTextLineBackground(QPainter &paint, KateLineLayoutPtr la
                 }
             }
         } // for
-    }     // Marks
+    } // Marks
 
     if (markCount) {
         markRed /= markCount;
@@ -222,7 +219,8 @@ void KateRenderer::paintTextLineBackground(QPainter &paint, KateLineLayoutPtr la
     paint.fillRect(0, 0, xEnd - xStart, lineHeight() * layout->viewLineCount(), backgroundColor);
 
     // paint the current line background if we're on the current line
-    if (currentViewLine != -1) {
+    const bool currentLineHasSelection = m_view && m_view->selection() && m_view->selectionRange().overlapsLine(layout->line());
+    if (currentViewLine != -1 && !currentLineHasSelection) {
         if (markCount) {
             markRed /= markCount;
             markGreen /= markCount;
@@ -553,7 +551,7 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
     }
 
     if (range->layout()) {
-        bool drawSelection = m_view && m_view->selection() && showSelections() && m_view->selectionRange().overlapsLine(range->line());
+        bool drawSelection = m_view && m_view->selection() && showSelections() && m_view->selectionRange().overlapsLine(range->line()) && !flags.testFlag(SkipDrawLineSelection);
         // Draw selection in block selection mode. We need 2 kinds of selections that QTextLayout::draw can't render:
         //   - past-end-of-line selection and
         //   - 0-column-wide selection (used to indicate where text will be typed)
@@ -648,7 +646,7 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
                 if (m_view && m_view->selection() && !m_view->blockSelection() && m_view->lineEndSelected(line.end(true))) {
                     draw = true;
                     drawBrush = config()->selectionColor();
-                } else if (backgroundBrushSet && !m_view->blockSelection()) {
+                } else if (backgroundBrushSet && m_view && !m_view->blockSelection()) {
                     draw = true;
                     drawBrush = backgroundBrush;
                 }
@@ -1048,7 +1046,7 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
                 QTextCharFormat text_char_format;
                 text_char_format.setFontLetterSpacing(width);
                 text_char_format.setFontLetterSpacingType(QFont::AbsoluteSpacing);
-                decorations.append(QTextLayout::FormatRange {column - 1, 1, text_char_format});
+                decorations.append(QTextLayout::FormatRange{column - 1, 1, text_char_format});
             }
         }
     }
@@ -1191,3 +1189,46 @@ void KateRenderer::setCaretOverrideColor(const QColor &color)
 {
     m_caretOverrideColor = color;
 }
+
+void KateRenderer::paintSelection(QPaintDevice *d, int startLine, int xStart, int endLine, int xEnd, qreal scale)
+{
+    if (!d || scale < 0.0) {
+        return;
+    }
+
+    const int lineHeight = std::max(1, this->lineHeight());
+    QPainter paint(d);
+    paint.scale(scale, scale);
+
+    // clip out non selected parts of start / end line
+    {
+        QRect mainRect(0, 0, d->width(), d->height());
+        QRegion main(mainRect);
+        // start line
+        QRect startRect(0, 0, xStart, lineHeight);
+        QRegion startRegion(startRect);
+        // end line
+        QRect endRect(mainRect.bottomLeft().x() + xEnd, mainRect.bottomRight().y() - lineHeight, mainRect.width() - xEnd, lineHeight);
+        QRegion drawRegion = main.subtracted(startRegion).subtracted(QRegion(endRect));
+        paint.setClipRegion(drawRegion);
+    }
+
+    for (int line = startLine; line <= endLine; ++line) {
+        // get real line, skip if invalid!
+        if (line < 0 || line >= doc()->lines()) {
+            continue;
+        }
+
+        // compute layout WITHOUT cache to not poison it + render it
+        KateLineLayoutPtr lineLayout(new KateLineLayout(*this));
+        lineLayout->setLine(line, -1);
+        layoutLine(lineLayout, -1 /* no wrap */, false /* no layout cache */);
+        KateRenderer::PaintTextLineFlags flags;
+        flags.setFlag(KateRenderer::SkipDrawFirstInvisibleLineUnderlined);
+        flags.setFlag(KateRenderer::SkipDrawLineSelection);
+        paintTextLine(paint, lineLayout, 0, 0, nullptr, flags);
+
+        // translate for next line
+        paint.translate(0, lineHeight);
+    }
+}
