@@ -59,7 +59,7 @@ KateScriptActionMenu::KateScriptActionMenu(KTextEditor::ViewPrivate *view, const
     , m_view(view)
 {
     repopulate();
-    setDelayed(false);
+    setPopupMode(QToolButton::InstantPopup);
 
     // on script-reload signal, repopulate script menu
     connect(KTextEditor::EditorPrivate::self()->scriptManager(), SIGNAL(reloaded()), this, SLOT(repopulate()));
