@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+    SPDX-FileCopyrightText: 2007 Sebastian Pipping <webmaster@hartwork.org>
 
-    Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
-    Copyright (C) 2007 Sebastian Pipping <webmaster@hartwork.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // BEGIN includes
@@ -57,7 +43,10 @@ KTextEditor::Range KatePlainTextSearch::search(const QString &text, const KTextE
         // escape dot and friends
         const QString workPattern = QStringLiteral("\\b%1\\b").arg(QRegularExpression::escape(text));
 
-        return KateRegExpSearch(m_document, m_caseSensitivity).search(workPattern, inputRange, backwards).at(0);
+        QRegularExpression::PatternOptions options;
+        options |= m_caseSensitivity == Qt::CaseInsensitive ? QRegularExpression::CaseInsensitiveOption : QRegularExpression::NoPatternOption;
+
+        return KateRegExpSearch(m_document).search(workPattern, inputRange, backwards, options).at(0);
     }
 
     if (text.isEmpty() || !inputRange.isValid() || (inputRange.start() == inputRange.end())) {
@@ -69,7 +58,7 @@ KTextEditor::Range KatePlainTextSearch::search(const QString &text, const KTextE
 
     if (needleLines.count() > 1) {
         // multi-line plaintext search (both forwards or backwards)
-        const int forMin = inputRange.start().line();                         // first line in range
+        const int forMin = inputRange.start().line(); // first line in range
         const int forMax = inputRange.end().line() + 1 - needleLines.count(); // last line in range
         const int forInit = backwards ? forMax : forMin;
         const int forInc = backwards ? -1 : +1;
