@@ -1,23 +1,9 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
- *  Copyright (C) 2007 Sebastian Pipping <webmaster@hartwork.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+    SPDX-FileCopyrightText: 2007 Sebastian Pipping <webmaster@hartwork.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef _KATE_PLAINTEXTSEARCH_H_
 #define _KATE_PLAINTEXTSEARCH_H_
@@ -57,8 +43,7 @@ public:
      *        (see Range::isValid()).
      * \see KTextEditor::Range
      */
-    KTextEditor::Range search(const QString &text,
-                              const KTextEditor::Range &inputRange, bool backwards = false);
+    KTextEditor::Range search(const QString &text, const KTextEditor::Range &inputRange, bool backwards = false);
 
 private:
     const KTextEditor::Document *m_document;
@@ -67,4 +52,3 @@ private:
 };
 
 #endif
-
