@@ -1,23 +1,9 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
- *  Copyright (C) 2007 Sebastian Pipping <webmaster@hartwork.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2009-2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+    SPDX-FileCopyrightText: 2007 Sebastian Pipping <webmaster@hartwork.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KATE_SEARCH_BAR_H
 #define KATE_SEARCH_BAR_H 1
@@ -28,7 +14,10 @@
 #include <ktexteditor/attribute.h>
 #include <ktexteditor/document.h>
 
-namespace KTextEditor { class ViewPrivate; }
+namespace KTextEditor
+{
+class ViewPrivate;
+}
 class KateViewConfig;
 class QVBoxLayout;
 class QComboBox;
@@ -61,19 +50,9 @@ public:
         MODE_REGEX = 3
     };
 
-    enum MatchResult {
-        MatchFound,
-        MatchWrappedForward,
-        MatchWrappedBackward,
-        MatchMismatch,
-        MatchNothing,
-        MatchNeutral
-    };
+    enum MatchResult { MatchFound, MatchWrappedForward, MatchWrappedBackward, MatchMismatch, MatchNothing, MatchNeutral };
 
-    enum SearchDirection {
-        SearchForward,
-        SearchBackward
-    };
+    enum SearchDirection { SearchForward, SearchBackward };
 
 public:
     explicit KateSearchBar(bool initAsPower, KTextEditor::ViewPrivate *view, KateViewConfig *config);
@@ -89,8 +68,7 @@ public:
     bool selectionOnly() const;
     bool matchCase() const;
 
-    // Only used by KTextEditor::ViewPrivate
-    static void nextMatchForSelection(KTextEditor::ViewPrivate *view, SearchDirection searchDirection);
+    void nextMatchForSelection(KTextEditor::ViewPrivate *view, SearchDirection searchDirection);
 
 public Q_SLOTS:
     /**
@@ -155,7 +133,6 @@ private Q_SLOTS:
      */
     void findOrReplaceAll();
 
-
     /**
      * Restore needed settings when signal @ref findOrReplaceAllFinished()
      * was received.
@@ -170,7 +147,10 @@ Q_SIGNALS:
 
 private:
     // Helpers
-    bool find(SearchDirection searchDirection = SearchForward) { return findOrReplace(searchDirection, nullptr); };
+    bool find(SearchDirection searchDirection = SearchForward)
+    {
+        return findOrReplace(searchDirection, nullptr);
+    };
     bool findOrReplace(SearchDirection searchDirection, const QString *replacement);
 
     /**
@@ -178,7 +158,10 @@ private:
      * Set needed member variables and call @ref findOrReplaceAll() to do the work.
      */
     void beginFindOrReplaceAll(KTextEditor::Range inputRange, const QString &replacement, bool replaceMode = true);
-    void beginFindAll(KTextEditor::Range inputRange) { beginFindOrReplaceAll(inputRange, QString(), false); };
+    void beginFindAll(KTextEditor::Range inputRange)
+    {
+        beginFindOrReplaceAll(inputRange, QString(), false);
+    };
 
     bool isPatternValid() const;
 
@@ -197,9 +180,9 @@ private:
     void addCurrentTextToHistory(QComboBox *combo);
     void backupConfig(bool ofPower);
     void sendConfig();
-    void fixForSingleLine(KTextEditor::Range &range, SearchDirection searchDirection);
 
     void showResultMessage();
+    void showSearchWrappedHint(SearchDirection searchDirection);
 
 private:
     KTextEditor::ViewPrivate *const m_view;
@@ -242,4 +225,3 @@ private:
 };
 
 #endif // KATE_SEARCH_BAR_H
-
