@@ -7,6 +7,7 @@
 
 #include "ontheflycheck.h"
 
+#include <QRegularExpression>
 #include <QTimer>
 
 #include "katebuffer.h"
@@ -49,7 +50,9 @@ KateOnTheFlyChecker::KateOnTheFlyChecker(KTextEditor::DocumentPrivate *document)
     connect(document, SIGNAL(highlightingModeChanged(KTextEditor::Document *)), this, SLOT(updateConfig()));
     connect(&document->buffer(), SIGNAL(respellCheckBlock(int, int)), this, SLOT(handleRespellCheckBlock(int, int)));
 
-    connect(document, &KTextEditor::Document::reloaded, this, [this](KTextEditor::Document *) { refreshSpellCheck(); });
+    connect(document, &KTextEditor::Document::reloaded, this, [this](KTextEditor::Document *) {
+        refreshSpellCheck();
+    });
 
     // load the settings for the speller
     updateConfig();
@@ -215,7 +218,7 @@ void KateOnTheFlyChecker::textRemoved(KTextEditor::Document *document, const KTe
     // don't consider a range that is behind the end of the document
     const KTextEditor::Range documentIntersection = m_document->documentRange().intersect(range);
     if (!documentIntersection.isValid()) { // the intersection might however be empty if the last
-        return;                            // word has been removed, for example
+        return; // word has been removed, for example
     }
 
     // for performance reasons we only want to schedule spellchecks for ranges that are visible
@@ -520,10 +523,10 @@ KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cu
 {
     // FIXME: QTextBoundaryFinder should be ideally used for this, but it is currently
     //        still broken in Qt
-    const QRegExp boundaryRegExp(QLatin1String("\\b"));
-    const QRegExp boundaryQuoteRegExp(QLatin1String("\\b\\w+'\\w*$")); // handle spell checking of QLatin1String("isn't"), QLatin1String("doesn't"), etc.
-    const QRegExp extendedBoundaryRegExp(QLatin1String("(\\W|$)"));
-    const QRegExp extendedBoundaryQuoteRegExp(QLatin1String("^\\w*'\\w+\\b")); // see above
+    const QRegularExpression boundaryRegExp(QLatin1String("\\b"));
+    const QRegularExpression boundaryQuoteRegExp(QLatin1String("\\b\\w+'\\w*$")); // handle spell checking of QLatin1String("isn't"), QLatin1String("doesn't"), etc.
+    const QRegularExpression extendedBoundaryRegExp(QLatin1String("(\\W|$)"));
+    const QRegularExpression extendedBoundaryQuoteRegExp(QLatin1String("^\\w*'\\w+\\b")); // see above
     KTextEditor::DocumentPrivate::OffsetList decToEncOffsetList, encToDecOffsetList;
     const int startLine = begin.line();
     const int startColumn = begin.column();
@@ -551,11 +554,13 @@ KTextEditor::Range KateOnTheFlyChecker::findWordBoundaries(const KTextEditor::Cu
     translatedColumn = m_document->computePositionWrtOffsets(encToDecOffsetList, endColumn);
     text = decodedLineText.mid(translatedColumn);
     boundaryEnd.setLine(endLine);
-    match = extendedBoundaryQuoteRegExp.indexIn(text);
+
+    QRegularExpressionMatch reMatch;
+    match = text.indexOf(extendedBoundaryQuoteRegExp, 0 /* from */, &reMatch);
     if (match == 0) {
-        match = extendedBoundaryQuoteRegExp.matchedLength();
+        match = reMatch.capturedLength(0);
     } else {
-        match = extendedBoundaryRegExp.indexIn(text);
+        match = text.indexOf(extendedBoundaryRegExp);
     }
     boundaryEnd.setColumn(m_document->computePositionWrtOffsets(decToEncOffsetList, translatedColumn + qMax(0, match)));
     return KTextEditor::Range(boundaryStart, boundaryEnd);
@@ -816,7 +821,7 @@ void KateOnTheFlyChecker::viewRefreshTimeout()
 
 void KateOnTheFlyChecker::restartViewRefreshTimer(KTextEditor::ViewPrivate *view)
 {
-    if (m_refreshView && view != m_refreshView) {   // a new view should be refreshed
+    if (m_refreshView && view != m_refreshView) { // a new view should be refreshed
         updateInstalledMovingRanges(m_refreshView); // so refresh the old one first
     }
     m_refreshView = view;
