@@ -1,21 +1,7 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2010-2018 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2010-2018 Dominik Haumann <dhaumann@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kateswapdiffcreator.h"
@@ -23,9 +9,10 @@
 #include "katepartdebug.h"
 #include "kateswapfile.h"
 
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
 
 #include <QDir>
 
@@ -150,12 +137,14 @@ void SwapDiffCreator::slotDiffFinished()
         return;
     }
 
-    // close diffFile and avoid removal, KRun will do that later!
+    // close diffFile and avoid removal, KIO::OpenUrlJob will do that later!
     m_diffFile.close();
     m_diffFile.setAutoRemove(false);
 
-    // KRun::runUrl should delete the file, once the client exits
-    KRun::runUrl(QUrl::fromLocalFile(m_diffFile.fileName()), QStringLiteral("text/x-patch"), m_swapFile->document()->activeView(), KRun::RunFlags(KRun::DeleteTemporaryFiles));
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(m_diffFile.fileName()), QStringLiteral("text/x-patch"));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_swapFile->document()->activeView()));
+    job->setDeleteTemporaryFile(true); // delete the file, once the client exits
+    job->start();
 
     deleteLater();
 }
