@@ -1,22 +1,8 @@
-/* This file is part of the KDE project
- *
- *  Copyright (C) 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2010 Bernhard Beschow <bbeschow@cs.tu-berlin.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "document.h"
 #include "katedocument.h"
@@ -25,7 +11,7 @@ using namespace KTextEditor;
 
 Document::Document(DocumentPrivate *impl, QObject *parent)
     : KParts::ReadWritePart(parent)
-    , d (impl)
+    , d(impl)
 {
 }
 
@@ -33,34 +19,35 @@ Document::~Document()
 {
 }
 
-namespace KTextEditor {
-
+namespace KTextEditor
+{
 /**
  * Private d-pointer type for EditingTransaction
  */
-class EditingTransactionPrivate {
-    public:
-        /**
-         * real document implementation
-         */
-        DocumentPrivate *document;
+class EditingTransactionPrivate
+{
+public:
+    /**
+     * real document implementation
+     */
+    DocumentPrivate *document;
 
-        /**
-         * Indicator for running editing transaction
-         */
-        bool transactionRunning;
+    /**
+     * Indicator for running editing transaction
+     */
+    bool transactionRunning;
 };
 
 }
 
 Document::EditingTransaction::EditingTransaction(Document *document)
-    : d (new EditingTransactionPrivate())
+    : d(new EditingTransactionPrivate())
 {
-    // Alghouth it works in release-mode, we usually want a valid document
+    // Although it works in release-mode, we usually want a valid document
     Q_ASSERT(document != nullptr);
 
     // initialize d-pointer
-    d->document = qobject_cast<KTextEditor::DocumentPrivate *> (document);
+    d->document = qobject_cast<KTextEditor::DocumentPrivate *>(document);
     d->transactionRunning = false;
 
     // start the editing transaction
@@ -70,7 +57,7 @@ Document::EditingTransaction::EditingTransaction(Document *document)
 void Document::EditingTransaction::start()
 {
     if (d->document && !d->transactionRunning) {
-        d->document->startEditing ();
+        d->document->startEditing();
         d->transactionRunning = true;
     }
 }
@@ -78,21 +65,17 @@ void Document::EditingTransaction::start()
 void Document::EditingTransaction::finish()
 {
     if (d->document && d->transactionRunning) {
-        d->document->finishEditing ();
+        d->document->finishEditing();
         d->transactionRunning = false;
     }
 }
 
 Document::EditingTransaction::~EditingTransaction()
 {
-    /**
-     * finish the editing transaction
-     */
+    // finish the editing transaction
     finish();
 
-    /**
-     * delete our d-pointer
-     */
+    // delete our d-pointer
     delete d;
 }
 
