@@ -1,26 +1,18 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2003 Jesse Yurkovich <yurkjes@iit.edu>
-   Copyright (C) 2004 Anders Lund <anders@alweb.dk> (KateVarIndent class)
-   Copyright (C) 2005 Dominik Haumann <dhdev@gmx.de> (basic support for config page)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2003 Jesse Yurkovich <yurkjes@iit.edu>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
+    KateVarIndent class:
+    SPDX-FileCopyrightText: 2004 Anders Lund <anders@alweb.dk>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    Basic support for config page:
+    SPDX-FileCopyrightText: 2005 Dominik Haumann <dhdev@gmx.de>
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kateautoindent.h"
 
-#include "kateconfig.h"
 #include "katedocument.h"
 #include "kateextendedattribute.h"
 #include "kateglobal.h"
@@ -51,7 +43,7 @@ inline const QString MODE_NORMAL()
 QStringList KateAutoIndent::listModes()
 {
     QStringList l;
-
+    l.reserve(modeCount());
     for (int i = 0; i < modeCount(); ++i) {
         l << modeDescription(i);
     }
@@ -62,7 +54,7 @@ QStringList KateAutoIndent::listModes()
 QStringList KateAutoIndent::listIdentifiers()
 {
     QStringList l;
-
+    l.reserve(modeCount());
     for (int i = 0; i < modeCount(); ++i) {
         l << modeName(i);
     }
@@ -337,8 +329,7 @@ void KateAutoIndent::setMode(const QString &name)
             m_mode = name;
             return;
         } else {
-            qCWarning(LOG_KTE) << "mode" << name << "requires a different highlight style: highlighting" << doc->highlight()->name() << "with style" << doc->highlight()->style()
-                               << "but script requires"
+            qCWarning(LOG_KTE) << "mode" << name << "requires a different highlight style: highlighting" << doc->highlight()->name() << "with style" << doc->highlight()->style() << "but script requires"
                                << script->indentHeader().requiredStyle();
         }
     } else {
@@ -353,8 +344,7 @@ void KateAutoIndent::checkRequiredStyle()
 {
     if (m_script) {
         if (!isStyleProvided(m_script, doc->highlight())) {
-            qCDebug(LOG_KTE) << "mode" << m_mode << "requires a different highlight style: highlighting" << doc->highlight()->name() << "with style" << doc->highlight()->style()
-                             << "but script requires"
+            qCDebug(LOG_KTE) << "mode" << m_mode << "requires a different highlight style: highlighting" << doc->highlight()->name() << "with style" << doc->highlight()->style() << "but script requires"
                              << m_script->indentHeader().requiredStyle();
             doc->config()->setIndentationMode(MODE_NORMAL());
         }
@@ -455,7 +445,7 @@ KateViewIndentationAction::KateViewIndentationAction(KTextEditor::DocumentPrivat
     : KActionMenu(text, parent)
     , doc(_doc)
 {
-    setDelayed(false);
+    setPopupMode(QToolButton::InstantPopup);
     connect(menu(), SIGNAL(aboutToShow()), this, SLOT(slotAboutToShow()));
     actionGroup = new QActionGroup(menu());
 }
