@@ -1,39 +1,27 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2002, 2003, 2004 Anders Lund <anders.lund@lund.tdcadsl.dk>
-   Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
+/*
+    SPDX-FileCopyrightText: 2002, 2003, 2004 Anders Lund <anders.lund@lund.tdcadsl.dk>
+    SPDX-FileCopyrightText: 2002 John Firebaugh <jfirebaugh@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katebookmarks.h"
 
+#include "kateabstractinputmode.h"
 #include "katedocument.h"
 #include "kateview.h"
-#include "kateabstractinputmode.h"
 
 #include <KActionCollection>
+#include <KActionMenu>
 #include <KGuiItem>
+#include <KLocalizedString>
 #include <KStringHandler>
+#include <KToggleAction>
 #include <KXMLGUIClient>
 #include <KXMLGUIFactory>
-#include <KToggleAction>
-#include <KActionMenu>
-#include <KLocalizedString>
 
-#include <QRegExp>
 #include <QEvent>
+#include <QRegularExpression>
 #include <QVector>
 
 namespace KTextEditor
@@ -48,7 +36,7 @@ KateBookmarks::KateBookmarks(KTextEditor::ViewPrivate *view, Sorting sort)
     , m_sorting(sort)
 {
     setObjectName(QStringLiteral("kate bookmarks"));
-    connect(view->doc(), SIGNAL(marksChanged(KTextEditor::Document*)), this, SLOT(marksChanged()));
+    connect(view->doc(), SIGNAL(marksChanged(KTextEditor::Document *)), this, SLOT(marksChanged()));
     _tries = 0;
     m_bookmarksMenu = nullptr;
 }
@@ -87,6 +75,7 @@ void KateBookmarks::createActions(KActionCollection *ac)
     connect(m_goPrevious, SIGNAL(triggered()), this, SLOT(goPrevious()));
 
     KActionMenu *actionMenu = new KActionMenu(i18n("&Bookmarks"), this);
+    actionMenu->setPopupMode(QToolButton::InstantPopup);
     ac->addAction(QStringLiteral("bookmarks"), actionMenu);
     m_bookmarksMenu = actionMenu->menu();
 
@@ -105,11 +94,9 @@ void KateBookmarks::toggleBookmark()
 {
     uint mark = m_view->doc()->mark(m_view->cursorPosition().line());
     if (mark & KTextEditor::MarkInterface::markType01)
-        m_view->doc()->removeMark(m_view->cursorPosition().line(),
-                                  KTextEditor::MarkInterface::markType01);
+        m_view->doc()->removeMark(m_view->cursorPosition().line(), KTextEditor::MarkInterface::markType01);
     else
-        m_view->doc()->addMark(m_view->cursorPosition().line(),
-                               KTextEditor::MarkInterface::markType01);
+        m_view->doc()->addMark(m_view->cursorPosition().line(), KTextEditor::MarkInterface::markType01);
 }
 
 void KateBookmarks::clearBookmarks()
@@ -126,8 +113,8 @@ void KateBookmarks::clearBookmarks()
 
 void KateBookmarks::insertBookmarks(QMenu &menu)
 {
-    int line = m_view->cursorPosition().line();
-    const QRegExp re(QLatin1String("&(?!&)"));
+    const int line = m_view->cursorPosition().line();
+    const QRegularExpression re(QStringLiteral("&(?!&)"));
     int next = -1; // -1 means next bookmark doesn't exist
     int prev = -1; // -1 means previous bookmark doesn't exist
 
@@ -146,17 +133,14 @@ void KateBookmarks::insertBookmarks(QMenu &menu)
     }
 
     if (m_sorting == Position) {
-        qSort(bookmarkLineArray.begin(), bookmarkLineArray.end());
+        std::sort(bookmarkLineArray.begin(), bookmarkLineArray.end());
     }
 
     QAction *firstNewAction = menu.addSeparator();
     // Consider each line with a bookmark one at a time
     for (int i = 0; i < bookmarkLineArray.size(); ++i) {
         // Get text in this particular line in a QString
-        QString bText = menu.fontMetrics().elidedText
-                        (m_view->doc()->line(bookmarkLineArray.at(i)),
-                         Qt::ElideRight,
-                         menu.fontMetrics().maxWidth() * 32);
+        QString bText = menu.fontMetrics().elidedText(m_view->doc()->line(bookmarkLineArray.at(i)), Qt::ElideRight, menu.fontMetrics().maxWidth() * 32);
         bText.replace(re, QStringLiteral("&&")); // kill undesired accellerators!
         bText.replace(QLatin1Char('\t'), QLatin1Char(' ')); // kill tabs, as they are interpreted as shortcuts
 
@@ -172,9 +156,7 @@ void KateBookmarks::insertBookmarks(QMenu &menu)
 
         // Adding action for this bookmark in menu
         if (before) {
-            QAction *a = new QAction(QStringLiteral("%1  %3  - \"%2\"")
-                                     .arg(bookmarkLineArray.at(i) + 1).arg(bText)
-                                     .arg(m_view->currentInputMode()->bookmarkLabel(bookmarkLineArray.at(i))), &menu);
+            QAction *a = new QAction(QStringLiteral("%1  %3  - \"%2\"").arg(bookmarkLineArray.at(i) + 1).arg(bText).arg(m_view->currentInputMode()->bookmarkLabel(bookmarkLineArray.at(i))), &menu);
             menu.insertAction(before, a);
             connect(a, SIGNAL(activated()), this, SLOT(gotoLine()));
             a->setData(bookmarkLineArray.at(i));
@@ -183,10 +165,7 @@ void KateBookmarks::insertBookmarks(QMenu &menu)
             }
 
         } else {
-            QAction *a = menu.addAction(QStringLiteral("%1  %3  - \"%2\"")
-                                        .arg(bookmarkLineArray.at(i) + 1).arg(bText)
-                                        .arg(m_view->currentInputMode()->bookmarkLabel(bookmarkLineArray.at(i))),
-                                        this, SLOT(gotoLine()));
+            QAction *a = menu.addAction(QStringLiteral("%1  %3  - \"%2\"").arg(bookmarkLineArray.at(i) + 1).arg(bText).arg(m_view->currentInputMode()->bookmarkLabel(bookmarkLineArray.at(i))), this, SLOT(gotoLine()));
             a->setData(bookmarkLineArray.at(i));
         }
 
@@ -204,15 +183,13 @@ void KateBookmarks::insertBookmarks(QMenu &menu)
 
     if (next != -1) {
         // Insert action for next bookmark
-        m_goNext->setText(i18n("&Next: %1 - \"%2\"",  next + 1,
-                               KStringHandler::rsqueeze(m_view->doc()->line(next), 24)));
+        m_goNext->setText(i18n("&Next: %1 - \"%2\"", next + 1, KStringHandler::rsqueeze(m_view->doc()->line(next), 24)));
         menu.insertAction(firstNewAction, m_goNext);
         firstNewAction = m_goNext;
     }
     if (prev != -1) {
         // Insert action for previous bookmark
-        m_goPrevious->setText(i18n("&Previous: %1 - \"%2\"", prev + 1,
-                                   KStringHandler::rsqueeze(m_view->doc()->line(prev), 24)));
+        m_goPrevious->setText(i18n("&Previous: %1 - \"%2\"", prev + 1, KStringHandler::rsqueeze(m_view->doc()->line(prev), 24)));
         menu.insertAction(firstNewAction, m_goPrevious);
         firstNewAction = m_goPrevious;
     }
@@ -238,8 +215,7 @@ void KateBookmarks::gotoLine(int line)
 void KateBookmarks::bookmarkMenuAboutToShow()
 {
     m_bookmarksMenu->clear();
-    m_bookmarkToggle->setChecked(m_view->doc()->mark(m_view->cursorPosition().line())
-                                 & KTextEditor::MarkInterface::markType01);
+    m_bookmarkToggle->setChecked(m_view->doc()->mark(m_view->cursorPosition().line()) & KTextEditor::MarkInterface::markType01);
     m_bookmarksMenu->addAction(m_bookmarkToggle);
     m_bookmarksMenu->addAction(m_bookmarkClear);
 
@@ -297,4 +273,3 @@ void KateBookmarks::marksChanged()
         m_bookmarkClear->setEnabled(!m_view->doc()->marks().isEmpty());
     }
 }
-
