@@ -1,42 +1,31 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2007, 2008 Matthew Woehlke <mw_triad@users.sourceforge.net>
-   Copyright (C) 2003 Christoph Cullmann <cullmann@kde.org>
+/*
+    SPDX-FileCopyrightText: 2007, 2008 Matthew Woehlke <mw_triad@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2003 Christoph Cullmann <cullmann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kateconfig.h"
 
-#include "kateglobal.h"
-#include "katedefaultcolors.h"
-#include "katerenderer.h"
-#include "kateview.h"
 #include "katedocument.h"
-#include "kateschema.h"
+#include "kateglobal.h"
 #include "katepartdebug.h"
+#include "katerenderer.h"
+#include "katesyntaxmanager.h"
+#include "kateview.h"
 
-#include <math.h>
-
-#include <KConfigGroup>
 #include <KCharsets>
+#include <KConfigGroup>
 
+#include <QGuiApplication>
 #include <QSettings>
-#include <QTextCodec>
 #include <QStringListModel>
+#include <QTextCodec>
 
-//BEGIN KateConfig
+#include <Sonnet/GuessLanguage>
+#include <Sonnet/Speller>
+
+// BEGIN KateConfig
 KateConfig::KateConfig(const KateConfig *parent)
     : m_parent(parent)
     , m_configKeys(m_parent ? nullptr : new QStringList())
@@ -50,36 +39,25 @@ KateConfig::~KateConfig()
 
 void KateConfig::addConfigEntry(ConfigEntry &&entry)
 {
-    /**
-     * shall only be called for toplevel config
-     */
+    // shall only be called for toplevel config
     Q_ASSERT(isGlobal());
 
-    /**
-     * there shall be no gaps in the entries
-     * we might later want to use a vector
-     */
+    // there shall be no gaps in the entries
+    // we might later want to use a vector
     Q_ASSERT(m_configEntries.size() == static_cast<size_t>(entry.enumKey));
 
-    /**
-     * add new element
-     */
+    // add new element
     m_configEntries.emplace(entry.enumKey, entry);
 }
 
 void KateConfig::finalizeConfigEntries()
 {
-    /**
-     * shall only be called for toplevel config
-     */
+    // shall only be called for toplevel config
     Q_ASSERT(isGlobal());
 
-    /**
-     * compute list of all config keys + register map from key => config entry
-     *
-     * we skip entries without a command name, these config entries are not exposed ATM
-     *
-     */
+    // compute list of all config keys + register map from key => config entry
+    //
+    // we skip entries without a command name, these config entries are not exposed ATM
     for (const auto &entry : m_configEntries) {
         if (!entry.second.commandName.isEmpty()) {
             Q_ASSERT_X(!m_configKeys->contains(entry.second.commandName), "finalizeConfigEntries", (QLatin1String("KEY NOT UNIQUE: ") + entry.second.commandName).toLocal8Bit().constData());
@@ -198,41 +176,33 @@ bool KateConfig::setValue(const int key, const QVariant &value)
 
 QVariant KateConfig::value(const QString &key) const
 {
-    /**
-     * check if we know this key, if not, return invalid variant
-     */
+    // check if we know this key, if not, return invalid variant
     const auto &knownEntries = fullConfigKeyToEntry();
     const auto it = knownEntries.find(key);
     if (it == knownEntries.end()) {
         return QVariant();
     }
 
-    /**
-     * key known, dispatch to normal value() function with enum
-     */
+    // key known, dispatch to normal value() function with enum
     return value(it.value()->enumKey);
 }
 
 bool KateConfig::setValue(const QString &key, const QVariant &value)
 {
-    /**
-     * check if we know this key, if not, ignore the set
-     */
+    // check if we know this key, if not, ignore the set
     const auto &knownEntries = fullConfigKeyToEntry();
     const auto it = knownEntries.find(key);
     if (it == knownEntries.end()) {
         return false;
     }
 
-    /**
-     * key known, dispatch to normal setValue() function with enum
-     */
+    // key known, dispatch to normal setValue() function with enum
     return setValue(it.value()->enumKey, value);
 }
 
-//END
+// END
 
-//BEGIN HelperFunctions
+// BEGIN HelperFunctions
 KateGlobalConfig *KateGlobalConfig::s_global = nullptr;
 KateDocumentConfig *KateDocumentConfig::s_global = nullptr;
 KateViewConfig *KateViewConfig::s_global = nullptr;
@@ -262,58 +232,44 @@ static bool isPositive(const QVariant &value)
     value.toUInt(&ok);
     return ok;
 }
-//END
+// END
 
-//BEGIN KateGlobalConfig
+// BEGIN KateGlobalConfig
 KateGlobalConfig::KateGlobalConfig()
 {
-    /**
-     * register this as our global instance
-     */
+    // register this as our global instance
     Q_ASSERT(isGlobal());
     s_global = this;
 
-    /**
-     * init all known config entries
-     */
+    // init all known config entries
     addConfigEntry(ConfigEntry(EncodingProberType, "Encoding Prober Type", QString(), KEncodingProber::Universal));
-    addConfigEntry(ConfigEntry(FallbackEncoding, "Fallback Encoding", QString(), QStringLiteral("ISO 8859-15"), [](const QVariant &value) { return isEncodingOk(value.toString()); }));
+    addConfigEntry(ConfigEntry(FallbackEncoding, "Fallback Encoding", QString(), QStringLiteral("ISO 8859-15"), [](const QVariant &value) {
+        return isEncodingOk(value.toString());
+    }));
 
-    /**
-     * finalize the entries, e.g. hashs them
-     */
+    // finalize the entries, e.g. hashs them
     finalizeConfigEntries();
 
-    /**
-     * init with defaults from config or really hardcoded ones
-     */
+    // init with defaults from config or really hardcoded ones
     KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Editor");
     readConfig(cg);
 }
 
 void KateGlobalConfig::readConfig(const KConfigGroup &config)
 {
-    /**
-     * start config update group
-     */
+    // start config update group
     configStart();
 
-    /**
-     * read generic entries
-     */
+    // read generic entries
     readConfigEntries(config);
 
-    /**
-     * end config update group, might trigger updateConfig()
-     */
+    // end config update group, might trigger updateConfig()
     configEnd();
 }
 
 void KateGlobalConfig::writeConfig(KConfigGroup &config)
 {
-    /**
-     * write generic entries
-     */
+    // write generic entries
     writeConfigEntries(config);
 }
 
@@ -327,35 +283,31 @@ void KateGlobalConfig::updateConfig()
 
 QTextCodec *KateGlobalConfig::fallbackCodec() const
 {
-    /**
-     * query stored encoding, always fallback to ISO 8859-15 if nothing valid set
-     */
+    // query stored encoding, always fallback to ISO 8859-15 if nothing valid set
     const auto encoding = value(FallbackEncoding).toString();
     if (encoding.isEmpty()) {
         return QTextCodec::codecForName("ISO 8859-15");
     }
 
-    /**
-     * use configured encoding
-     */
+    // use configured encoding
     return KCharsets::charsets()->codecForName(encoding);
 }
-//END
+// END
 
-//BEGIN KateDocumentConfig
+// BEGIN KateDocumentConfig
 KateDocumentConfig::KateDocumentConfig()
 {
-    /**
-     * register this as our global instance
-     */
+    // register this as our global instance
     Q_ASSERT(isGlobal());
     s_global = this;
 
-    /**
-     * init all known config entries
-     */
-    addConfigEntry(ConfigEntry(TabWidth, "Tab Width", QStringLiteral("tab-width"), 4, [](const QVariant &value) { return value.toInt() >= 1; }));
-    addConfigEntry(ConfigEntry(IndentationWidth, "Indentation Width", QStringLiteral("indent-width"), 4, [](const QVariant &value) { return value.toInt() >= 1; }));
+    // init all known config entries
+    addConfigEntry(ConfigEntry(TabWidth, "Tab Width", QStringLiteral("tab-width"), 4, [](const QVariant &value) {
+        return value.toInt() >= 1;
+    }));
+    addConfigEntry(ConfigEntry(IndentationWidth, "Indentation Width", QStringLiteral("indent-width"), 4, [](const QVariant &value) {
+        return value.toInt() >= 1;
+    }));
     addConfigEntry(ConfigEntry(OnTheFlySpellCheck, "On-The-Fly Spellcheck", QStringLiteral("on-the-fly-spellcheck"), false));
     addConfigEntry(ConfigEntry(IndentOnTextPaste, "Indent On Text Paste", QStringLiteral("indent-pasted-text"), false));
     addConfigEntry(ConfigEntry(ReplaceTabsWithSpaces, "ReplaceTabsDyn", QStringLiteral("replace-tabs"), true));
@@ -366,7 +318,9 @@ KateDocumentConfig::KateDocumentConfig()
     addConfigEntry(ConfigEntry(IndentationMode, "Indentation Mode", QString(), QStringLiteral("normal")));
     addConfigEntry(ConfigEntry(TabHandlingMode, "Tab Handling", QString(), KateDocumentConfig::tabSmart));
     addConfigEntry(ConfigEntry(StaticWordWrap, "Word Wrap", QString(), false));
-    addConfigEntry(ConfigEntry(StaticWordWrapColumn, "Word Wrap Column", QString(), 80, [](const QVariant &value) { return value.toInt() >= 1; }));
+    addConfigEntry(ConfigEntry(StaticWordWrapColumn, "Word Wrap Column", QString(), 80, [](const QVariant &value) {
+        return value.toInt() >= 1;
+    }));
     addConfigEntry(ConfigEntry(PageUpDownMovesCursor, "PageUp/PageDown Moves Cursor", QString(), false));
     addConfigEntry(ConfigEntry(SmartHome, "Smart Home", QString(), true));
     addConfigEntry(ConfigEntry(ShowTabs, "Show Tabs", QString(), true));
@@ -378,7 +332,9 @@ KateDocumentConfig::KateDocumentConfig()
     addConfigEntry(ConfigEntry(RemoveSpacesMode, "Remove Spaces", QString(), 0));
     addConfigEntry(ConfigEntry(NewlineAtEOF, "Newline at End of File", QString(), true));
     addConfigEntry(ConfigEntry(OverwriteMode, "Overwrite Mode", QString(), false));
-    addConfigEntry(ConfigEntry(Encoding, "Encoding", QString(), QStringLiteral("UTF-8"), [](const QVariant &value) { return isEncodingOk(value.toString()); }));
+    addConfigEntry(ConfigEntry(Encoding, "Encoding", QString(), QStringLiteral("UTF-8"), [](const QVariant &value) {
+        return isEncodingOk(value.toString());
+    }));
     addConfigEntry(ConfigEntry(EndOfLine, "End of Line", QString(), 0));
     addConfigEntry(ConfigEntry(AllowEndOfLineDetection, "Allow End of Line Detection", QString(), true));
     addConfigEntry(ConfigEntry(ByteOrderMark, "BOM", QString(), false));
@@ -387,75 +343,66 @@ KateDocumentConfig::KateDocumentConfig()
     addConfigEntry(ConfigEntry(SwapFileSyncInterval, "Swap Sync Interval", QString(), 15));
     addConfigEntry(ConfigEntry(LineLengthLimit, "Line Length Limit", QString(), 10000));
 
-    /**
-     * finalize the entries, e.g. hashs them
-     */
+    // finalize the entries, e.g. hashs them
     finalizeConfigEntries();
 
-    /**
-     * init with defaults from config or really hardcoded ones
-     */
+    // init with defaults from config or really hardcoded ones
     KConfigGroup cg(KTextEditor::EditorPrivate::config(), "KTextEditor Document");
     readConfig(cg);
 }
 
 KateDocumentConfig::KateDocumentConfig(KTextEditor::DocumentPrivate *doc)
-    : KateConfig(s_global),
-      m_doc(doc)
+    : KateConfig(s_global)
+    , m_doc(doc)
 {
-    /**
-     * per document config doesn't read stuff per default
-     */
+    // per document config doesn't read stuff per default
 }
 
 void KateDocumentConfig::readConfig(const KConfigGroup &config)
 {
-    /**
-     * start config update group
-     */
+    // start config update group
     configStart();
 
-    /**
-     * read generic entries
-     */
+    // read generic entries
     readConfigEntries(config);
 
-    /**
-     * fixup sonnet config, see KateSpellCheckConfigTab::apply(), too
-     * WARNING: this is slightly hackish, but it's currently the only way to
-     *          do it, see also the KTextEdit class
-     */
+    // fixup sonnet config, see KateSpellCheckConfigTab::apply(), too
+    // WARNING: this is slightly hackish, but it's currently the only way to
+    //          do it, see also the KTextEdit class
     if (isGlobal()) {
         const QSettings settings(QStringLiteral("KDE"), QStringLiteral("Sonnet"));
-        setOnTheFlySpellCheck(settings.value(QStringLiteral("checkerEnabledByDefault"), false).toBool());
+        const bool onTheFlyChecking = settings.value(QStringLiteral("checkerEnabledByDefault"), false).toBool();
+        setOnTheFlySpellCheck(onTheFlyChecking);
+
+        // ensure we load the default dictionary speller + trigrams early
+        // this avoids hangs for auto-spellchecking on first edits
+        // do this if we have on the fly spellchecking on only
+        if (onTheFlyChecking) {
+            Sonnet::Speller speller;
+            speller.setLanguage(Sonnet::Speller().defaultLanguage());
+            Sonnet::GuessLanguage languageGuesser;
+            languageGuesser.identify(QStringLiteral("dummy to trigger identify"));
+        }
     }
 
-    /**
-     * backwards compatibility mappings
-     * convert stuff, old entries deleted in writeConfig
-     */
+    // backwards compatibility mappings
+    // convert stuff, old entries deleted in writeConfig
     if (const int backupFlags = config.readEntry("Backup Flags", 0)) {
         setBackupOnSaveLocal(backupFlags & 0x1);
         setBackupOnSaveRemote(backupFlags & 0x2);
     }
 
-    /**
-     * end config update group, might trigger updateConfig()
-     */
+    // end config update group, might trigger updateConfig()
     configEnd();
 }
 
 void KateDocumentConfig::writeConfig(KConfigGroup &config)
 {
-    /**
-     * write generic entries
-     */
+    // write generic entries
     writeConfigEntries(config);
 
-    /**
-     * backwards compatibility mappings
-     * here we remove old entries we converted on readConfig
-     */
+    // backwards compatibility mappings
+    // here we remove old entries we converted on readConfig
     config.deleteEntry("Backup Flags");
 }
 
@@ -480,36 +427,32 @@ void KateDocumentConfig::updateConfig()
 
 QTextCodec *KateDocumentConfig::codec() const
 {
-    /**
-     * query stored encoding, always fallback to UTF-8 if nothing valid set
-     */
+    // query stored encoding, always fallback to UTF-8 if nothing valid set
     const auto encoding = value(Encoding).toString();
     if (encoding.isEmpty()) {
         return QTextCodec::codecForName("UTF-8");
     }
 
-    /**
-     * use configured encoding
-     */
+    // use configured encoding
     return KCharsets::charsets()->codecForName(encoding);
 }
 
 QString KateDocumentConfig::eolString()
 {
-    switch(eol()) {
-        case KateDocumentConfig::eolDos:
-            return QStringLiteral("\r\n");
+    switch (eol()) {
+    case KateDocumentConfig::eolDos:
+        return QStringLiteral("\r\n");
 
-        case KateDocumentConfig::eolMac:
-            return QStringLiteral("\r");
+    case KateDocumentConfig::eolMac:
+        return QStringLiteral("\r");
 
-        default:
-            return QStringLiteral("\n");
+    default:
+        return QStringLiteral("\n");
     }
 }
-//END
+// END
 
-//BEGIN KateViewConfig
+// BEGIN KateViewConfig
 KateViewConfig::KateViewConfig()
 {
     s_global = this;
@@ -523,21 +466,35 @@ KateViewConfig::KateViewConfig()
     addConfigEntry(ConfigEntry(AutomaticCompletionInvocation, "Auto Completion", QString(), true));
     addConfigEntry(ConfigEntry(BackspaceRemoveComposedCharacters, "Backspace Remove Composed Characters", QString(), false));
     addConfigEntry(ConfigEntry(BookmarkSorting, "Bookmark Menu Sorting", QString(), 0));
-    addConfigEntry(ConfigEntry(CharsToEncloseSelection, "Chars To Enclose Selection", QString(), QString()));
-    addConfigEntry(ConfigEntry(DefaultMarkType, "Default Mark Type", QStringLiteral("default-mark-type"), KTextEditor::MarkInterface::markType01, [](const QVariant &value) { return isPositive(value); }));
-    addConfigEntry(ConfigEntry(DynWordWrapAlignIndent, "Dynamic Word Wrap Align Indent", QString(), 80, [](const QVariant &value) { return inBounds(1, value, 100); }));
-    addConfigEntry(ConfigEntry(DynWordWrapIndicators, "Dynamic Word Wrap Indicators", QString(), 1, [](const QVariant &value) { return inBounds(1, value, 3); }));
+    addConfigEntry(ConfigEntry(CharsToEncloseSelection, "Chars To Enclose Selection", QStringLiteral("enclose-selection"), QString()));
+    addConfigEntry(ConfigEntry(DefaultMarkType, "Default Mark Type", QStringLiteral("default-mark-type"), KTextEditor::MarkInterface::markType01, [](const QVariant &value) {
+        return isPositive(value);
+    }));
+    addConfigEntry(ConfigEntry(DynWordWrapAlignIndent, "Dynamic Word Wrap Align Indent", QString(), 80, [](const QVariant &value) {
+        return inBounds(1, value, 100);
+    }));
+    addConfigEntry(ConfigEntry(DynWordWrapIndicators, "Dynamic Word Wrap Indicators", QString(), 1, [](const QVariant &value) {
+        return inBounds(1, value, 3);
+    }));
+    addConfigEntry(ConfigEntry(DynWrapAnywhere, "Dynamic Wrap not at word boundaries", QStringLiteral("dynamic-word-wrap-anywhere"), false));
     addConfigEntry(ConfigEntry(DynWrapAtStaticMarker, "Dynamic Word Wrap At Static Marker", QString(), false));
     addConfigEntry(ConfigEntry(DynamicWordWrap, "Dynamic Word Wrap", QStringLiteral("dynamic-word-wrap"), true));
     addConfigEntry(ConfigEntry(FoldFirstLine, "Fold First Line", QString(), false));
-    addConfigEntry(ConfigEntry(InputMode, "Input Mode", QString(), 0, [](const QVariant &value) { return isPositive(value); }));
+    addConfigEntry(ConfigEntry(InputMode, "Input Mode", QString(), 0, [](const QVariant &value) {
+        return isPositive(value);
+    }));
     addConfigEntry(ConfigEntry(KeywordCompletion, "Keyword Completion", QStringLiteral("keyword-completion"), true));
-    addConfigEntry(ConfigEntry(MaxHistorySize, "Maximum Search History Size", QString(), 100, [](const QVariant &value) { return inBounds(0, value, 999); }));
+    addConfigEntry(ConfigEntry(MaxHistorySize, "Maximum Search History Size", QString(), 100, [](const QVariant &value) {
+        return inBounds(0, value, 999);
+    }));
     addConfigEntry(ConfigEntry(MousePasteAtCursorPosition, "Mouse Paste At Cursor Position", QString(), false));
     addConfigEntry(ConfigEntry(PersistentSelection, "Persistent Selection", QStringLiteral("persistent-selectionq"), false));
-    addConfigEntry(ConfigEntry(ScrollBarMiniMapWidth, "Scroll Bar Mini Map Width", QString(), 60, [](const QVariant &value) { return inBounds(0, value, 999); }));
+    addConfigEntry(ConfigEntry(ScrollBarMiniMapWidth, "Scroll Bar Mini Map Width", QString(), 60, [](const QVariant &value) {
+        return inBounds(0, value, 999);
+    }));
     addConfigEntry(ConfigEntry(ScrollPastEnd, "Scroll Past End", QString(), false));
     addConfigEntry(ConfigEntry(SearchFlags, "Search/Replace Flags", QString(), IncFromCursor | PowerMatchCase | PowerModePlainText));
+    addConfigEntry(ConfigEntry(ShowBracketMatchPreview, "Bracket Match Preview", QStringLiteral("bracket-match-preview"), false));
     addConfigEntry(ConfigEntry(ShowFoldingBar, "Folding Bar", QStringLiteral("folding-bar"), true));
     addConfigEntry(ConfigEntry(ShowFoldingPreview, "Folding Preview", QStringLiteral("folding-preview"), true));
     addConfigEntry(ConfigEntry(ShowIconBar, "Icon Bar", QStringLiteral("icon-bar"), false));
@@ -548,13 +505,19 @@ KateViewConfig::KateViewConfig()
     addConfigEntry(ConfigEntry(ShowScrollBarMiniMap, "Scroll Bar MiniMap", QStringLiteral("scrollbar-minimap"), true));
     addConfigEntry(ConfigEntry(ShowScrollBarMiniMapAll, "Scroll Bar Mini Map All", QString(), true));
     addConfigEntry(ConfigEntry(ShowScrollBarPreview, "Scroll Bar Preview", QStringLiteral("scrollbar-preview"), true));
-    addConfigEntry(ConfigEntry(ShowScrollbars, "Show Scrollbars", QString(), AlwaysOn, [](const QVariant &value) { return inBounds(0, value, 2); }));
+    addConfigEntry(ConfigEntry(ShowScrollbars, "Show Scrollbars", QString(), AlwaysOn, [](const QVariant &value) {
+        return inBounds(0, value, 2);
+    }));
     addConfigEntry(ConfigEntry(ShowWordCount, "Show Word Count", QString(), false));
+    addConfigEntry(ConfigEntry(TextDragAndDrop, "Text Drag And Drop", QString(), true));
     addConfigEntry(ConfigEntry(SmartCopyCut, "Smart Copy Cut", QString(), false));
+    addConfigEntry(ConfigEntry(UserSetsOfCharsToEncloseSelection, "User Sets Of Chars To Enclose Selection", QString(), QStringList()));
     addConfigEntry(ConfigEntry(ViInputModeStealKeys, "Vi Input Mode Steal Keys", QString(), false));
     addConfigEntry(ConfigEntry(ViRelativeLineNumbers, "Vi Relative Line Numbers", QString(), false));
     addConfigEntry(ConfigEntry(WordCompletion, "Word Completion", QString(), true));
-    addConfigEntry(ConfigEntry(WordCompletionMinimalWordLength, "Word Completion Minimal Word Length", QString(), 3, [](const QVariant &value) { return inBounds(0, value, 99); }));
+    addConfigEntry(ConfigEntry(WordCompletionMinimalWordLength, "Word Completion Minimal Word Length", QString(), 3, [](const QVariant &value) {
+        return inBounds(0, value, 99);
+    }));
     addConfigEntry(ConfigEntry(WordCompletionRemoveTail, "Word Completion Remove Tail", QString(), true));
 
     // Never forget to finalize or the <CommandName> becomes not available
@@ -599,7 +562,8 @@ void KateViewConfig::updateConfig()
     }
 
     if (isGlobal()) {
-        foreach (KTextEditor::ViewPrivate* view, KTextEditor::EditorPrivate::self()->views()) {
+        const auto allViews = KTextEditor::EditorPrivate::self()->views();
+        for (KTextEditor::ViewPrivate *view : allViews) {
             view->updateConfig();
         }
 
@@ -609,38 +573,35 @@ void KateViewConfig::updateConfig()
         KTextEditor::EditorPrivate::config()->sync();
     }
 }
+// END
 
-//END
-
-//BEGIN KateRendererConfig
+// BEGIN KateRendererConfig
 KateRendererConfig::KateRendererConfig()
-    : m_fontMetrics(QFont()),
-      m_lineMarkerColor(KTextEditor::MarkInterface::reservedMarkersCount()),
-
-      m_schemaSet(false),
-      m_fontSet(false),
-      m_wordWrapMarkerSet(false),
-      m_showIndentationLinesSet(false),
-      m_showWholeBracketExpressionSet(false),
-      m_backgroundColorSet(false),
-      m_selectionColorSet(false),
-      m_highlightedLineColorSet(false),
-      m_highlightedBracketColorSet(false),
-      m_wordWrapMarkerColorSet(false),
-      m_tabMarkerColorSet(false),
-      m_indentationLineColorSet(false),
-      m_iconBarColorSet(false),
-      m_foldingColorSet(false),
-      m_lineNumberColorSet(false),
-      m_currentLineNumberColorSet(false),
-      m_separatorColorSet(false),
-      m_spellingMistakeLineColorSet(false),
-      m_templateColorsSet(false),
-      m_modifiedLineColorSet(false),
-      m_savedLineColorSet(false),
-      m_searchHighlightColorSet(false),
-      m_replaceHighlightColorSet(false),
-      m_lineMarkerColorSet(m_lineMarkerColor.size())
+    : m_lineMarkerColor(KTextEditor::MarkInterface::reservedMarkersCount())
+    , m_schemaSet(false)
+    , m_fontSet(false)
+    , m_wordWrapMarkerSet(false)
+    , m_showIndentationLinesSet(false)
+    , m_showWholeBracketExpressionSet(false)
+    , m_backgroundColorSet(false)
+    , m_selectionColorSet(false)
+    , m_highlightedLineColorSet(false)
+    , m_highlightedBracketColorSet(false)
+    , m_wordWrapMarkerColorSet(false)
+    , m_tabMarkerColorSet(false)
+    , m_indentationLineColorSet(false)
+    , m_iconBarColorSet(false)
+    , m_foldingColorSet(false)
+    , m_lineNumberColorSet(false)
+    , m_currentLineNumberColorSet(false)
+    , m_separatorColorSet(false)
+    , m_spellingMistakeLineColorSet(false)
+    , m_templateColorsSet(false)
+    , m_modifiedLineColorSet(false)
+    , m_savedLineColorSet(false)
+    , m_searchHighlightColorSet(false)
+    , m_replaceHighlightColorSet(false)
+    , m_lineMarkerColorSet(m_lineMarkerColor.size())
 
 {
     // init bitarray
@@ -648,40 +609,45 @@ KateRendererConfig::KateRendererConfig()
 
     s_global = this;
 
+    // Init all known config entries
+    addConfigEntry(ConfigEntry(AutoColorThemeSelection, "Auto Color Theme Selection", QString(), true));
+
+    // Never forget to finalize or the <CommandName> becomes not available
+    finalizeConfigEntries();
+
     // init with defaults from config or really hardcoded ones
     KConfigGroup config(KTextEditor::EditorPrivate::config(), "KTextEditor Renderer");
     readConfig(config);
 }
 
 KateRendererConfig::KateRendererConfig(KateRenderer *renderer)
-    : KateConfig(s_global),
-      m_fontMetrics(QFont()),
-      m_lineMarkerColor(KTextEditor::MarkInterface::reservedMarkersCount()),
-      m_schemaSet(false),
-      m_fontSet(false),
-      m_wordWrapMarkerSet(false),
-      m_showIndentationLinesSet(false),
-      m_showWholeBracketExpressionSet(false),
-      m_backgroundColorSet(false),
-      m_selectionColorSet(false),
-      m_highlightedLineColorSet(false),
-      m_highlightedBracketColorSet(false),
-      m_wordWrapMarkerColorSet(false),
-      m_tabMarkerColorSet(false),
-      m_indentationLineColorSet(false),
-      m_iconBarColorSet(false),
-      m_foldingColorSet(false),
-      m_lineNumberColorSet(false),
-      m_currentLineNumberColorSet(false),
-      m_separatorColorSet(false),
-      m_spellingMistakeLineColorSet(false),
-      m_templateColorsSet(false),
-      m_modifiedLineColorSet(false),
-      m_savedLineColorSet(false),
-      m_searchHighlightColorSet(false),
-      m_replaceHighlightColorSet(false),
-      m_lineMarkerColorSet(m_lineMarkerColor.size()),
-      m_renderer(renderer)
+    : KateConfig(s_global)
+    , m_lineMarkerColor(KTextEditor::MarkInterface::reservedMarkersCount())
+    , m_schemaSet(false)
+    , m_fontSet(false)
+    , m_wordWrapMarkerSet(false)
+    , m_showIndentationLinesSet(false)
+    , m_showWholeBracketExpressionSet(false)
+    , m_backgroundColorSet(false)
+    , m_selectionColorSet(false)
+    , m_highlightedLineColorSet(false)
+    , m_highlightedBracketColorSet(false)
+    , m_wordWrapMarkerColorSet(false)
+    , m_tabMarkerColorSet(false)
+    , m_indentationLineColorSet(false)
+    , m_iconBarColorSet(false)
+    , m_foldingColorSet(false)
+    , m_lineNumberColorSet(false)
+    , m_currentLineNumberColorSet(false)
+    , m_separatorColorSet(false)
+    , m_spellingMistakeLineColorSet(false)
+    , m_templateColorsSet(false)
+    , m_modifiedLineColorSet(false)
+    , m_savedLineColorSet(false)
+    , m_searchHighlightColorSet(false)
+    , m_replaceHighlightColorSet(false)
+    , m_lineMarkerColorSet(m_lineMarkerColor.size())
+    , m_renderer(renderer)
 {
     // init bitarray
     m_lineMarkerColorSet.fill(false);
@@ -693,7 +659,8 @@ KateRendererConfig::~KateRendererConfig()
 
 namespace
 {
-const char KEY_SCHEMA[] = "Schema";
+const char KEY_FONT[] = "Font";
+const char KEY_COLOR_THEME[] = "Color Theme";
 const char KEY_WORD_WRAP_MARKER[] = "Word Wrap Marker";
 const char KEY_SHOW_INDENTATION_LINES[] = "Show Indentation Lines";
 const char KEY_SHOW_WHOLE_BRACKET_EXPRESSION[] = "Show Whole Bracket Expression";
@@ -707,8 +674,11 @@ void KateRendererConfig::readConfig(const KConfigGroup &config)
     // read generic entries
     readConfigEntries(config);
 
-    // "Normal" Schema MUST BE THERE, see global kateschemarc
-    setSchema(config.readEntry(KEY_SCHEMA, "Normal"));
+    // read font, but drop all styles, else we have no bold/italic/... variants
+    setFontWithDroppedStyleName(config.readEntry(KEY_FONT, QFontDatabase::systemFont(QFontDatabase::FixedFont)));
+
+    // setSchema will default to right theme
+    setSchema(config.readEntry(KEY_COLOR_THEME, QString()));
 
     setWordWrapMarker(config.readEntry(KEY_WORD_WRAP_MARKER, false));
 
@@ -726,7 +696,9 @@ void KateRendererConfig::writeConfig(KConfigGroup &config)
     // write generic entries
     writeConfigEntries(config);
 
-    config.writeEntry(KEY_SCHEMA, schema());
+    config.writeEntry(KEY_FONT, baseFont());
+
+    config.writeEntry(KEY_COLOR_THEME, schema());
 
     config.writeEntry(KEY_WORD_WRAP_MARKER, wordWrapMarker());
 
@@ -765,8 +737,14 @@ const QString &KateRendererConfig::schema() const
     return s_global->schema();
 }
 
-void KateRendererConfig::setSchema(const QString &schema)
+void KateRendererConfig::setSchema(QString schema)
 {
+    // check if we have some matching theme, else fallback to best theme for current palette
+    // same behavior as for the "Automatic Color Theme Selection"
+    if (!KateHlManager::self()->repository().theme(schema).isValid()) {
+        schema = KateHlManager::self()->repository().themeForPalette(qGuiApp->palette()).name();
+    }
+
     if (m_schemaSet && m_schema == schema) {
         return;
     }
@@ -774,7 +752,7 @@ void KateRendererConfig::setSchema(const QString &schema)
     configStart();
     m_schemaSet = true;
     m_schema = schema;
-    setSchemaInternal(schema);
+    setSchemaInternal(m_schema);
     configEnd();
 }
 
@@ -782,7 +760,8 @@ void KateRendererConfig::reloadSchema()
 {
     if (isGlobal()) {
         setSchemaInternal(m_schema);
-        foreach (KTextEditor::ViewPrivate *view, KTextEditor::EditorPrivate::self()->views()) {
+        const auto allViews = KTextEditor::EditorPrivate::self()->views();
+        for (KTextEditor::ViewPrivate *view : allViews) {
             view->renderer()->config()->reloadSchema();
         }
     }
@@ -799,89 +778,97 @@ void KateRendererConfig::reloadSchema()
 
 void KateRendererConfig::setSchemaInternal(const QString &schema)
 {
+    // we always set the theme if we arrive here!
     m_schemaSet = true;
-    m_schema = schema;
 
-    KConfigGroup config = KTextEditor::EditorPrivate::self()->schemaManager()->schema(schema);
+    // for the global config, we honor the auto selection based on the palette
+    // do the same if the set theme really doesn't exist, we need a valid theme or the rendering will be broken in bad ways!
+    if ((isGlobal() && value(AutoColorThemeSelection).toBool()) || !KateHlManager::self()->repository().theme(schema).isValid()) {
+        // always choose some theme matching the current application palette
+        // we will arrive here after palette changed signals, too!
+        m_schema = KateHlManager::self()->repository().themeForPalette(qGuiApp->palette()).name();
+    } else {
+        // take user given theme 1:1
+        m_schema = schema;
+    }
 
-    // use global color instance, creation is expensive!
-    const KateDefaultColors &colors(KTextEditor::EditorPrivate::self()->defaultColors());
-
-    m_backgroundColor = config.readEntry("Color Background", colors.color(Kate::Background));
+    const auto theme = KateHlManager::self()->repository().theme(m_schema);
 
+    m_backgroundColor = theme.editorColor(KSyntaxHighlighting::Theme::BackgroundColor);
     m_backgroundColorSet = true;
-    m_selectionColor = config.readEntry("Color Selection", colors.color(Kate::SelectionBackground));
+
+    m_selectionColor = theme.editorColor(KSyntaxHighlighting::Theme::TextSelection);
     m_selectionColorSet = true;
-    m_highlightedLineColor  = config.readEntry("Color Highlighted Line", colors.color(Kate::HighlightedLineBackground));
+
+    m_highlightedLineColor = theme.editorColor(KSyntaxHighlighting::Theme::CurrentLine);
     m_highlightedLineColorSet = true;
-    m_highlightedBracketColor = config.readEntry("Color Highlighted Bracket", colors.color(Kate::HighlightedBracket));
+
+    m_highlightedBracketColor = theme.editorColor(KSyntaxHighlighting::Theme::BracketMatching);
     m_highlightedBracketColorSet = true;
-    m_wordWrapMarkerColor = config.readEntry("Color Word Wrap Marker", colors.color(Kate::WordWrapMarker));
+
+    m_wordWrapMarkerColor = theme.editorColor(KSyntaxHighlighting::Theme::WordWrapMarker);
     m_wordWrapMarkerColorSet = true;
-    m_tabMarkerColor = config.readEntry("Color Tab Marker", colors.color(Kate::TabMarker));
+
+    m_tabMarkerColor = theme.editorColor(KSyntaxHighlighting::Theme::TabMarker);
     m_tabMarkerColorSet = true;
-    m_indentationLineColor = config.readEntry("Color Indentation Line", colors.color(Kate::IndentationLine));
+
+    m_indentationLineColor = theme.editorColor(KSyntaxHighlighting::Theme::IndentationLine);
     m_indentationLineColorSet = true;
-    m_iconBarColor  = config.readEntry("Color Icon Bar", colors.color(Kate::IconBar));
+
+    m_iconBarColor = theme.editorColor(KSyntaxHighlighting::Theme::IconBorder);
     m_iconBarColorSet = true;
-    m_foldingColor  = config.readEntry("Color Code Folding", colors.color(Kate::CodeFolding));
+
+    m_foldingColor = theme.editorColor(KSyntaxHighlighting::Theme::CodeFolding);
     m_foldingColorSet = true;
-    m_lineNumberColor = config.readEntry("Color Line Number", colors.color(Kate::LineNumber));
+
+    m_lineNumberColor = theme.editorColor(KSyntaxHighlighting::Theme::LineNumbers);
     m_lineNumberColorSet = true;
-    m_currentLineNumberColor = config.readEntry("Color Current Line Number", colors.color(Kate::CurrentLineNumber));
+
+    m_currentLineNumberColor = theme.editorColor(KSyntaxHighlighting::Theme::CurrentLineNumber);
     m_currentLineNumberColorSet = true;
-    m_separatorColor = config.readEntry("Color Separator", colors.color(Kate::Separator));
+
+    m_separatorColor = theme.editorColor(KSyntaxHighlighting::Theme::Separator);
     m_separatorColorSet = true;
-    m_spellingMistakeLineColor = config.readEntry("Color Spelling Mistake Line", colors.color(Kate::SpellingMistakeLine));
+
+    m_spellingMistakeLineColor = theme.editorColor(KSyntaxHighlighting::Theme::SpellChecking);
     m_spellingMistakeLineColorSet = true;
 
-    m_modifiedLineColor = config.readEntry("Color Modified Lines", colors.color(Kate::ModifiedLine));
+    m_modifiedLineColor = theme.editorColor(KSyntaxHighlighting::Theme::ModifiedLines);
     m_modifiedLineColorSet = true;
-    m_savedLineColor = config.readEntry("Color Saved Lines", colors.color(Kate::SavedLine));
+
+    m_savedLineColor = theme.editorColor(KSyntaxHighlighting::Theme::SavedLines);
     m_savedLineColorSet = true;
-    m_searchHighlightColor = config.readEntry("Color Search Highlight", colors.color(Kate::SearchHighlight));
+
+    m_searchHighlightColor = theme.editorColor(KSyntaxHighlighting::Theme::SearchHighlight);
     m_searchHighlightColorSet = true;
-    m_replaceHighlightColor = config.readEntry("Color Replace Highlight", colors.color(Kate::ReplaceHighlight));
+
+    m_replaceHighlightColor = theme.editorColor(KSyntaxHighlighting::Theme::ReplaceHighlight);
     m_replaceHighlightColorSet = true;
 
-    for (int i = Kate::FIRST_MARK; i <= Kate::LAST_MARK; i++) {
-        QColor col = config.readEntry(QStringLiteral("Color MarkType %1").arg(i + 1), colors.mark(i));
+    for (int i = 0; i <= KSyntaxHighlighting::Theme::MarkError - KSyntaxHighlighting::Theme::MarkBookmark; i++) {
+        QColor col = theme.editorColor(static_cast<KSyntaxHighlighting::Theme::EditorColorRole>(i + KSyntaxHighlighting::Theme::MarkBookmark));
         m_lineMarkerColorSet[i] = true;
         m_lineMarkerColor[i] = col;
     }
 
-    setFontWithDroppedStyleName(config.readEntry("Font", QFontDatabase::systemFont(QFontDatabase::FixedFont)));
+    m_templateBackgroundColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplateBackground);
 
-    m_templateBackgroundColor = config.readEntry(QStringLiteral("Color Template Background"), colors.color(Kate::TemplateBackground));
+    m_templateFocusedEditablePlaceholderColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplateFocusedPlaceholder);
 
-    m_templateFocusedEditablePlaceholderColor = config.readEntry(QStringLiteral("Color Template Focused Editable Placeholder"),
-                                                                 colors.color(Kate::TemplateFocusedEditablePlaceholder));
+    m_templateEditablePlaceholderColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplatePlaceholder);
 
-    m_templateEditablePlaceholderColor = config.readEntry(QStringLiteral("Color Template Editable Placeholder"),
-                                                          colors.color(Kate::TemplateEditablePlaceholder));
-
-    m_templateNotEditablePlaceholderColor = config.readEntry(QStringLiteral("Color Template Not Editable Placeholder"),
-                                                             colors.color(Kate::TemplateNotEditablePlaceholder));
+    m_templateNotEditablePlaceholderColor = theme.editorColor(KSyntaxHighlighting::Theme::TemplateReadOnlyPlaceholder);
 
     m_templateColorsSet = true;
 }
 
-const QFont &KateRendererConfig::font() const
+const QFont &KateRendererConfig::baseFont() const
 {
     if (m_fontSet || isGlobal()) {
         return m_font;
     }
 
-    return s_global->font();
-}
-
-const QFontMetricsF &KateRendererConfig::fontMetrics() const
-{
-    if (m_fontSet || isGlobal()) {
-        return m_fontMetrics;
-    }
-
-    return s_global->fontMetrics();
+    return s_global->baseFont();
 }
 
 void KateRendererConfig::setFont(const QFont &font)
@@ -897,12 +884,9 @@ void KateRendererConfig::setFont(const QFont &font)
 
 void KateRendererConfig::setFontWithDroppedStyleName(const QFont &font)
 {
-    /**
-     * Drop styleName, otherwise stuff like bold/italic/... won't work as style!
-     */
+    // Drop styleName, otherwise stuff like bold/italic/... won't work as style!
     m_font = font;
     m_font.setStyleName(QString());
-    m_fontMetrics = QFontMetricsF(m_font);
     m_fontSet = true;
 }
 
@@ -1002,7 +986,7 @@ const QColor &KateRendererConfig::lineMarkerColor(KTextEditor::MarkInterface::Ma
 {
     int index = 0;
     if (type > 0) {
-        while ((type >> index++) ^ 1) {}
+        while ((type >> index++) ^ 1) { }
     }
     index -= 1;
 
@@ -1018,23 +1002,6 @@ const QColor &KateRendererConfig::lineMarkerColor(KTextEditor::MarkInterface::Ma
     return s_global->lineMarkerColor(type);
 }
 
-void KateRendererConfig::setLineMarkerColor(const QColor &col, KTextEditor::MarkInterface::MarkTypes type)
-{
-    int index = static_cast<int>(log(static_cast<double>(type)) / log(2.0));
-    Q_ASSERT(index >= 0 && index < KTextEditor::MarkInterface::reservedMarkersCount());
-
-    if (m_lineMarkerColorSet[index] && m_lineMarkerColor[index] == col) {
-        return;
-    }
-
-    configStart();
-
-    m_lineMarkerColorSet[index] = true;
-    m_lineMarkerColor[index] = col;
-
-    configEnd();
-}
-
 const QColor &KateRendererConfig::highlightedBracketColor() const
 {
     if (m_highlightedBracketColorSet || isGlobal()) {
@@ -1455,5 +1422,4 @@ void KateRendererConfig::setAnimateBracketMatching(bool on)
     }
 }
 
-//END
-
+// END
