@@ -1,23 +1,9 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2003-2005 Anders Lund <anders@alweb.dk>
+    SPDX-FileCopyrightText: 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Charles Samuels <charles@kde.org>
 
-    Copyright (C) 2003-2005 Anders Lund <anders@alweb.dk>
-    Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
-    Copyright (C) 2001 Charles Samuels <charles@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katesedcmd.h"
@@ -185,7 +171,8 @@ KateCommands::SedReplace::InteractiveSedReplacer::InteractiveSedReplacer(KTextEd
     , m_onlyOnePerLine(onlyOnePerLine)
     , m_endLine(endLine)
     , m_doc(doc)
-    , m_regExpSearch(doc, caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive)
+    , m_regExpSearch(doc)
+    , m_caseSensitive(caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive)
     , m_numReplacementsDone(0)
     , m_numLinesTouched(0)
     , m_lastChangedLineNum(-1)
@@ -279,13 +266,18 @@ const QVector<KTextEditor::Range> KateCommands::SedReplace::InteractiveSedReplac
         return QVector<KTextEditor::Range>();
     }
 
-    return m_regExpSearch.search(m_findPattern, KTextEditor::Range(m_currentSearchPos, m_doc->documentEnd()));
+    QRegularExpression::PatternOptions options;
+    if (m_caseSensitive == Qt::CaseInsensitive) {
+        options |= (QRegularExpression::CaseInsensitiveOption);
+    }
+    return m_regExpSearch.search(m_findPattern, KTextEditor::Range(m_currentSearchPos, m_doc->documentEnd()), false /* search backwards */, options);
 }
 
 QString KateCommands::SedReplace::InteractiveSedReplacer::replacementTextForCurrentMatch()
 {
     const QVector<KTextEditor::Range> captureRanges = fullCurrentMatch();
     QStringList captureTexts;
+    captureTexts.reserve(captureRanges.size());
     for (KTextEditor::Range captureRange : captureRanges) {
         captureTexts << m_doc->text(captureRange);
     }
