@@ -1,37 +1,24 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2003-2005 Anders Lund <anders@alweb.dk>
- *  Copyright (C) 2001-2010 Christoph Cullmann <cullmann@kde.org>
- *  Copyright (C) 2001 Charles Samuels <charles@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2003-2005 Anders Lund <anders@alweb.dk>
+    SPDX-FileCopyrightText: 2001-2010 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2001 Charles Samuels <charles@kde.org>
 
-#ifndef __KATE_SED_CMD_H__
-#define __KATE_SED_CMD_H__
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#ifndef KATE_SED_CMD_H
+#define KATE_SED_CMD_H
 
-#include <KTextEditor/Command>
 #include "kateregexpsearch.h"
+#include <KTextEditor/Command>
 
-#include <QStringList>
 #include <QSharedPointer>
+#include <QStringList>
 
-namespace KTextEditor {
-    class DocumentPrivate;
-    class ViewPrivate;
+namespace KTextEditor
+{
+class DocumentPrivate;
+class ViewPrivate;
 }
 
 /**
@@ -40,7 +27,6 @@ namespace KTextEditor {
  */
 namespace KateCommands
 {
-
 /**
  * Support vim/sed style search and replace
  * @author Charles Samuels <charles@kde.org>
@@ -50,12 +36,13 @@ class SedReplace : public KTextEditor::Command
     static SedReplace *m_instance;
 
 protected:
-    SedReplace() : KTextEditor::Command({ QStringLiteral("s"), QStringLiteral("%s"), QStringLiteral("$s") })
+    SedReplace()
+        : KTextEditor::Command({QStringLiteral("s"), QStringLiteral("%s"), QStringLiteral("$s")})
     {
     }
 
 public:
-    ~SedReplace()
+    ~SedReplace() override
     {
         m_instance = nullptr;
     }
@@ -75,16 +62,15 @@ public:
      * @param errorMsg error to return if no success
      * @return success
      */
-    bool exec(class KTextEditor::View *view, const QString &cmd, QString &errorMsg,
-              const KTextEditor::Range &r) Q_DECL_OVERRIDE;
+    bool exec(class KTextEditor::View *view, const QString &cmd, QString &errorMsg, const KTextEditor::Range &r) override;
 
-    bool supportsRange(const QString &) Q_DECL_OVERRIDE
+    bool supportsRange(const QString &) override
     {
         return true;
     }
 
     /** This command does not have help. @see KTextEditor::Command::help */
-    bool help(class KTextEditor::View *, const QString &, QString &) Q_DECL_OVERRIDE
+    bool help(class KTextEditor::View *, const QString &, QString &) override
     {
         return false;
     }
@@ -119,6 +105,7 @@ public:
         void replaceAllRemaining();
         QString currentMatchReplacementConfirmationMessage();
         QString finalStatusReportMessage();
+
     private:
         const QString m_findPattern;
         const QString m_replacePattern;
@@ -126,6 +113,7 @@ public:
         int m_endLine;
         KTextEditor::DocumentPrivate *m_doc;
         KateRegExpSearch m_regExpSearch;
+        Qt::CaseSensitivity m_caseSensitive;
 
         int m_numReplacementsDone;
         int m_numLinesTouched;
@@ -142,4 +130,3 @@ protected:
 
 } // namespace KateCommands
 #endif
-
