@@ -1,21 +1,7 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2011-2018 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2011-2018 Dominik Haumann <dhaumann@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "variableeditor.h"
@@ -69,8 +55,6 @@ VariableEditor::VariableEditor(VariableItem *item, QWidget *parent)
     l->setColumnStretch(2, 1);
     l->setColumnStretch(3, 0);
 
-    setLayout(l);
-
     connect(m_checkBox, SIGNAL(toggled(bool)), this, SLOT(itemEnabled(bool)));
     m_checkBox->setChecked(item->isActive());
 
