@@ -1,21 +1,7 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2011-2018 Dominik Haumann <dhaumann@kde.org>
 
-    Copyright (C) 2011-2018 Dominik Haumann <dhaumann@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "variablelistview.h"
@@ -46,11 +32,19 @@ void VariableListView::parseVariables(const QString &line)
         tmp.remove(0, 5);
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList variables = tmp.split(QLatin1Char(';'), QString::SkipEmptyParts);
+#else
+    QStringList variables = tmp.split(QLatin1Char(';'), Qt::SkipEmptyParts);
+#endif
 
     const QRegularExpression sep(QStringLiteral("\\s+"));
     for (int i = 0; i < variables.size(); ++i) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList pair = variables[i].split(sep, QString::SkipEmptyParts);
+#else
+        QStringList pair = variables[i].split(sep, Qt::SkipEmptyParts);
+#endif
         if (pair.size() < 2) {
             continue;
         }
