@@ -131,6 +131,11 @@ private Q_SLOTS:
      */
     void pasteSelection();
 
+    /**
+     * Copy current selected stuff and paste previous content of clipboard as one operation.
+     */
+    void swapWithClipboard();
+
     /**
      * Wrap lines touched by the selection with respect of existing paragraphs.
      * Work is done by KTextEditor::DocumentPrivate::wrapParagraph
@@ -757,6 +762,7 @@ private:
     QAction *m_paste;
     // always nullptr if paste selection isn't supported
     QAction *m_pasteSelection = nullptr;
+    QAction *m_swapWithClipboard;
     QAction *m_selectAll;
     QAction *m_deSelect;
 
@@ -990,7 +996,7 @@ private:
      * Message widgets showing KTextEditor::Messages.
      * The index of the array maps to the enum KTextEditor::Message::MessagePosition.
      */
-    std::array<KateMessageWidget *, 5> m_messageWidgets {{nullptr}};
+    std::array<KateMessageWidget *, 5> m_messageWidgets{{nullptr}};
     /** Layout for floating notifications */
     KateMessageLayout *m_notificationLayout = nullptr;
 
