@@ -1,26 +1,14 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2002-2007 Hamish Rodda <rodda@kde.org>
-   Copyright (C) 2002 John Firebaugh <jfirebaugh@kde.org>
-   Copyright (C) 2002 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2002 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2007 Mirko Stocker <me@misto.ch>
+/*
+    SPDX-FileCopyrightText: 2002-2007 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2002 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2002 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2007 Mirko Stocker <me@misto.ch>
 
-   Based on:
-     KWriteView : Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+    Based on KWriteView:
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef _KATE_VIEW_INTERNAL_
@@ -28,21 +16,23 @@
 
 #include <ktexteditor/attribute.h>
 
+#include "inlinenotedata.h"
+#include "katedocument.h"
+#include "katerenderer.h"
 #include "katetextcursor.h"
 #include "katetextline.h"
-#include "katedocument.h"
 #include "kateview.h"
-#include "katerenderer.h"
-#include "inlinenotedata.h"
 
-#include <QPoint>
-#include <QTimer>
-#include <QElapsedTimer>
-#include <QTime>
 #include <QDrag>
-#include <QWidget>
-#include <QSet>
+#include <QElapsedTimer>
+#include <QPoint>
 #include <QPointer>
+#include <QSet>
+#include <QTime>
+#include <QTimer>
+#include <QWidget>
+
+#include <memory>
 
 namespace KTextEditor
 {
@@ -52,6 +42,8 @@ class TextHintProvider;
 
 class KateIconBorder;
 class KateScrollBar;
+class KateAnnotationItemDelegate;
+class KateAnnotationGroupPositionState;
 class KateTextLayout;
 class KateTextAnimation;
 class KateAbstractInputMode;
@@ -66,6 +58,8 @@ class KateViewInternal : public QWidget
     friend class KTextEditor::ViewPrivate;
     friend class KateIconBorder;
     friend class KateScrollBar;
+    friend class KateAnnotationItemDelegate;
+    friend class KateAnnotationGroupPositionState;
     friend class CalculatingCursor;
     friend class BoundedCursor;
     friend class WrappingCursor;
@@ -73,11 +67,7 @@ class KateViewInternal : public QWidget
     friend class ::KateTextPreview;
 
 public:
-    enum Bias {
-        left  = -1,
-        none  =  0,
-        right =  1
-    };
+    enum Bias { left = -1, none = 0, right = 1 };
 
 public:
     explicit KateViewInternal(KTextEditor::ViewPrivate *view);
@@ -87,7 +77,7 @@ public:
         return m_view;
     }
 
-    //BEGIN EDIT STUFF
+    // BEGIN EDIT STUFF
 public:
     void editStart();
     void editEnd(int editTagLineStart, int editTagLineEnd, bool tagFrom);
@@ -99,9 +89,9 @@ private:
     bool editIsRunning;
     KTextEditor::Cursor editOldCursor;
     KTextEditor::Range editOldSelection;
-    //END
+    // END
 
-    //BEGIN TAG & CLEAR & UPDATE STUFF
+    // BEGIN TAG & CLEAR & UPDATE STUFF
 public:
     bool tagLine(const KTextEditor::Cursor &virtualCursor);
 
@@ -116,15 +106,13 @@ public:
     void updateDirty();
 
     void clear();
-    //END
+    // END
 
 private Q_SLOTS:
     // Updates the view and requests a redraw.
     void updateView(bool changed = false, int viewLinesScrolled = 0);
 
 private:
-    // Actually performs the updating, but doesn't call update().
-    void doUpdateView(bool changed = false, int viewLinesScrolled = 0);
     void makeVisible(const KTextEditor::Cursor &c, int endCol, bool force = false, bool center = false, bool calledExternally = false);
 
 public:
@@ -153,6 +141,7 @@ public:
 public Q_SLOTS:
     void slotIncFontSizes(qreal step = 1.0);
     void slotDecFontSizes(qreal step = 1.0);
+    void slotResetFontSizes();
 
     void paintCursor();
 
@@ -164,19 +153,10 @@ private Q_SLOTS:
     void scrollPrevPage();
     void scrollPrevLine();
     void scrollNextLine();
-    void scrollColumns(int x);  // connected to the valueChanged of the m_columnScroll
+    void scrollColumns(int x); // connected to the valueChanged of the m_columnScroll
     void viewSelectionChanged();
 
 public:
-    void doReturn();
-    void doSmartNewline();
-    void doDelete();
-    void doBackspace();
-    void doTabulator();
-    void doTranspose();
-    void doDeletePrevWord();
-    void doDeleteNextWord();
-
     void cursorPrevChar(bool sel = false);
     void cursorNextChar(bool sel = false);
     void wordPrev(bool sel = false);
@@ -197,11 +177,22 @@ public:
     void top_home(bool sel = false);
     void bottom_end(bool sel = false);
 
-    KTextEditor::Cursor getCursor() const
+    /**
+     * Accessor to the current caret position
+     * @return position of the caret as @c KTextEditor::Cursor
+     * @see KTextEditor::Cursor
+     */
+    KTextEditor::Cursor cursorPosition() const
     {
         return m_cursor;
     }
-    KTextEditor::Cursor getMouse() const
+
+    /**
+     * Accessor to the current mouse position
+     * @return position of the mouse as @c KTextEditor::Cursor
+     * @see KTextEditor::Cursor
+     */
+    KTextEditor::Cursor mousePosition() const
     {
         return m_mouse;
     }
@@ -220,6 +211,9 @@ public:
     // EVENT HANDLING STUFF - IMPORTANT
 private:
     void fixDropEvent(QDropEvent *event);
+
+    bool isAcceptableInput(const QKeyEvent *e) const;
+
 protected:
     void hideEvent(QHideEvent *e) override;
     void paintEvent(QPaintEvent *e) override;
@@ -227,6 +221,7 @@ protected:
     void keyPressEvent(QKeyEvent *) override;
     void keyReleaseEvent(QKeyEvent *) override;
     void resizeEvent(QResizeEvent *) override;
+    void moveEvent(QMoveEvent *) override;
     void mousePressEvent(QMouseEvent *) override;
     void mouseDoubleClickEvent(QMouseEvent *) override;
     void mouseReleaseEvent(QMouseEvent *) override;
@@ -261,6 +256,7 @@ private:
     void scrollPos(KTextEditor::Cursor &c, bool force = false, bool calledExternally = false, bool emitSignals = true);
     void scrollLines(int lines, bool sel);
 
+    KTextEditor::Attribute::Ptr attributeAt(const KTextEditor::Cursor &position) const;
     int linesDisplayed() const;
 
     int lineToY(int viewLine) const;
@@ -274,7 +270,7 @@ private:
 
     void placeCursor(const QPoint &p, bool keepSelection = false, bool updateSelection = true);
     bool isTargetSelected(const QPoint &p);
-    //Returns whether the given range affects the area currently visible in the view
+    // Returns whether the given range affects the area currently visible in the view
     bool rangeAffectsView(const KTextEditor::Range &range, bool realCursors) const;
 
     void doDrag();
@@ -299,21 +295,22 @@ private:
 
     bool m_possibleTripleClick;
 
-    //Whether the current completion-item was expanded while the last press of ALT
+    // Whether the current completion-item was expanded while the last press of ALT
     bool m_completionItemExpanded;
     QElapsedTimer m_altDownTime;
 
     // Bracket mark and corresponding decorative ranges
     KTextEditor::MovingRange *m_bm, *m_bmStart, *m_bmEnd;
     KTextEditor::MovingCursor *m_bmLastFlashPos;
+    std::unique_ptr<KateTextPreview> m_bmPreview;
     void updateBracketMarkAttributes();
 
     enum DragState { diNone, diPending, diDragging };
 
     struct _dragInfo {
-        DragState    state;
-        QPoint       start;
-        QDrag   *dragObject;
+        DragState state;
+        QPoint start;
+        QDrag *dragObject;
     } m_dragInfo;
 
     //
@@ -326,8 +323,8 @@ private:
     // These are now cursors to account for word-wrap.
     // Start Position is a virtual cursor
     Kate::TextCursor m_startPos;
-    //Count of lines that are visible behind m_startPos.
-    //This does not respect dynamic word wrap, so take it as an approximation.
+    // Count of lines that are visible behind m_startPos.
+    // This does not respect dynamic word wrap, so take it as an approximation.
     uint m_visibleLineCount;
 
     // This is set to false on resize or scroll (other than that called by makeVisible),
@@ -398,6 +395,9 @@ private:
     //
 public:
     void flashChar(const KTextEditor::Cursor &pos, KTextEditor::Attribute::Ptr attribute);
+    void showBracketMatchPreview();
+    void hideBracketMatchPreview();
+
 private:
     QPointer<KateTextAnimation> m_textAnimation;
 
@@ -435,7 +435,7 @@ public:
     bool textHintsEnabled(); // not part of the interface
 
 private:
-    QVector<KTextEditor::TextHintProvider*> m_textHintProviders;
+    QVector<KTextEditor::TextHintProvider *> m_textHintProviders;
     int m_textHintDelay;
     QPoint m_textHintPos;
 
@@ -469,9 +469,8 @@ private:
     KateAbstractInputMode *m_currentInputMode;
 
     KateInlineNoteData m_activeInlineNote;
-    KateInlineNoteData inlineNoteAt(const QPoint& globalPos) const;
-    QRect inlineNoteRect(const KateInlineNoteData& note) const;
+    KateInlineNoteData inlineNoteAt(const QPoint &globalPos) const;
+    QRect inlineNoteRect(const KateInlineNoteData &note) const;
 };
 
 #endif
-
