@@ -1,26 +1,11 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2009 Erlend Hamberg <ehamberg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
 
-    Copyright (C) 2009 Erlend Hamberg <ehamberg@gmail.com>
-    Copyright (C) 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QDir>
-#include <QRegularExpression>
 #include <QTimer>
 
 #include <KLocalizedString>
@@ -63,7 +48,11 @@ AppCommands::~AppCommands()
 
 bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg, const KTextEditor::Range &)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList args(cmd.split(QRegularExpression(QStringLiteral("\\s+")), QString::SkipEmptyParts));
+#else
+    QStringList args(cmd.split(QRegularExpression(QStringLiteral("\\s+")), Qt::SkipEmptyParts));
+#endif
     QString command(args.takeFirst());
 
     KTextEditor::MainWindow *mainWin = view->mainWindow();
@@ -71,7 +60,7 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
 
     QRegularExpressionMatch match;
     if ((match = re_write.match(command)).hasMatch()) { // TODO: handle writing to specific file
-        if (!match.captured(1).isEmpty()) {             // [a]ll
+        if (!match.captured(1).isEmpty()) { // [a]ll
             const auto docs = app->documents();
             for (KTextEditor::Document *doc : docs) {
                 doc->save();
@@ -84,10 +73,12 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
     }
     // Other buffer commands are implemented by the KateFileTree plugin
     else if ((match = re_close.match(command)).hasMatch()) {
-        QTimer::singleShot(0, [app, view]() { app->closeDocument(view->document()); });
+        QTimer::singleShot(0, [app, view]() {
+            app->closeDocument(view->document());
+        });
     } else if ((match = re_quit.match(command)).hasMatch()) {
-        const bool save = !match.captured(1).isEmpty();               // :[w]q
-        const bool allDocuments = !match.captured(2).isEmpty();       // :q[all]
+        const bool save = !match.captured(1).isEmpty(); // :[w]q
+        const bool allDocuments = !match.captured(2).isEmpty(); // :q[all]
         const bool doNotPromptForSave = !match.captured(3).isEmpty(); // :q[!]
 
         if (allDocuments) {
@@ -150,7 +141,9 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
         if (argument.isEmpty() || argument == QLatin1String("!")) {
             if ((match = re_tabedit.match(command)).hasMatch()) {
                 if (auto doc = app->openUrl(QUrl())) {
-                    QTimer::singleShot(0, [mainWin, doc]() { mainWin->activateView(doc); });
+                    QTimer::singleShot(0, [mainWin, doc]() {
+                        mainWin->activateView(doc);
+                    });
                 }
             } else {
                 view->document()->documentReload();
@@ -159,9 +152,9 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
             QUrl base = view->document()->url();
             QUrl url;
             QUrl arg2path(argument);
-            if (base.isValid()) {                                                            // first try to use the same path as the current open document has
-                url = QUrl(base.resolved(arg2path));                                         // resolved handles the case where the args is a relative path, and is the same as using QUrl(args) elsewise
-            } else {                                                                         // else use the cwd
+            if (base.isValid()) { // first try to use the same path as the current open document has
+                url = QUrl(base.resolved(arg2path)); // resolved handles the case where the args is a relative path, and is the same as using QUrl(args) elsewise
+            } else { // else use the cwd
                 url = QUrl(QUrl(QDir::currentPath() + QLatin1Char('/')).resolved(arg2path)); // + "/" is needed because of https://lists.qt-project.org/pipermail/qt-interest-old/2011-May/033913.html
             }
             QFileInfo file(url.toLocalFile());
@@ -178,7 +171,9 @@ bool AppCommands::exec(KTextEditor::View *view, const QString &cmd, QString &msg
                 }
             }
             if (doc) {
-                QTimer::singleShot(0, [mainWin, doc]() { mainWin->activateView(doc); });
+                QTimer::singleShot(0, [mainWin, doc]() {
+                    mainWin->activateView(doc);
+                });
             }
         }
         // splitView() orientations are reversed from the usual editor convention.
@@ -304,7 +299,9 @@ void AppCommands::closeCurrentDocument()
 {
     KTextEditor::Application *app = KTextEditor::Editor::instance()->application();
     KTextEditor::Document *doc = app->activeMainWindow()->activeView()->document();
-    QTimer::singleShot(0, [app, doc]() { app->closeDocument(doc); });
+    QTimer::singleShot(0, [app, doc]() {
+        app->closeDocument(doc);
+    });
 }
 
 void AppCommands::closeCurrentView()
@@ -374,7 +371,11 @@ BufferCommands::~BufferCommands()
 bool BufferCommands::exec(KTextEditor::View *view, const QString &cmd, QString &, const KTextEditor::Range &)
 {
     // create list of args
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList args(cmd.split(QLatin1Char(' '), QString::KeepEmptyParts));
+#else
+    QStringList args(cmd.split(QLatin1Char(' '), Qt::KeepEmptyParts));
+#endif
     QString command = args.takeFirst(); // same as cmd if split failed
     QString argument = args.join(QLatin1Char(' '));
 
@@ -496,7 +497,9 @@ void BufferCommands::lastTab(KTextEditor::View *view)
 void BufferCommands::activateDocument(KTextEditor::View *view, KTextEditor::Document *doc)
 {
     KTextEditor::MainWindow *mainWindow = view->mainWindow();
-    QTimer::singleShot(0, [mainWindow, doc]() { mainWindow->activateView(doc); });
+    QTimer::singleShot(0, [mainWindow, doc]() {
+        mainWindow->activateView(doc);
+    });
 }
 
 QList<KTextEditor::Document *> BufferCommands::documents()
