@@ -1,57 +1,42 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2008 - 2009 Erlend Hamberg <ehamberg@gmail.com>
- *  Copyright (C) 2009 Paul Gideon Dann <pdgiddie@gmail.com>
- *  Copyright (C) 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
- *  Copyright (C) 2012 - 2013 Simon St James <kdedevel@etotheipiplusone.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2008-2009 Erlend Hamberg <ehamberg@gmail.com>
+    SPDX-FileCopyrightText: 2009 Paul Gideon Dann <pdgiddie@gmail.com>
+    SPDX-FileCopyrightText: 2011 Svyatoslav Kuzmich <svatoslav1@gmail.com>
+    SPDX-FileCopyrightText: 2012-2013 Simon St James <kdedevel@etotheipiplusone.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include <vimode/inputmodemanager.h>
 
-#include <QKeyEvent>
-#include <QString>
 #include <QApplication>
+#include <QString>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 
-#include "kateconfig.h"
-#include "kateglobal.h"
-#include "globalstate.h"
-#include "kateviewinternal.h"
-#include <vimode/modes/normalvimode.h>
-#include <vimode/modes/insertvimode.h>
-#include <vimode/modes/visualvimode.h>
-#include <vimode/modes/replacevimode.h>
-#include <vimode/keyparser.h>
-#include <vimode/keymapper.h>
-#include <vimode/emulatedcommandbar.h>
-#include "kateviinputmode.h"
-#include "marks.h"
-#include "jumps.h"
-#include "macros.h"
-#include "registers.h"
-#include "searcher.h"
 #include "completionrecorder.h"
 #include "completionreplayer.h"
-#include "macrorecorder.h"
+#include "globalstate.h"
+#include "jumps.h"
+#include "kateconfig.h"
+#include "kateglobal.h"
+#include "kateviewinternal.h"
+#include "kateviinputmode.h"
 #include "lastchangerecorder.h"
+#include "macrorecorder.h"
+#include "macros.h"
+#include "marks.h"
+#include "registers.h"
+#include "searcher.h"
+#include <vimode/emulatedcommandbar/emulatedcommandbar.h>
+#include <vimode/keymapper.h>
+#include <vimode/keyparser.h>
+#include <vimode/modes/insertvimode.h>
+#include <vimode/modes/normalvimode.h>
+#include <vimode/modes/replacevimode.h>
+#include <vimode/modes/visualvimode.h>
 
 using namespace KateVi;
 
@@ -118,7 +103,7 @@ bool InputModeManager::handleKeypress(const QKeyEvent *e)
     // of a mapping, we don't want to record them when they are played back by m_keyMapper, hence
     // the "!isPlayingBackRejectedKeys()". And obviously, since we're recording keys before they are mapped, we don't
     // want to also record the executed mapping, as when we replayed the macro, we'd get duplication!
-    if (m_macroRecorder->isRecording() && !m_macroRecorder->isReplaying() && !isSyntheticSearchCompletedKeyPress && !keyMapper()->isExecutingMapping() && !keyMapper()->isPlayingBackRejectedKeys()) {
+    if (m_macroRecorder->isRecording() && !m_macroRecorder->isReplaying() && !isSyntheticSearchCompletedKeyPress && !keyMapper()->isExecutingMapping() && !keyMapper()->isPlayingBackRejectedKeys() && !lastChangeRecorder()->isReplaying()) {
         m_macroRecorder->record(*e);
     }
 
@@ -162,22 +147,20 @@ void InputModeManager::feedKeyPresses(const QString &keyPresses) const
     Qt::KeyboardModifiers mods;
     QString text;
 
-    foreach (QChar c, keyPresses) {
+    for (const QChar c : keyPresses) {
         QString decoded = KeyParser::self()->decodeKeySequence(QString(c));
         key = -1;
         mods = Qt::NoModifier;
         text.clear();
 
-        if (decoded.length() > 1) {  // special key
+        if (decoded.length() > 1) { // special key
 
             // remove the angle brackets
             decoded.remove(0, 1);
-            decoded.remove(decoded.indexOf(QLatin1String(">")), 1);
+            decoded.remove(decoded.indexOf(QLatin1Char('>')), 1);
 
             // check if one or more modifier keys where used
-            if (decoded.indexOf(QLatin1String("s-")) != -1 || decoded.indexOf(QLatin1String("c-")) != -1
-                    || decoded.indexOf(QLatin1String("m-")) != -1 || decoded.indexOf(QLatin1String("a-")) != -1) {
-
+            if (decoded.indexOf(QLatin1String("s-")) != -1 || decoded.indexOf(QLatin1String("c-")) != -1 || decoded.indexOf(QLatin1String("m-")) != -1 || decoded.indexOf(QLatin1String("a-")) != -1) {
                 int s = decoded.indexOf(QLatin1String("s-"));
                 if (s != -1) {
                     mods |= Qt::ShiftModifier;
@@ -216,10 +199,13 @@ void InputModeManager::feedKeyPresses(const QString &keyPresses) const
             text = decoded.at(0);
         }
 
+        if (key == -1)
+            continue;
+
         // We have to be clever about which widget we dispatch to, as we can trigger
         // shortcuts if we're not careful (even if Vim mode is configured to steal shortcuts).
         QKeyEvent k(QEvent::KeyPress, key, mods, text);
-        QWidget *destWidget = NULL;
+        QWidget *destWidget = nullptr;
         if (QApplication::activePopupWidget()) {
             // According to the docs, the activePopupWidget, if present, takes all events.
             destWidget = QApplication::activePopupWidget();
@@ -278,19 +264,19 @@ ViMode InputModeManager::getCurrentViMode() const
 KTextEditor::View::ViewMode InputModeManager::getCurrentViewMode() const
 {
     switch (m_currentViMode) {
-        case ViMode::InsertMode:
-            return KTextEditor::View::ViModeInsert;
-        case ViMode::VisualMode:
-            return KTextEditor::View::ViModeVisual;
-        case ViMode::VisualLineMode:
-            return KTextEditor::View::ViModeVisualLine;
-        case ViMode::VisualBlockMode:
-            return KTextEditor::View::ViModeVisualBlock;
-        case ViMode::ReplaceMode:
-            return KTextEditor::View::ViModeReplace;
-        case ViMode::NormalMode:
-        default:
-            return KTextEditor::View::ViModeNormal;
+    case ViMode::InsertMode:
+        return KTextEditor::View::ViModeInsert;
+    case ViMode::VisualMode:
+        return KTextEditor::View::ViModeVisual;
+    case ViMode::VisualLineMode:
+        return KTextEditor::View::ViModeVisualLine;
+    case ViMode::VisualBlockMode:
+        return KTextEditor::View::ViModeVisualBlock;
+    case ViMode::ReplaceMode:
+        return KTextEditor::View::ViModeReplace;
+    case ViMode::NormalMode:
+    default:
+        return KTextEditor::View::ViModeNormal;
     }
 }
 
@@ -301,9 +287,7 @@ ViMode InputModeManager::getPreviousViMode() const
 
 bool InputModeManager::isAnyVisualMode() const
 {
-    return ((m_currentViMode == ViMode::VisualMode) ||
-            (m_currentViMode == ViMode::VisualLineMode) ||
-            (m_currentViMode == ViMode::VisualBlockMode));
+    return ((m_currentViMode == ViMode::VisualMode) || (m_currentViMode == ViMode::VisualLineMode) || (m_currentViMode == ViMode::VisualBlockMode));
 }
 
 ::ModeBase *InputModeManager::getCurrentViModeHandler() const
@@ -320,17 +304,14 @@ bool InputModeManager::isAnyVisualMode() const
     case ViMode::ReplaceMode:
         return m_viReplaceMode;
     }
-    return NULL;
+    return nullptr;
 }
 
 void InputModeManager::viEnterNormalMode()
 {
-    bool moveCursorLeft = (m_currentViMode == ViMode::InsertMode || m_currentViMode == ViMode::ReplaceMode)
-                          && m_viewInternal->getCursor().column() > 0;
+    bool moveCursorLeft = (m_currentViMode == ViMode::InsertMode || m_currentViMode == ViMode::ReplaceMode) && m_viewInternal->cursorPosition().column() > 0;
 
-    if (!m_lastChangeRecorder->isReplaying() &&
-            (m_currentViMode == ViMode::InsertMode ||
-             m_currentViMode == ViMode::ReplaceMode)) {
+    if (!m_lastChangeRecorder->isReplaying() && (m_currentViMode == ViMode::InsertMode || m_currentViMode == ViMode::ReplaceMode)) {
         // '^ is the insert mark and "^ is the insert register,
         // which holds the last inserted text
         KTextEditor::Range r(m_view->cursorPosition(), m_marks->getInsertStopped());
@@ -467,7 +448,6 @@ KTextEditor::ViewPrivate *InputModeManager::view() const
     return m_view;
 }
 
-
 void InputModeManager::pushKeyMapper(QSharedPointer<KeyMapper> mapper)
 {
     m_keyMapperStack.push(mapper);
