@@ -1,41 +1,27 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2008-2009 Erlend Hamberg <ehamberg@gmail.com>
- *  Copyright (C) 2013 Simon St James <kdedevel@etotheipiplusone.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2008-2009 Erlend Hamberg <ehamberg@gmail.com>
+    SPDX-FileCopyrightText: 2013 Simon St James <kdedevel@etotheipiplusone.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
-#include "kateglobal.h"
 #include "globalstate.h"
-#include "mappings.h"
-#include "katepartdebug.h"
 #include "katedocument.h"
+#include "kateglobal.h"
+#include "macrorecorder.h"
+#include "mappings.h"
+#include <vimode/inputmodemanager.h>
 #include <vimode/keymapper.h>
 #include <vimode/keyparser.h>
-#include <vimode/inputmodemanager.h>
 
 #include <QTimer>
 
 using namespace KateVi;
 
 KeyMapper::KeyMapper(InputModeManager *kateViInputModeManager, KTextEditor::DocumentPrivate *doc, KTextEditor::ViewPrivate *view)
-    : m_viInputModeManager(kateViInputModeManager),
-      m_doc(doc),
-      m_view(view)
+    : m_viInputModeManager(kateViInputModeManager)
+    , m_doc(doc)
+    , m_view(view)
 {
     m_mappingTimer = new QTimer(this);
     m_doNotExpandFurtherMappings = false;
@@ -53,7 +39,6 @@ void KeyMapper::executeMapping()
     m_numMappingsBeingExecuted++;
     const QString mappedKeypresses = m_viInputModeManager->globalState()->mappings()->get(Mappings::mappingModeForCurrentViMode(m_viInputModeManager->inputAdapter()), m_fullMappingMatch, false, true);
     if (!m_viInputModeManager->globalState()->mappings()->isRecursive(Mappings::mappingModeForCurrentViMode(m_viInputModeManager->inputAdapter()), m_fullMappingMatch)) {
-        qCDebug(LOG_PART) << "Non-recursive: " << mappedKeypresses;
         m_doNotExpandFurtherMappings = true;
     }
     m_doc->editBegin();
@@ -79,7 +64,6 @@ void KeyMapper::setMappingTimeout(int timeoutMS)
 
 void KeyMapper::mappingTimerTimeOut()
 {
-    qCDebug(LOG_PART) << "timeout! key presses: " << m_mappingKeys;
     if (!m_fullMappingMatch.isNull()) {
         executeMapping();
     } else {
@@ -96,7 +80,9 @@ bool KeyMapper::handleKeypress(QChar key)
         bool isPartialMapping = false;
         bool isFullMapping = false;
         m_fullMappingMatch.clear();
-        foreach (const QString &mapping, m_viInputModeManager->globalState()->mappings()->getAll(Mappings::mappingModeForCurrentViMode(m_viInputModeManager->inputAdapter()), false, true)) {
+        const auto mappingMode = Mappings::mappingModeForCurrentViMode(m_viInputModeManager->inputAdapter());
+        const auto mappings = m_viInputModeManager->globalState()->mappings()->getAll(mappingMode, false, true);
+        for (const QString &mapping : mappings) {
             if (mapping.startsWith(m_mappingKeys)) {
                 if (mapping == m_mappingKeys) {
                     isFullMapping = true;
@@ -122,8 +108,30 @@ bool KeyMapper::handleKeypress(QChar key)
         // We've been swallowing all the keypresses meant for m_keys for our mapping keys; now that we know
         // this cannot be a mapping, restore them.
         Q_ASSERT(!isPartialMapping && !isFullMapping);
-        playBackRejectedKeys();
-        return true;
+        const bool isUserKeypress = !m_viInputModeManager->macroRecorder()->isReplaying() && !isExecutingMapping();
+        if (isUserKeypress && m_mappingKeys.size() == 1) {
+            // Ugh - unpleasant complication starting with Qt 5.5-ish - it is no
+            // longer possible to replay QKeyEvents in such a way that shortcuts
+            // are triggered, so if we want to correctly handle a shortcut (e.g.
+            // ctrl+s for e.g. Save), we can no longer pop it into m_mappingKeys
+            // then immediately playBackRejectedKeys() (as this will not trigger
+            // the e.g. Save shortcut) - the best we can do is, if e.g. ctrl+s is
+            // not part of any mapping, immediately return false, *not* calling
+            // playBackRejectedKeys() and clearing m_mappingKeys ourselves.
+            // If e.g. ctrl+s *is* part of a mapping, then if the mapping is
+            // rejected, the played back e.g. ctrl+s does not trigger the e.g.
+            // Save shortcut. Likewise, we can no longer have e.g. ctrl+s inside
+            // mappings or macros - the e.g. Save shortcut will not be triggered!
+            // Altogether, a pretty disastrous change from Qt's old behaviour -
+            // either they "fix" it (although it could be argued that being able
+            // to trigger shortcuts from QKeyEvents was never the desired behaviour)
+            // or we try to emulate Shortcut-handling ourselves :(
+            m_mappingKeys.clear();
+            return false;
+        } else {
+            playBackRejectedKeys();
+            return true;
+        }
     }
     m_doNotMapNextKeypress = false;
     return false;
@@ -143,4 +151,3 @@ bool KeyMapper::isPlayingBackRejectedKeys()
 {
     return m_isPlayingBackRejectedKeys;
 }
-
